Documentation
¶
Index ¶
- Variables
- func GetEndpointMap() map[string]string
- func GetEndpointType() string
- func SetClientProperty(client *Client, propertyName string, propertyValue interface{})
- func SetEndpointDataToClient(client *Client)
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) CreateConfiguration(request *CreateConfigurationRequest) (response *CreateConfigurationResponse, err error)
- func (client *Client) CreateConfigurationWithCallback(request *CreateConfigurationRequest, ...) <-chan int
- func (client *Client) CreateConfigurationWithChan(request *CreateConfigurationRequest) (<-chan *CreateConfigurationResponse, <-chan error)
- func (client *Client) CreateNamespace(request *CreateNamespaceRequest) (response *CreateNamespaceResponse, err error)
- func (client *Client) CreateNamespaceWithCallback(request *CreateNamespaceRequest, ...) <-chan int
- func (client *Client) CreateNamespaceWithChan(request *CreateNamespaceRequest) (<-chan *CreateNamespaceResponse, <-chan error)
- func (client *Client) DeleteConfiguration(request *DeleteConfigurationRequest) (response *DeleteConfigurationResponse, err error)
- func (client *Client) DeleteConfigurationWithCallback(request *DeleteConfigurationRequest, ...) <-chan int
- func (client *Client) DeleteConfigurationWithChan(request *DeleteConfigurationRequest) (<-chan *DeleteConfigurationResponse, <-chan error)
- func (client *Client) DeleteNamespace(request *DeleteNamespaceRequest) (response *DeleteNamespaceResponse, err error)
- func (client *Client) DeleteNamespaceWithCallback(request *DeleteNamespaceRequest, ...) <-chan int
- func (client *Client) DeleteNamespaceWithChan(request *DeleteNamespaceRequest) (<-chan *DeleteNamespaceResponse, <-chan error)
- func (client *Client) DeployConfiguration(request *DeployConfigurationRequest) (response *DeployConfigurationResponse, err error)
- func (client *Client) DeployConfigurationWithCallback(request *DeployConfigurationRequest, ...) <-chan int
- func (client *Client) DeployConfigurationWithChan(request *DeployConfigurationRequest) (<-chan *DeployConfigurationResponse, <-chan error)
- func (client *Client) DescribeConfiguration(request *DescribeConfigurationRequest) (response *DescribeConfigurationResponse, err error)
- func (client *Client) DescribeConfigurationWithCallback(request *DescribeConfigurationRequest, ...) <-chan int
- func (client *Client) DescribeConfigurationWithChan(request *DescribeConfigurationRequest) (<-chan *DescribeConfigurationResponse, <-chan error)
- func (client *Client) DescribeNamespace(request *DescribeNamespaceRequest) (response *DescribeNamespaceResponse, err error)
- func (client *Client) DescribeNamespaceWithCallback(request *DescribeNamespaceRequest, ...) <-chan int
- func (client *Client) DescribeNamespaceWithChan(request *DescribeNamespaceRequest) (<-chan *DescribeNamespaceResponse, <-chan error)
- func (client *Client) UpdateNamespace(request *UpdateNamespaceRequest) (response *UpdateNamespaceResponse, err error)
- func (client *Client) UpdateNamespaceWithCallback(request *UpdateNamespaceRequest, ...) <-chan int
- func (client *Client) UpdateNamespaceWithChan(request *UpdateNamespaceRequest) (<-chan *UpdateNamespaceResponse, <-chan error)
- type Configuration
- type CreateConfigurationRequest
- type CreateConfigurationResponse
- type CreateNamespaceRequest
- type CreateNamespaceResponse
- type DeleteConfigurationRequest
- type DeleteConfigurationResponse
- type DeleteNamespaceRequest
- type DeleteNamespaceResponse
- type DeployConfigurationRequest
- type DeployConfigurationResponse
- type DescribeConfigurationRequest
- type DescribeConfigurationResponse
- type DescribeNamespaceRequest
- type DescribeNamespaceResponse
- type Namespace
- type UpdateNamespaceRequest
- type UpdateNamespaceResponse
Constants ¶
This section is empty.
Variables ¶
var EndpointMap map[string]string
EndpointMap Endpoint Data
var EndpointType = "regional"
EndpointType regional or central
Functions ¶
func SetClientProperty ¶
SetClientProperty Set Property by Reflect
func SetEndpointDataToClient ¶
func SetEndpointDataToClient(client *Client)
SetEndpointDataToClient Set EndpointMap and ENdpointType
Types ¶
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) CreateConfiguration ¶
func (client *Client) CreateConfiguration(request *CreateConfigurationRequest) (response *CreateConfigurationResponse, err error)
CreateConfiguration invokes the acms_open.CreateConfiguration API synchronously api document: https://help.aliyun.com/api/acms-open/createconfiguration.html
func (*Client) CreateConfigurationWithCallback ¶
func (client *Client) CreateConfigurationWithCallback(request *CreateConfigurationRequest, callback func(response *CreateConfigurationResponse, err error)) <-chan int
CreateConfigurationWithCallback invokes the acms_open.CreateConfiguration API asynchronously api document: https://help.aliyun.com/api/acms-open/createconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CreateConfigurationWithChan ¶
func (client *Client) CreateConfigurationWithChan(request *CreateConfigurationRequest) (<-chan *CreateConfigurationResponse, <-chan error)
CreateConfigurationWithChan invokes the acms_open.CreateConfiguration API asynchronously api document: https://help.aliyun.com/api/acms-open/createconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CreateNamespace ¶
func (client *Client) CreateNamespace(request *CreateNamespaceRequest) (response *CreateNamespaceResponse, err error)
CreateNamespace invokes the acms_open.CreateNamespace API synchronously api document: https://help.aliyun.com/api/acms-open/createnamespace.html
func (*Client) CreateNamespaceWithCallback ¶
func (client *Client) CreateNamespaceWithCallback(request *CreateNamespaceRequest, callback func(response *CreateNamespaceResponse, err error)) <-chan int
CreateNamespaceWithCallback invokes the acms_open.CreateNamespace API asynchronously api document: https://help.aliyun.com/api/acms-open/createnamespace.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CreateNamespaceWithChan ¶
func (client *Client) CreateNamespaceWithChan(request *CreateNamespaceRequest) (<-chan *CreateNamespaceResponse, <-chan error)
CreateNamespaceWithChan invokes the acms_open.CreateNamespace API asynchronously api document: https://help.aliyun.com/api/acms-open/createnamespace.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteConfiguration ¶
func (client *Client) DeleteConfiguration(request *DeleteConfigurationRequest) (response *DeleteConfigurationResponse, err error)
DeleteConfiguration invokes the acms_open.DeleteConfiguration API synchronously api document: https://help.aliyun.com/api/acms-open/deleteconfiguration.html
func (*Client) DeleteConfigurationWithCallback ¶
func (client *Client) DeleteConfigurationWithCallback(request *DeleteConfigurationRequest, callback func(response *DeleteConfigurationResponse, err error)) <-chan int
DeleteConfigurationWithCallback invokes the acms_open.DeleteConfiguration API asynchronously api document: https://help.aliyun.com/api/acms-open/deleteconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteConfigurationWithChan ¶
func (client *Client) DeleteConfigurationWithChan(request *DeleteConfigurationRequest) (<-chan *DeleteConfigurationResponse, <-chan error)
DeleteConfigurationWithChan invokes the acms_open.DeleteConfiguration API asynchronously api document: https://help.aliyun.com/api/acms-open/deleteconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteNamespace ¶
func (client *Client) DeleteNamespace(request *DeleteNamespaceRequest) (response *DeleteNamespaceResponse, err error)
DeleteNamespace invokes the acms_open.DeleteNamespace API synchronously api document: https://help.aliyun.com/api/acms-open/deletenamespace.html
func (*Client) DeleteNamespaceWithCallback ¶
func (client *Client) DeleteNamespaceWithCallback(request *DeleteNamespaceRequest, callback func(response *DeleteNamespaceResponse, err error)) <-chan int
DeleteNamespaceWithCallback invokes the acms_open.DeleteNamespace API asynchronously api document: https://help.aliyun.com/api/acms-open/deletenamespace.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeleteNamespaceWithChan ¶
func (client *Client) DeleteNamespaceWithChan(request *DeleteNamespaceRequest) (<-chan *DeleteNamespaceResponse, <-chan error)
DeleteNamespaceWithChan invokes the acms_open.DeleteNamespace API asynchronously api document: https://help.aliyun.com/api/acms-open/deletenamespace.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeployConfiguration ¶
func (client *Client) DeployConfiguration(request *DeployConfigurationRequest) (response *DeployConfigurationResponse, err error)
DeployConfiguration invokes the acms_open.DeployConfiguration API synchronously api document: https://help.aliyun.com/api/acms-open/deployconfiguration.html
func (*Client) DeployConfigurationWithCallback ¶
func (client *Client) DeployConfigurationWithCallback(request *DeployConfigurationRequest, callback func(response *DeployConfigurationResponse, err error)) <-chan int
DeployConfigurationWithCallback invokes the acms_open.DeployConfiguration API asynchronously api document: https://help.aliyun.com/api/acms-open/deployconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DeployConfigurationWithChan ¶
func (client *Client) DeployConfigurationWithChan(request *DeployConfigurationRequest) (<-chan *DeployConfigurationResponse, <-chan error)
DeployConfigurationWithChan invokes the acms_open.DeployConfiguration API asynchronously api document: https://help.aliyun.com/api/acms-open/deployconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeConfiguration ¶
func (client *Client) DescribeConfiguration(request *DescribeConfigurationRequest) (response *DescribeConfigurationResponse, err error)
DescribeConfiguration invokes the acms_open.DescribeConfiguration API synchronously api document: https://help.aliyun.com/api/acms-open/describeconfiguration.html
func (*Client) DescribeConfigurationWithCallback ¶
func (client *Client) DescribeConfigurationWithCallback(request *DescribeConfigurationRequest, callback func(response *DescribeConfigurationResponse, err error)) <-chan int
DescribeConfigurationWithCallback invokes the acms_open.DescribeConfiguration API asynchronously api document: https://help.aliyun.com/api/acms-open/describeconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeConfigurationWithChan ¶
func (client *Client) DescribeConfigurationWithChan(request *DescribeConfigurationRequest) (<-chan *DescribeConfigurationResponse, <-chan error)
DescribeConfigurationWithChan invokes the acms_open.DescribeConfiguration API asynchronously api document: https://help.aliyun.com/api/acms-open/describeconfiguration.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNamespace ¶
func (client *Client) DescribeNamespace(request *DescribeNamespaceRequest) (response *DescribeNamespaceResponse, err error)
DescribeNamespace invokes the acms_open.DescribeNamespace API synchronously api document: https://help.aliyun.com/api/acms-open/describenamespace.html
func (*Client) DescribeNamespaceWithCallback ¶
func (client *Client) DescribeNamespaceWithCallback(request *DescribeNamespaceRequest, callback func(response *DescribeNamespaceResponse, err error)) <-chan int
DescribeNamespaceWithCallback invokes the acms_open.DescribeNamespace API asynchronously api document: https://help.aliyun.com/api/acms-open/describenamespace.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNamespaceWithChan ¶
func (client *Client) DescribeNamespaceWithChan(request *DescribeNamespaceRequest) (<-chan *DescribeNamespaceResponse, <-chan error)
DescribeNamespaceWithChan invokes the acms_open.DescribeNamespace API asynchronously api document: https://help.aliyun.com/api/acms-open/describenamespace.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateNamespace ¶
func (client *Client) UpdateNamespace(request *UpdateNamespaceRequest) (response *UpdateNamespaceResponse, err error)
UpdateNamespace invokes the acms_open.UpdateNamespace API synchronously api document: https://help.aliyun.com/api/acms-open/updatenamespace.html
func (*Client) UpdateNamespaceWithCallback ¶
func (client *Client) UpdateNamespaceWithCallback(request *UpdateNamespaceRequest, callback func(response *UpdateNamespaceResponse, err error)) <-chan int
UpdateNamespaceWithCallback invokes the acms_open.UpdateNamespace API asynchronously api document: https://help.aliyun.com/api/acms-open/updatenamespace.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) UpdateNamespaceWithChan ¶
func (client *Client) UpdateNamespaceWithChan(request *UpdateNamespaceRequest) (<-chan *UpdateNamespaceResponse, <-chan error)
UpdateNamespaceWithChan invokes the acms_open.UpdateNamespace API asynchronously api document: https://help.aliyun.com/api/acms-open/updatenamespace.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
type Configuration ¶
type Configuration struct {
DataId string `json:"DataId" xml:"DataId"`
Group string `json:"Group" xml:"Group"`
Content string `json:"Content" xml:"Content"`
Md5 string `json:"Md5" xml:"Md5"`
AppName string `json:"AppName" xml:"AppName"`
Desc string `json:"Desc" xml:"Desc"`
Tags string `json:"Tags" xml:"Tags"`
}
Configuration is a nested struct in acms_open response
type CreateConfigurationRequest ¶
type CreateConfigurationRequest struct {
*requests.RoaRequest
DataId string `position:"Body" name:"DataId"`
AppName string `position:"Body" name:"AppName"`
NamespaceId string `position:"Body" name:"NamespaceId"`
Type string `position:"Body" name:"Type"`
Content string `position:"Body" name:"Content"`
Group string `position:"Body" name:"Group"`
Desc string `position:"Body" name:"Desc"`
Tags string `position:"Body" name:"Tags"`
}
CreateConfigurationRequest is the request struct for api CreateConfiguration
func CreateCreateConfigurationRequest ¶
func CreateCreateConfigurationRequest() (request *CreateConfigurationRequest)
CreateCreateConfigurationRequest creates a request to invoke CreateConfiguration API
type CreateConfigurationResponse ¶
type CreateConfigurationResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code string `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
}
CreateConfigurationResponse is the response struct for api CreateConfiguration
func CreateCreateConfigurationResponse ¶
func CreateCreateConfigurationResponse() (response *CreateConfigurationResponse)
CreateCreateConfigurationResponse creates a response to parse from CreateConfiguration response
type CreateNamespaceRequest ¶
type CreateNamespaceRequest struct {
*requests.RoaRequest
Name string `position:"Body" name:"Name"`
}
CreateNamespaceRequest is the request struct for api CreateNamespace
func CreateCreateNamespaceRequest ¶
func CreateCreateNamespaceRequest() (request *CreateNamespaceRequest)
CreateCreateNamespaceRequest creates a request to invoke CreateNamespace API
type CreateNamespaceResponse ¶
type CreateNamespaceResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code string `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
NamespaceId string `json:"NamespaceId" xml:"NamespaceId"`
}
CreateNamespaceResponse is the response struct for api CreateNamespace
func CreateCreateNamespaceResponse ¶
func CreateCreateNamespaceResponse() (response *CreateNamespaceResponse)
CreateCreateNamespaceResponse creates a response to parse from CreateNamespace response
type DeleteConfigurationRequest ¶
type DeleteConfigurationRequest struct {
*requests.RoaRequest
DataId string `position:"Query" name:"DataId"`
NamespaceId string `position:"Query" name:"NamespaceId"`
Group string `position:"Query" name:"Group"`
}
DeleteConfigurationRequest is the request struct for api DeleteConfiguration
func CreateDeleteConfigurationRequest ¶
func CreateDeleteConfigurationRequest() (request *DeleteConfigurationRequest)
CreateDeleteConfigurationRequest creates a request to invoke DeleteConfiguration API
type DeleteConfigurationResponse ¶
type DeleteConfigurationResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code string `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
}
DeleteConfigurationResponse is the response struct for api DeleteConfiguration
func CreateDeleteConfigurationResponse ¶
func CreateDeleteConfigurationResponse() (response *DeleteConfigurationResponse)
CreateDeleteConfigurationResponse creates a response to parse from DeleteConfiguration response
type DeleteNamespaceRequest ¶
type DeleteNamespaceRequest struct {
*requests.RoaRequest
NamespaceId string `position:"Query" name:"NamespaceId"`
}
DeleteNamespaceRequest is the request struct for api DeleteNamespace
func CreateDeleteNamespaceRequest ¶
func CreateDeleteNamespaceRequest() (request *DeleteNamespaceRequest)
CreateDeleteNamespaceRequest creates a request to invoke DeleteNamespace API
type DeleteNamespaceResponse ¶
type DeleteNamespaceResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code string `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
}
DeleteNamespaceResponse is the response struct for api DeleteNamespace
func CreateDeleteNamespaceResponse ¶
func CreateDeleteNamespaceResponse() (response *DeleteNamespaceResponse)
CreateDeleteNamespaceResponse creates a response to parse from DeleteNamespace response
type DeployConfigurationRequest ¶
type DeployConfigurationRequest struct {
*requests.RoaRequest
DataId string `position:"Body" name:"DataId"`
AppName string `position:"Body" name:"AppName"`
NamespaceId string `position:"Body" name:"NamespaceId"`
Type string `position:"Body" name:"Type"`
Content string `position:"Body" name:"Content"`
Group string `position:"Body" name:"Group"`
Desc string `position:"Body" name:"Desc"`
Tags string `position:"Body" name:"Tags"`
}
DeployConfigurationRequest is the request struct for api DeployConfiguration
func CreateDeployConfigurationRequest ¶
func CreateDeployConfigurationRequest() (request *DeployConfigurationRequest)
CreateDeployConfigurationRequest creates a request to invoke DeployConfiguration API
type DeployConfigurationResponse ¶
type DeployConfigurationResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code string `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
}
DeployConfigurationResponse is the response struct for api DeployConfiguration
func CreateDeployConfigurationResponse ¶
func CreateDeployConfigurationResponse() (response *DeployConfigurationResponse)
CreateDeployConfigurationResponse creates a response to parse from DeployConfiguration response
type DescribeConfigurationRequest ¶
type DescribeConfigurationRequest struct {
*requests.RoaRequest
DataId string `position:"Query" name:"DataId"`
NamespaceId string `position:"Query" name:"NamespaceId"`
Group string `position:"Query" name:"Group"`
}
DescribeConfigurationRequest is the request struct for api DescribeConfiguration
func CreateDescribeConfigurationRequest ¶
func CreateDescribeConfigurationRequest() (request *DescribeConfigurationRequest)
CreateDescribeConfigurationRequest creates a request to invoke DescribeConfiguration API
type DescribeConfigurationResponse ¶
type DescribeConfigurationResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Message string `json:"Message" xml:"Message"`
Code string `json:"Code" xml:"Code"`
Configuration Configuration `json:"Configuration" xml:"Configuration"`
}
DescribeConfigurationResponse is the response struct for api DescribeConfiguration
func CreateDescribeConfigurationResponse ¶
func CreateDescribeConfigurationResponse() (response *DescribeConfigurationResponse)
CreateDescribeConfigurationResponse creates a response to parse from DescribeConfiguration response
type DescribeNamespaceRequest ¶
type DescribeNamespaceRequest struct {
*requests.RoaRequest
NamespaceId string `position:"Query" name:"NamespaceId"`
}
DescribeNamespaceRequest is the request struct for api DescribeNamespace
func CreateDescribeNamespaceRequest ¶
func CreateDescribeNamespaceRequest() (request *DescribeNamespaceRequest)
CreateDescribeNamespaceRequest creates a request to invoke DescribeNamespace API
type DescribeNamespaceResponse ¶
type DescribeNamespaceResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code string `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
Namespace Namespace `json:"Namespace" xml:"Namespace"`
}
DescribeNamespaceResponse is the response struct for api DescribeNamespace
func CreateDescribeNamespaceResponse ¶
func CreateDescribeNamespaceResponse() (response *DescribeNamespaceResponse)
CreateDescribeNamespaceResponse creates a response to parse from DescribeNamespace response
type Namespace ¶
type Namespace struct {
RegionId string `json:"RegionId" xml:"RegionId"`
Endpoint string `json:"Endpoint" xml:"Endpoint"`
AccessKey string `json:"AccessKey" xml:"AccessKey"`
SecretKey string `json:"SecretKey" xml:"SecretKey"`
Name string `json:"Name" xml:"Name"`
}
Namespace is a nested struct in acms_open response
type UpdateNamespaceRequest ¶
type UpdateNamespaceRequest struct {
*requests.RoaRequest
NamespaceName string `position:"Body" name:"NamespaceName"`
NamespaceId string `position:"Body" name:"NamespaceId"`
}
UpdateNamespaceRequest is the request struct for api UpdateNamespace
func CreateUpdateNamespaceRequest ¶
func CreateUpdateNamespaceRequest() (request *UpdateNamespaceRequest)
CreateUpdateNamespaceRequest creates a request to invoke UpdateNamespace API
type UpdateNamespaceResponse ¶
type UpdateNamespaceResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code string `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
}
UpdateNamespaceResponse is the response struct for api UpdateNamespace
func CreateUpdateNamespaceResponse ¶
func CreateUpdateNamespaceResponse() (response *UpdateNamespaceResponse)
CreateUpdateNamespaceResponse creates a response to parse from UpdateNamespace response