Documentation
¶
Index ¶
- Variables
- func GetEndpointMap() map[string]string
- func GetEndpointType() string
- func SetClientProperty(client *Client, propertyName string, propertyValue interface{})
- func SetEndpointDataToClient(client *Client)
- type CapUrl
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) DescribeBgpPackByIp(request *DescribeBgpPackByIpRequest) (response *DescribeBgpPackByIpResponse, err error)
- func (client *Client) DescribeBgpPackByIpWithCallback(request *DescribeBgpPackByIpRequest, ...) <-chan int
- func (client *Client) DescribeBgpPackByIpWithChan(request *DescribeBgpPackByIpRequest) (<-chan *DescribeBgpPackByIpResponse, <-chan error)
- func (client *Client) DescribeCap(request *DescribeCapRequest) (response *DescribeCapResponse, err error)
- func (client *Client) DescribeCapWithCallback(request *DescribeCapRequest, ...) <-chan int
- func (client *Client) DescribeCapWithChan(request *DescribeCapRequest) (<-chan *DescribeCapResponse, <-chan error)
- func (client *Client) DescribeDdosCount(request *DescribeDdosCountRequest) (response *DescribeDdosCountResponse, err error)
- func (client *Client) DescribeDdosCountWithCallback(request *DescribeDdosCountRequest, ...) <-chan int
- func (client *Client) DescribeDdosCountWithChan(request *DescribeDdosCountRequest) (<-chan *DescribeDdosCountResponse, <-chan error)
- func (client *Client) DescribeDdosCredit(request *DescribeDdosCreditRequest) (response *DescribeDdosCreditResponse, err error)
- func (client *Client) DescribeDdosCreditWithCallback(request *DescribeDdosCreditRequest, ...) <-chan int
- func (client *Client) DescribeDdosCreditWithChan(request *DescribeDdosCreditRequest) (<-chan *DescribeDdosCreditResponse, <-chan error)
- func (client *Client) DescribeDdosEventList(request *DescribeDdosEventListRequest) (response *DescribeDdosEventListResponse, err error)
- func (client *Client) DescribeDdosEventListWithCallback(request *DescribeDdosEventListRequest, ...) <-chan int
- func (client *Client) DescribeDdosEventListWithChan(request *DescribeDdosEventListRequest) (<-chan *DescribeDdosEventListResponse, <-chan error)
- func (client *Client) DescribeDdosThreshold(request *DescribeDdosThresholdRequest) (response *DescribeDdosThresholdResponse, err error)
- func (client *Client) DescribeDdosThresholdWithCallback(request *DescribeDdosThresholdRequest, ...) <-chan int
- func (client *Client) DescribeDdosThresholdWithChan(request *DescribeDdosThresholdRequest) (<-chan *DescribeDdosThresholdResponse, <-chan error)
- func (client *Client) DescribeInstance(request *DescribeInstanceRequest) (response *DescribeInstanceResponse, err error)
- func (client *Client) DescribeInstanceIpAddress(request *DescribeInstanceIpAddressRequest) (response *DescribeInstanceIpAddressResponse, err error)
- func (client *Client) DescribeInstanceIpAddressWithCallback(request *DescribeInstanceIpAddressRequest, ...) <-chan int
- func (client *Client) DescribeInstanceIpAddressWithChan(request *DescribeInstanceIpAddressRequest) (<-chan *DescribeInstanceIpAddressResponse, <-chan error)
- func (client *Client) DescribeInstanceWithCallback(request *DescribeInstanceRequest, ...) <-chan int
- func (client *Client) DescribeInstanceWithChan(request *DescribeInstanceRequest) (<-chan *DescribeInstanceResponse, <-chan error)
- func (client *Client) DescribeIpDdosThreshold(request *DescribeIpDdosThresholdRequest) (response *DescribeIpDdosThresholdResponse, err error)
- func (client *Client) DescribeIpDdosThresholdWithCallback(request *DescribeIpDdosThresholdRequest, ...) <-chan int
- func (client *Client) DescribeIpDdosThresholdWithChan(request *DescribeIpDdosThresholdRequest) (<-chan *DescribeIpDdosThresholdResponse, <-chan error)
- func (client *Client) DescribeIpLocationService(request *DescribeIpLocationServiceRequest) (response *DescribeIpLocationServiceResponse, err error)
- func (client *Client) DescribeIpLocationServiceWithCallback(request *DescribeIpLocationServiceRequest, ...) <-chan int
- func (client *Client) DescribeIpLocationServiceWithChan(request *DescribeIpLocationServiceRequest) (<-chan *DescribeIpLocationServiceResponse, <-chan error)
- func (client *Client) DescribeRegions(request *DescribeRegionsRequest) (response *DescribeRegionsResponse, err error)
- func (client *Client) DescribeRegionsWithCallback(request *DescribeRegionsRequest, ...) <-chan int
- func (client *Client) DescribeRegionsWithChan(request *DescribeRegionsRequest) (<-chan *DescribeRegionsResponse, <-chan error)
- func (client *Client) ModifyDdosStatus(request *ModifyDdosStatusRequest) (response *ModifyDdosStatusResponse, err error)
- func (client *Client) ModifyDdosStatusWithCallback(request *ModifyDdosStatusRequest, ...) <-chan int
- func (client *Client) ModifyDdosStatusWithChan(request *ModifyDdosStatusRequest) (<-chan *ModifyDdosStatusResponse, <-chan error)
- func (client *Client) ModifyDefenseThreshold(request *ModifyDefenseThresholdRequest) (response *ModifyDefenseThresholdResponse, err error)
- func (client *Client) ModifyDefenseThresholdWithCallback(request *ModifyDefenseThresholdRequest, ...) <-chan int
- func (client *Client) ModifyDefenseThresholdWithChan(request *ModifyDefenseThresholdRequest) (<-chan *ModifyDefenseThresholdResponse, <-chan error)
- func (client *Client) ModifyIpDefenseThreshold(request *ModifyIpDefenseThresholdRequest) (response *ModifyIpDefenseThresholdResponse, err error)
- func (client *Client) ModifyIpDefenseThresholdWithCallback(request *ModifyIpDefenseThresholdRequest, ...) <-chan int
- func (client *Client) ModifyIpDefenseThresholdWithChan(request *ModifyIpDefenseThresholdRequest) (<-chan *ModifyIpDefenseThresholdResponse, <-chan error)
- type DdosCount
- type DdosCredit
- type DdosEvent
- type DdosEventList
- type DdosbgpInfo
- type DescribeBgpPackByIpRequest
- type DescribeBgpPackByIpResponse
- type DescribeCapRequest
- type DescribeCapResponse
- type DescribeDdosCountRequest
- type DescribeDdosCountResponse
- type DescribeDdosCreditRequest
- type DescribeDdosCreditResponse
- type DescribeDdosEventListRequest
- type DescribeDdosEventListResponse
- type DescribeDdosThresholdRequest
- type DescribeDdosThresholdResponse
- type DescribeInstanceIpAddressRequest
- type DescribeInstanceIpAddressResponse
- type DescribeInstanceRequest
- type DescribeInstanceResponse
- type DescribeIpDdosThresholdRequest
- type DescribeIpDdosThresholdResponse
- type DescribeIpLocationServiceRequest
- type DescribeIpLocationServiceResponse
- type DescribeRegionsRequest
- type DescribeRegionsResponse
- type Instance
- type InstanceListInDescribeInstance
- type InstanceListInDescribeInstanceIpAddress
- type IpAddressConfig
- type IpAddressConfigItem
- type ModifyDdosStatusRequest
- type ModifyDdosStatusResponse
- type ModifyDefenseThresholdRequest
- type ModifyDefenseThresholdResponse
- type ModifyIpDefenseThresholdRequest
- type ModifyIpDefenseThresholdResponse
- type Region
- type Regions
- type Threshold
- type Thresholds
Constants ¶
This section is empty.
Variables ¶
var EndpointMap map[string]string
EndpointMap Endpoint Data
var EndpointType = "regional"
EndpointType regional or central
Functions ¶
func GetEndpointMap ¶ added in v1.61.1779
GetEndpointMap Get Endpoint Data Map
func GetEndpointType ¶ added in v1.61.1779
func GetEndpointType() string
GetEndpointType Get Endpoint Type Value
func SetClientProperty ¶ added in v1.61.1779
SetClientProperty Set Property by Reflect
func SetEndpointDataToClient ¶ added in v1.61.1779
func SetEndpointDataToClient(client *Client)
SetEndpointDataToClient Set EndpointMap and ENdpointType
Types ¶
type CapUrl ¶
type CapUrl struct {
Url string `json:"Url" xml:"Url"`
}
CapUrl is a nested struct in antiddos_public response
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) DescribeBgpPackByIp ¶
func (client *Client) DescribeBgpPackByIp(request *DescribeBgpPackByIpRequest) (response *DescribeBgpPackByIpResponse, err error)
DescribeBgpPackByIp invokes the antiddos_public.DescribeBgpPackByIp API synchronously
func (*Client) DescribeBgpPackByIpWithCallback ¶
func (client *Client) DescribeBgpPackByIpWithCallback(request *DescribeBgpPackByIpRequest, callback func(response *DescribeBgpPackByIpResponse, err error)) <-chan int
DescribeBgpPackByIpWithCallback invokes the antiddos_public.DescribeBgpPackByIp API asynchronously
func (*Client) DescribeBgpPackByIpWithChan ¶
func (client *Client) DescribeBgpPackByIpWithChan(request *DescribeBgpPackByIpRequest) (<-chan *DescribeBgpPackByIpResponse, <-chan error)
DescribeBgpPackByIpWithChan invokes the antiddos_public.DescribeBgpPackByIp API asynchronously
func (*Client) DescribeCap ¶
func (client *Client) DescribeCap(request *DescribeCapRequest) (response *DescribeCapResponse, err error)
DescribeCap invokes the antiddos_public.DescribeCap API synchronously
func (*Client) DescribeCapWithCallback ¶
func (client *Client) DescribeCapWithCallback(request *DescribeCapRequest, callback func(response *DescribeCapResponse, err error)) <-chan int
DescribeCapWithCallback invokes the antiddos_public.DescribeCap API asynchronously
func (*Client) DescribeCapWithChan ¶
func (client *Client) DescribeCapWithChan(request *DescribeCapRequest) (<-chan *DescribeCapResponse, <-chan error)
DescribeCapWithChan invokes the antiddos_public.DescribeCap API asynchronously
func (*Client) DescribeDdosCount ¶
func (client *Client) DescribeDdosCount(request *DescribeDdosCountRequest) (response *DescribeDdosCountResponse, err error)
DescribeDdosCount invokes the antiddos_public.DescribeDdosCount API synchronously
func (*Client) DescribeDdosCountWithCallback ¶
func (client *Client) DescribeDdosCountWithCallback(request *DescribeDdosCountRequest, callback func(response *DescribeDdosCountResponse, err error)) <-chan int
DescribeDdosCountWithCallback invokes the antiddos_public.DescribeDdosCount API asynchronously
func (*Client) DescribeDdosCountWithChan ¶
func (client *Client) DescribeDdosCountWithChan(request *DescribeDdosCountRequest) (<-chan *DescribeDdosCountResponse, <-chan error)
DescribeDdosCountWithChan invokes the antiddos_public.DescribeDdosCount API asynchronously
func (*Client) DescribeDdosCredit ¶
func (client *Client) DescribeDdosCredit(request *DescribeDdosCreditRequest) (response *DescribeDdosCreditResponse, err error)
DescribeDdosCredit invokes the antiddos_public.DescribeDdosCredit API synchronously
func (*Client) DescribeDdosCreditWithCallback ¶
func (client *Client) DescribeDdosCreditWithCallback(request *DescribeDdosCreditRequest, callback func(response *DescribeDdosCreditResponse, err error)) <-chan int
DescribeDdosCreditWithCallback invokes the antiddos_public.DescribeDdosCredit API asynchronously
func (*Client) DescribeDdosCreditWithChan ¶
func (client *Client) DescribeDdosCreditWithChan(request *DescribeDdosCreditRequest) (<-chan *DescribeDdosCreditResponse, <-chan error)
DescribeDdosCreditWithChan invokes the antiddos_public.DescribeDdosCredit API asynchronously
func (*Client) DescribeDdosEventList ¶
func (client *Client) DescribeDdosEventList(request *DescribeDdosEventListRequest) (response *DescribeDdosEventListResponse, err error)
DescribeDdosEventList invokes the antiddos_public.DescribeDdosEventList API synchronously
func (*Client) DescribeDdosEventListWithCallback ¶
func (client *Client) DescribeDdosEventListWithCallback(request *DescribeDdosEventListRequest, callback func(response *DescribeDdosEventListResponse, err error)) <-chan int
DescribeDdosEventListWithCallback invokes the antiddos_public.DescribeDdosEventList API asynchronously
func (*Client) DescribeDdosEventListWithChan ¶
func (client *Client) DescribeDdosEventListWithChan(request *DescribeDdosEventListRequest) (<-chan *DescribeDdosEventListResponse, <-chan error)
DescribeDdosEventListWithChan invokes the antiddos_public.DescribeDdosEventList API asynchronously
func (*Client) DescribeDdosThreshold ¶
func (client *Client) DescribeDdosThreshold(request *DescribeDdosThresholdRequest) (response *DescribeDdosThresholdResponse, err error)
DescribeDdosThreshold invokes the antiddos_public.DescribeDdosThreshold API synchronously
func (*Client) DescribeDdosThresholdWithCallback ¶
func (client *Client) DescribeDdosThresholdWithCallback(request *DescribeDdosThresholdRequest, callback func(response *DescribeDdosThresholdResponse, err error)) <-chan int
DescribeDdosThresholdWithCallback invokes the antiddos_public.DescribeDdosThreshold API asynchronously
func (*Client) DescribeDdosThresholdWithChan ¶
func (client *Client) DescribeDdosThresholdWithChan(request *DescribeDdosThresholdRequest) (<-chan *DescribeDdosThresholdResponse, <-chan error)
DescribeDdosThresholdWithChan invokes the antiddos_public.DescribeDdosThreshold API asynchronously
func (*Client) DescribeInstance ¶
func (client *Client) DescribeInstance(request *DescribeInstanceRequest) (response *DescribeInstanceResponse, err error)
DescribeInstance invokes the antiddos_public.DescribeInstance API synchronously
func (*Client) DescribeInstanceIpAddress ¶
func (client *Client) DescribeInstanceIpAddress(request *DescribeInstanceIpAddressRequest) (response *DescribeInstanceIpAddressResponse, err error)
DescribeInstanceIpAddress invokes the antiddos_public.DescribeInstanceIpAddress API synchronously
func (*Client) DescribeInstanceIpAddressWithCallback ¶
func (client *Client) DescribeInstanceIpAddressWithCallback(request *DescribeInstanceIpAddressRequest, callback func(response *DescribeInstanceIpAddressResponse, err error)) <-chan int
DescribeInstanceIpAddressWithCallback invokes the antiddos_public.DescribeInstanceIpAddress API asynchronously
func (*Client) DescribeInstanceIpAddressWithChan ¶
func (client *Client) DescribeInstanceIpAddressWithChan(request *DescribeInstanceIpAddressRequest) (<-chan *DescribeInstanceIpAddressResponse, <-chan error)
DescribeInstanceIpAddressWithChan invokes the antiddos_public.DescribeInstanceIpAddress API asynchronously
func (*Client) DescribeInstanceWithCallback ¶
func (client *Client) DescribeInstanceWithCallback(request *DescribeInstanceRequest, callback func(response *DescribeInstanceResponse, err error)) <-chan int
DescribeInstanceWithCallback invokes the antiddos_public.DescribeInstance API asynchronously
func (*Client) DescribeInstanceWithChan ¶
func (client *Client) DescribeInstanceWithChan(request *DescribeInstanceRequest) (<-chan *DescribeInstanceResponse, <-chan error)
DescribeInstanceWithChan invokes the antiddos_public.DescribeInstance API asynchronously
func (*Client) DescribeIpDdosThreshold ¶
func (client *Client) DescribeIpDdosThreshold(request *DescribeIpDdosThresholdRequest) (response *DescribeIpDdosThresholdResponse, err error)
DescribeIpDdosThreshold invokes the antiddos_public.DescribeIpDdosThreshold API synchronously
func (*Client) DescribeIpDdosThresholdWithCallback ¶
func (client *Client) DescribeIpDdosThresholdWithCallback(request *DescribeIpDdosThresholdRequest, callback func(response *DescribeIpDdosThresholdResponse, err error)) <-chan int
DescribeIpDdosThresholdWithCallback invokes the antiddos_public.DescribeIpDdosThreshold API asynchronously
func (*Client) DescribeIpDdosThresholdWithChan ¶
func (client *Client) DescribeIpDdosThresholdWithChan(request *DescribeIpDdosThresholdRequest) (<-chan *DescribeIpDdosThresholdResponse, <-chan error)
DescribeIpDdosThresholdWithChan invokes the antiddos_public.DescribeIpDdosThreshold API asynchronously
func (*Client) DescribeIpLocationService ¶
func (client *Client) DescribeIpLocationService(request *DescribeIpLocationServiceRequest) (response *DescribeIpLocationServiceResponse, err error)
DescribeIpLocationService invokes the antiddos_public.DescribeIpLocationService API synchronously
func (*Client) DescribeIpLocationServiceWithCallback ¶
func (client *Client) DescribeIpLocationServiceWithCallback(request *DescribeIpLocationServiceRequest, callback func(response *DescribeIpLocationServiceResponse, err error)) <-chan int
DescribeIpLocationServiceWithCallback invokes the antiddos_public.DescribeIpLocationService API asynchronously
func (*Client) DescribeIpLocationServiceWithChan ¶
func (client *Client) DescribeIpLocationServiceWithChan(request *DescribeIpLocationServiceRequest) (<-chan *DescribeIpLocationServiceResponse, <-chan error)
DescribeIpLocationServiceWithChan invokes the antiddos_public.DescribeIpLocationService API asynchronously
func (*Client) DescribeRegions ¶
func (client *Client) DescribeRegions(request *DescribeRegionsRequest) (response *DescribeRegionsResponse, err error)
DescribeRegions invokes the antiddos_public.DescribeRegions API synchronously
func (*Client) DescribeRegionsWithCallback ¶
func (client *Client) DescribeRegionsWithCallback(request *DescribeRegionsRequest, callback func(response *DescribeRegionsResponse, err error)) <-chan int
DescribeRegionsWithCallback invokes the antiddos_public.DescribeRegions API asynchronously
func (*Client) DescribeRegionsWithChan ¶
func (client *Client) DescribeRegionsWithChan(request *DescribeRegionsRequest) (<-chan *DescribeRegionsResponse, <-chan error)
DescribeRegionsWithChan invokes the antiddos_public.DescribeRegions API asynchronously
func (*Client) ModifyDdosStatus ¶
func (client *Client) ModifyDdosStatus(request *ModifyDdosStatusRequest) (response *ModifyDdosStatusResponse, err error)
ModifyDdosStatus invokes the antiddos_public.ModifyDdosStatus API synchronously
func (*Client) ModifyDdosStatusWithCallback ¶
func (client *Client) ModifyDdosStatusWithCallback(request *ModifyDdosStatusRequest, callback func(response *ModifyDdosStatusResponse, err error)) <-chan int
ModifyDdosStatusWithCallback invokes the antiddos_public.ModifyDdosStatus API asynchronously
func (*Client) ModifyDdosStatusWithChan ¶
func (client *Client) ModifyDdosStatusWithChan(request *ModifyDdosStatusRequest) (<-chan *ModifyDdosStatusResponse, <-chan error)
ModifyDdosStatusWithChan invokes the antiddos_public.ModifyDdosStatus API asynchronously
func (*Client) ModifyDefenseThreshold ¶
func (client *Client) ModifyDefenseThreshold(request *ModifyDefenseThresholdRequest) (response *ModifyDefenseThresholdResponse, err error)
ModifyDefenseThreshold invokes the antiddos_public.ModifyDefenseThreshold API synchronously
func (*Client) ModifyDefenseThresholdWithCallback ¶
func (client *Client) ModifyDefenseThresholdWithCallback(request *ModifyDefenseThresholdRequest, callback func(response *ModifyDefenseThresholdResponse, err error)) <-chan int
ModifyDefenseThresholdWithCallback invokes the antiddos_public.ModifyDefenseThreshold API asynchronously
func (*Client) ModifyDefenseThresholdWithChan ¶
func (client *Client) ModifyDefenseThresholdWithChan(request *ModifyDefenseThresholdRequest) (<-chan *ModifyDefenseThresholdResponse, <-chan error)
ModifyDefenseThresholdWithChan invokes the antiddos_public.ModifyDefenseThreshold API asynchronously
func (*Client) ModifyIpDefenseThreshold ¶ added in v1.61.1778
func (client *Client) ModifyIpDefenseThreshold(request *ModifyIpDefenseThresholdRequest) (response *ModifyIpDefenseThresholdResponse, err error)
ModifyIpDefenseThreshold invokes the antiddos_public.ModifyIpDefenseThreshold API synchronously
func (*Client) ModifyIpDefenseThresholdWithCallback ¶ added in v1.61.1778
func (client *Client) ModifyIpDefenseThresholdWithCallback(request *ModifyIpDefenseThresholdRequest, callback func(response *ModifyIpDefenseThresholdResponse, err error)) <-chan int
ModifyIpDefenseThresholdWithCallback invokes the antiddos_public.ModifyIpDefenseThreshold API asynchronously
func (*Client) ModifyIpDefenseThresholdWithChan ¶ added in v1.61.1778
func (client *Client) ModifyIpDefenseThresholdWithChan(request *ModifyIpDefenseThresholdRequest) (<-chan *ModifyIpDefenseThresholdResponse, <-chan error)
ModifyIpDefenseThresholdWithChan invokes the antiddos_public.ModifyIpDefenseThreshold API asynchronously
type DdosCount ¶
type DdosCount struct {
BlackholeCount int `json:"BlackholeCount" xml:"BlackholeCount"`
InstacenCount int `json:"InstacenCount" xml:"InstacenCount"`
DefenseCount int `json:"DefenseCount" xml:"DefenseCount"`
}
DdosCount is a nested struct in antiddos_public response
type DdosCredit ¶
type DdosCredit struct {
Score int `json:"Score" xml:"Score"`
ScoreLevel string `json:"ScoreLevel" xml:"ScoreLevel"`
BlackholeTime int `json:"BlackholeTime" xml:"BlackholeTime"`
}
DdosCredit is a nested struct in antiddos_public response
type DdosEvent ¶
type DdosEvent struct {
DdosType string `json:"DdosType" xml:"DdosType"`
EndTime int64 `json:"EndTime" xml:"EndTime"`
StartTime int64 `json:"StartTime" xml:"StartTime"`
DelayTime int64 `json:"DelayTime" xml:"DelayTime"`
DdosStatus string `json:"DdosStatus" xml:"DdosStatus"`
UnBlackholeTime int64 `json:"UnBlackholeTime" xml:"UnBlackholeTime"`
}
DdosEvent is a nested struct in antiddos_public response
type DdosEventList ¶
type DdosEventList struct {
DdosEvent []DdosEvent `json:"DdosEvent" xml:"DdosEvent"`
}
DdosEventList is a nested struct in antiddos_public response
type DdosbgpInfo ¶
type DdosbgpInfo struct {
Ip string `json:"Ip" xml:"Ip"`
ExpireTime int64 `json:"ExpireTime" xml:"ExpireTime"`
ElasticThreshold int `json:"ElasticThreshold" xml:"ElasticThreshold"`
BaseThreshold int `json:"BaseThreshold" xml:"BaseThreshold"`
DdosbgpInstanceId string `json:"DdosbgpInstanceId" xml:"DdosbgpInstanceId"`
}
DdosbgpInfo is a nested struct in antiddos_public response
type DescribeBgpPackByIpRequest ¶
type DescribeBgpPackByIpRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
Lang string `position:"Query" name:"Lang"`
Ip string `position:"Query" name:"Ip"`
}
DescribeBgpPackByIpRequest is the request struct for api DescribeBgpPackByIp
func CreateDescribeBgpPackByIpRequest ¶
func CreateDescribeBgpPackByIpRequest() (request *DescribeBgpPackByIpRequest)
CreateDescribeBgpPackByIpRequest creates a request to invoke DescribeBgpPackByIp API
type DescribeBgpPackByIpResponse ¶
type DescribeBgpPackByIpResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code int `json:"Code" xml:"Code"`
Success bool `json:"Success" xml:"Success"`
DdosbgpInfo DdosbgpInfo `json:"DdosbgpInfo" xml:"DdosbgpInfo"`
}
DescribeBgpPackByIpResponse is the response struct for api DescribeBgpPackByIp
func CreateDescribeBgpPackByIpResponse ¶
func CreateDescribeBgpPackByIpResponse() (response *DescribeBgpPackByIpResponse)
CreateDescribeBgpPackByIpResponse creates a response to parse from DescribeBgpPackByIp response
type DescribeCapRequest ¶
type DescribeCapRequest struct {
*requests.RpcRequest
InternetIp string `position:"Query" name:"InternetIp"`
BegTime requests.Integer `position:"Query" name:"BegTime"`
SourceIp string `position:"Query" name:"SourceIp"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
InstanceId string `position:"Query" name:"InstanceId"`
}
DescribeCapRequest is the request struct for api DescribeCap
func CreateDescribeCapRequest ¶
func CreateDescribeCapRequest() (request *DescribeCapRequest)
CreateDescribeCapRequest creates a request to invoke DescribeCap API
type DescribeCapResponse ¶
type DescribeCapResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
CapUrl CapUrl `json:"CapUrl" xml:"CapUrl"`
}
DescribeCapResponse is the response struct for api DescribeCap
func CreateDescribeCapResponse ¶
func CreateDescribeCapResponse() (response *DescribeCapResponse)
CreateDescribeCapResponse creates a response to parse from DescribeCap response
type DescribeDdosCountRequest ¶
type DescribeDdosCountRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
}
DescribeDdosCountRequest is the request struct for api DescribeDdosCount
func CreateDescribeDdosCountRequest ¶
func CreateDescribeDdosCountRequest() (request *DescribeDdosCountRequest)
CreateDescribeDdosCountRequest creates a request to invoke DescribeDdosCount API
type DescribeDdosCountResponse ¶
type DescribeDdosCountResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
DdosCount DdosCount `json:"DdosCount" xml:"DdosCount"`
}
DescribeDdosCountResponse is the response struct for api DescribeDdosCount
func CreateDescribeDdosCountResponse ¶
func CreateDescribeDdosCountResponse() (response *DescribeDdosCountResponse)
CreateDescribeDdosCountResponse creates a response to parse from DescribeDdosCount response
type DescribeDdosCreditRequest ¶
type DescribeDdosCreditRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
Lang string `position:"Query" name:"Lang"`
}
DescribeDdosCreditRequest is the request struct for api DescribeDdosCredit
func CreateDescribeDdosCreditRequest ¶
func CreateDescribeDdosCreditRequest() (request *DescribeDdosCreditRequest)
CreateDescribeDdosCreditRequest creates a request to invoke DescribeDdosCredit API
type DescribeDdosCreditResponse ¶
type DescribeDdosCreditResponse struct {
*responses.BaseResponse
Success bool `json:"Success" xml:"Success"`
RequestId string `json:"RequestId" xml:"RequestId"`
DdosCredit DdosCredit `json:"DdosCredit" xml:"DdosCredit"`
}
DescribeDdosCreditResponse is the response struct for api DescribeDdosCredit
func CreateDescribeDdosCreditResponse ¶
func CreateDescribeDdosCreditResponse() (response *DescribeDdosCreditResponse)
CreateDescribeDdosCreditResponse creates a response to parse from DescribeDdosCredit response
type DescribeDdosEventListRequest ¶
type DescribeDdosEventListRequest struct {
*requests.RpcRequest
InternetIp string `position:"Query" name:"InternetIp"`
SourceIp string `position:"Query" name:"SourceIp"`
PageSize requests.Integer `position:"Query" name:"PageSize"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
CurrentPage requests.Integer `position:"Query" name:"CurrentPage"`
InstanceId string `position:"Query" name:"InstanceId"`
}
DescribeDdosEventListRequest is the request struct for api DescribeDdosEventList
func CreateDescribeDdosEventListRequest ¶
func CreateDescribeDdosEventListRequest() (request *DescribeDdosEventListRequest)
CreateDescribeDdosEventListRequest creates a request to invoke DescribeDdosEventList API
type DescribeDdosEventListResponse ¶
type DescribeDdosEventListResponse struct {
*responses.BaseResponse
Total int `json:"Total" xml:"Total"`
RequestId string `json:"RequestId" xml:"RequestId"`
DdosEventList DdosEventList `json:"DdosEventList" xml:"DdosEventList"`
}
DescribeDdosEventListResponse is the response struct for api DescribeDdosEventList
func CreateDescribeDdosEventListResponse ¶
func CreateDescribeDdosEventListResponse() (response *DescribeDdosEventListResponse)
CreateDescribeDdosEventListResponse creates a response to parse from DescribeDdosEventList response
type DescribeDdosThresholdRequest ¶
type DescribeDdosThresholdRequest struct {
*requests.RpcRequest
DdosType string `position:"Query" name:"DdosType"`
SourceIp string `position:"Query" name:"SourceIp"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
InstanceIds *[]string `position:"Query" name:"InstanceIds" type:"Repeated"`
}
DescribeDdosThresholdRequest is the request struct for api DescribeDdosThreshold
func CreateDescribeDdosThresholdRequest ¶
func CreateDescribeDdosThresholdRequest() (request *DescribeDdosThresholdRequest)
CreateDescribeDdosThresholdRequest creates a request to invoke DescribeDdosThreshold API
type DescribeDdosThresholdResponse ¶
type DescribeDdosThresholdResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Thresholds Thresholds `json:"Thresholds" xml:"Thresholds"`
}
DescribeDdosThresholdResponse is the response struct for api DescribeDdosThreshold
func CreateDescribeDdosThresholdResponse ¶
func CreateDescribeDdosThresholdResponse() (response *DescribeDdosThresholdResponse)
CreateDescribeDdosThresholdResponse creates a response to parse from DescribeDdosThreshold response
type DescribeInstanceIpAddressRequest ¶
type DescribeInstanceIpAddressRequest struct {
*requests.RpcRequest
EagleEyeRpcId string `position:"Body" name:"EagleEyeRpcId"`
SourceIp string `position:"Query" name:"SourceIp"`
EagleEyeTraceId string `position:"Body" name:"EagleEyeTraceId"`
PageSize requests.Integer `position:"Query" name:"PageSize"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
DdosStatus string `position:"Query" name:"DdosStatus"`
CurrentPage requests.Integer `position:"Query" name:"CurrentPage"`
InstanceName string `position:"Query" name:"InstanceName"`
InstanceId string `position:"Query" name:"InstanceId"`
EagleEyeUserData string `position:"Body" name:"EagleEyeUserData"`
InstanceIp string `position:"Query" name:"InstanceIp"`
}
DescribeInstanceIpAddressRequest is the request struct for api DescribeInstanceIpAddress
func CreateDescribeInstanceIpAddressRequest ¶
func CreateDescribeInstanceIpAddressRequest() (request *DescribeInstanceIpAddressRequest)
CreateDescribeInstanceIpAddressRequest creates a request to invoke DescribeInstanceIpAddress API
type DescribeInstanceIpAddressResponse ¶
type DescribeInstanceIpAddressResponse struct {
*responses.BaseResponse
Total int `json:"Total" xml:"Total"`
RequestId string `json:"RequestId" xml:"RequestId"`
InstanceList []Instance `json:"InstanceList" xml:"InstanceList"`
}
DescribeInstanceIpAddressResponse is the response struct for api DescribeInstanceIpAddress
func CreateDescribeInstanceIpAddressResponse ¶
func CreateDescribeInstanceIpAddressResponse() (response *DescribeInstanceIpAddressResponse)
CreateDescribeInstanceIpAddressResponse creates a response to parse from DescribeInstanceIpAddress response
type DescribeInstanceRequest ¶
type DescribeInstanceRequest struct {
*requests.RpcRequest
EagleEyeRpcId string `position:"Body" name:"eagleEyeRpcId"`
SourceIp string `position:"Query" name:"SourceIp"`
EagleEyeTraceId string `position:"Body" name:"eagleEyeTraceId"`
PageSize requests.Integer `position:"Query" name:"PageSize"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
DdosStatus string `position:"Query" name:"DdosStatus"`
CurrentPage requests.Integer `position:"Query" name:"CurrentPage"`
InstanceName string `position:"Query" name:"InstanceName"`
InstanceId string `position:"Query" name:"InstanceId"`
EagleEyeUserData string `position:"Body" name:"eagleEyeUserData"`
InstanceIp string `position:"Query" name:"InstanceIp"`
}
DescribeInstanceRequest is the request struct for api DescribeInstance
func CreateDescribeInstanceRequest ¶
func CreateDescribeInstanceRequest() (request *DescribeInstanceRequest)
CreateDescribeInstanceRequest creates a request to invoke DescribeInstance API
type DescribeInstanceResponse ¶
type DescribeInstanceResponse struct {
*responses.BaseResponse
Total int `json:"Total" xml:"Total"`
RequestId string `json:"RequestId" xml:"RequestId"`
InstanceList InstanceListInDescribeInstance `json:"InstanceList" xml:"InstanceList"`
}
DescribeInstanceResponse is the response struct for api DescribeInstance
func CreateDescribeInstanceResponse ¶
func CreateDescribeInstanceResponse() (response *DescribeInstanceResponse)
CreateDescribeInstanceResponse creates a response to parse from DescribeInstance response
type DescribeIpDdosThresholdRequest ¶
type DescribeIpDdosThresholdRequest struct {
*requests.RpcRequest
InternetIp string `position:"Query" name:"InternetIp"`
DdosType string `position:"Query" name:"DdosType"`
SourceIp string `position:"Query" name:"SourceIp"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
InstanceId string `position:"Query" name:"InstanceId"`
}
DescribeIpDdosThresholdRequest is the request struct for api DescribeIpDdosThreshold
func CreateDescribeIpDdosThresholdRequest ¶
func CreateDescribeIpDdosThresholdRequest() (request *DescribeIpDdosThresholdRequest)
CreateDescribeIpDdosThresholdRequest creates a request to invoke DescribeIpDdosThreshold API
type DescribeIpDdosThresholdResponse ¶
type DescribeIpDdosThresholdResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Threshold Threshold `json:"Threshold" xml:"Threshold"`
}
DescribeIpDdosThresholdResponse is the response struct for api DescribeIpDdosThreshold
func CreateDescribeIpDdosThresholdResponse ¶
func CreateDescribeIpDdosThresholdResponse() (response *DescribeIpDdosThresholdResponse)
CreateDescribeIpDdosThresholdResponse creates a response to parse from DescribeIpDdosThreshold response
type DescribeIpLocationServiceRequest ¶
type DescribeIpLocationServiceRequest struct {
*requests.RpcRequest
InternetIp string `position:"Query" name:"InternetIp"`
EagleEyeRpcId string `position:"Body" name:"EagleEyeRpcId"`
SourceIp string `position:"Query" name:"SourceIp"`
EagleEyeTraceId string `position:"Body" name:"EagleEyeTraceId"`
Lang string `position:"Query" name:"Lang"`
EagleEyeUserData string `position:"Body" name:"EagleEyeUserData"`
}
DescribeIpLocationServiceRequest is the request struct for api DescribeIpLocationService
func CreateDescribeIpLocationServiceRequest ¶
func CreateDescribeIpLocationServiceRequest() (request *DescribeIpLocationServiceRequest)
CreateDescribeIpLocationServiceRequest creates a request to invoke DescribeIpLocationService API
type DescribeIpLocationServiceResponse ¶
type DescribeIpLocationServiceResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Instance Instance `json:"Instance" xml:"Instance"`
}
DescribeIpLocationServiceResponse is the response struct for api DescribeIpLocationService
func CreateDescribeIpLocationServiceResponse ¶
func CreateDescribeIpLocationServiceResponse() (response *DescribeIpLocationServiceResponse)
CreateDescribeIpLocationServiceResponse creates a response to parse from DescribeIpLocationService response
type DescribeRegionsRequest ¶
type DescribeRegionsRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
Lang string `position:"Query" name:"Lang"`
}
DescribeRegionsRequest is the request struct for api DescribeRegions
func CreateDescribeRegionsRequest ¶
func CreateDescribeRegionsRequest() (request *DescribeRegionsRequest)
CreateDescribeRegionsRequest creates a request to invoke DescribeRegions API
type DescribeRegionsResponse ¶
type DescribeRegionsResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Regions Regions `json:"Regions" xml:"Regions"`
}
DescribeRegionsResponse is the response struct for api DescribeRegions
func CreateDescribeRegionsResponse ¶
func CreateDescribeRegionsResponse() (response *DescribeRegionsResponse)
CreateDescribeRegionsResponse creates a response to parse from DescribeRegions response
type Instance ¶
type Instance struct {
Region string `json:"Region" xml:"Region"`
InternetIp string `json:"InternetIp" xml:"InternetIp"`
ElasticThreshold int `json:"ElasticThreshold" xml:"ElasticThreshold"`
InstanceName string `json:"InstanceName" xml:"InstanceName"`
IsBgppack bool `json:"IsBgppack" xml:"IsBgppack"`
InstanceType string `json:"InstanceType" xml:"InstanceType"`
DefensePpsThreshold int `json:"DefensePpsThreshold" xml:"DefensePpsThreshold"`
IpVersion string `json:"IpVersion" xml:"IpVersion"`
BlackholeThreshold int `json:"BlackholeThreshold" xml:"BlackholeThreshold"`
InstanceId string `json:"InstanceId" xml:"InstanceId"`
InstanceStatus string `json:"InstanceStatus" xml:"InstanceStatus"`
InstanceIp string `json:"InstanceIp" xml:"InstanceIp"`
DefenseBpsThreshold int `json:"DefenseBpsThreshold" xml:"DefenseBpsThreshold"`
IpAddressConfig []IpAddressConfigItem `json:"IpAddressConfig" xml:"IpAddressConfig"`
}
Instance is a nested struct in antiddos_public response
type InstanceListInDescribeInstance ¶
type InstanceListInDescribeInstance struct {
Instance []Instance `json:"Instance" xml:"Instance"`
}
InstanceListInDescribeInstance is a nested struct in antiddos_public response
type InstanceListInDescribeInstanceIpAddress ¶
type InstanceListInDescribeInstanceIpAddress struct {
Instance []Instance `json:"Instance" xml:"Instance"`
}
InstanceListInDescribeInstanceIpAddress is a nested struct in antiddos_public response
type IpAddressConfig ¶
type IpAddressConfig struct {
IpAddressConfigItem []IpAddressConfigItem `json:"IpAddressConfig" xml:"IpAddressConfig"`
}
IpAddressConfig is a nested struct in antiddos_public response
type IpAddressConfigItem ¶
type IpAddressConfigItem struct {
InstanceIp string `json:"InstanceIp" xml:"InstanceIp"`
IsBgppack bool `json:"IsBgppack" xml:"IsBgppack"`
IpVersion string `json:"IpVersion" xml:"IpVersion"`
IpStatus string `json:"IpStatus" xml:"IpStatus"`
RegionId string `json:"RegionId" xml:"RegionId"`
ElasticThreshold int `json:"ElasticThreshold" xml:"ElasticThreshold"`
BlackholeThreshold int `json:"BlackholeThreshold" xml:"BlackholeThreshold"`
DefenseBpsThreshold int `json:"DefenseBpsThreshold" xml:"DefenseBpsThreshold"`
DefensePpsThreshold int `json:"DefensePpsThreshold" xml:"DefensePpsThreshold"`
}
IpAddressConfigItem is a nested struct in antiddos_public response
type ModifyDdosStatusRequest ¶
type ModifyDdosStatusRequest struct {
*requests.RpcRequest
InternetIp string `position:"Query" name:"InternetIp"`
SourceIp string `position:"Query" name:"SourceIp"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
InstanceId string `position:"Query" name:"InstanceId"`
}
ModifyDdosStatusRequest is the request struct for api ModifyDdosStatus
func CreateModifyDdosStatusRequest ¶
func CreateModifyDdosStatusRequest() (request *ModifyDdosStatusRequest)
CreateModifyDdosStatusRequest creates a request to invoke ModifyDdosStatus API
type ModifyDdosStatusResponse ¶
type ModifyDdosStatusResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
}
ModifyDdosStatusResponse is the response struct for api ModifyDdosStatus
func CreateModifyDdosStatusResponse ¶
func CreateModifyDdosStatusResponse() (response *ModifyDdosStatusResponse)
CreateModifyDdosStatusResponse creates a response to parse from ModifyDdosStatus response
type ModifyDefenseThresholdRequest ¶
type ModifyDefenseThresholdRequest struct {
*requests.RpcRequest
InternetIp string `position:"Query" name:"InternetIp"`
SourceIp string `position:"Query" name:"SourceIp"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
Bps requests.Integer `position:"Query" name:"Bps"`
Pps requests.Integer `position:"Query" name:"Pps"`
InstanceId string `position:"Query" name:"InstanceId"`
IsAuto requests.Boolean `position:"Query" name:"IsAuto"`
}
ModifyDefenseThresholdRequest is the request struct for api ModifyDefenseThreshold
func CreateModifyDefenseThresholdRequest ¶
func CreateModifyDefenseThresholdRequest() (request *ModifyDefenseThresholdRequest)
CreateModifyDefenseThresholdRequest creates a request to invoke ModifyDefenseThreshold API
type ModifyDefenseThresholdResponse ¶
type ModifyDefenseThresholdResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
}
ModifyDefenseThresholdResponse is the response struct for api ModifyDefenseThreshold
func CreateModifyDefenseThresholdResponse ¶
func CreateModifyDefenseThresholdResponse() (response *ModifyDefenseThresholdResponse)
CreateModifyDefenseThresholdResponse creates a response to parse from ModifyDefenseThreshold response
type ModifyIpDefenseThresholdRequest ¶ added in v1.61.1778
type ModifyIpDefenseThresholdRequest struct {
*requests.RpcRequest
InternetIp string `position:"Query" name:"InternetIp"`
SourceIp string `position:"Query" name:"SourceIp"`
DdosRegionId string `position:"Query" name:"DdosRegionId"`
InstanceType string `position:"Query" name:"InstanceType"`
Lang string `position:"Query" name:"Lang"`
Bps requests.Integer `position:"Query" name:"Bps"`
Pps requests.Integer `position:"Query" name:"Pps"`
InstanceId string `position:"Query" name:"InstanceId"`
IsAuto requests.Boolean `position:"Query" name:"IsAuto"`
}
ModifyIpDefenseThresholdRequest is the request struct for api ModifyIpDefenseThreshold
func CreateModifyIpDefenseThresholdRequest ¶ added in v1.61.1778
func CreateModifyIpDefenseThresholdRequest() (request *ModifyIpDefenseThresholdRequest)
CreateModifyIpDefenseThresholdRequest creates a request to invoke ModifyIpDefenseThreshold API
type ModifyIpDefenseThresholdResponse ¶ added in v1.61.1778
type ModifyIpDefenseThresholdResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
}
ModifyIpDefenseThresholdResponse is the response struct for api ModifyIpDefenseThreshold
func CreateModifyIpDefenseThresholdResponse ¶ added in v1.61.1778
func CreateModifyIpDefenseThresholdResponse() (response *ModifyIpDefenseThresholdResponse)
CreateModifyIpDefenseThresholdResponse creates a response to parse from ModifyIpDefenseThreshold response
type Region ¶
type Region struct {
RegionEnName string `json:"RegionEnName" xml:"RegionEnName"`
RegionName string `json:"RegionName" xml:"RegionName"`
RegionNoAlias string `json:"RegionNoAlias" xml:"RegionNoAlias"`
RegionNo string `json:"RegionNo" xml:"RegionNo"`
}
Region is a nested struct in antiddos_public response
type Regions ¶
type Regions struct {
Region []Region `json:"Region" xml:"Region"`
}
Regions is a nested struct in antiddos_public response
type Threshold ¶
type Threshold struct {
Bps int `json:"Bps" xml:"Bps"`
InternetIp string `json:"InternetIp" xml:"InternetIp"`
InstanceId string `json:"InstanceId" xml:"InstanceId"`
DdosType string `json:"DdosType" xml:"DdosType"`
MaxBps int `json:"MaxBps" xml:"MaxBps"`
IsAuto bool `json:"IsAuto" xml:"IsAuto"`
ElasticBps int `json:"ElasticBps" xml:"ElasticBps"`
Pps int `json:"Pps" xml:"Pps"`
MaxPps int `json:"MaxPps" xml:"MaxPps"`
}
Threshold is a nested struct in antiddos_public response
type Thresholds ¶
type Thresholds struct {
Threshold []Threshold `json:"Threshold" xml:"Threshold"`
}
Thresholds is a nested struct in antiddos_public response
Source Files
¶
- client.go
- describe_bgp_pack_by_ip.go
- describe_cap.go
- describe_ddos_count.go
- describe_ddos_credit.go
- describe_ddos_event_list.go
- describe_ddos_threshold.go
- describe_instance.go
- describe_instance_ip_address.go
- describe_ip_ddos_threshold.go
- describe_ip_location_service.go
- describe_regions.go
- endpoint.go
- modify_ddos_status.go
- modify_defense_threshold.go
- modify_ip_defense_threshold.go
- struct_cap_url.go
- struct_ddos_count.go
- struct_ddos_credit.go
- struct_ddos_event.go
- struct_ddos_event_list.go
- struct_ddosbgp_info.go
- struct_instance.go
- struct_instance_list_in_describe_instance.go
- struct_instance_list_in_describe_instance_ip_address.go
- struct_ip_address_config.go
- struct_ip_address_config_item.go
- struct_region.go
- struct_regions.go
- struct_threshold.go
- struct_thresholds.go