Documentation
¶
Index ¶
- Variables
- func GetEndpointMap() map[string]string
- func GetEndpointType() string
- func SetClientProperty(client *Client, propertyName string, propertyValue interface{})
- func SetEndpointDataToClient(client *Client)
- type BizMessages
- type BizMessagesItem
- type Cinemas
- type CinemasItem
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) GetMessages(request *GetMessagesRequest) (response *GetMessagesResponse, err error)
- func (client *Client) GetMessagesWithCallback(request *GetMessagesRequest, ...) <-chan int
- func (client *Client) GetMessagesWithChan(request *GetMessagesRequest) (<-chan *GetMessagesResponse, <-chan error)
- func (client *Client) RemoveMessages(request *RemoveMessagesRequest) (response *RemoveMessagesResponse, err error)
- func (client *Client) RemoveMessagesWithCallback(request *RemoveMessagesRequest, ...) <-chan int
- func (client *Client) RemoveMessagesWithChan(request *RemoveMessagesRequest) (<-chan *RemoveMessagesResponse, <-chan error)
- func (client *Client) TaobaoFilmGetCinemas(request *TaobaoFilmGetCinemasRequest) (response *TaobaoFilmGetCinemasResponse, err error)
- func (client *Client) TaobaoFilmGetCinemasWithCallback(request *TaobaoFilmGetCinemasRequest, ...) <-chan int
- func (client *Client) TaobaoFilmGetCinemasWithChan(request *TaobaoFilmGetCinemasRequest) (<-chan *TaobaoFilmGetCinemasResponse, <-chan error)
- func (client *Client) TaobaoFilmGetHotShows(request *TaobaoFilmGetHotShowsRequest) (response *TaobaoFilmGetHotShowsResponse, err error)
- func (client *Client) TaobaoFilmGetHotShowsWithCallback(request *TaobaoFilmGetHotShowsRequest, ...) <-chan int
- func (client *Client) TaobaoFilmGetHotShowsWithChan(request *TaobaoFilmGetHotShowsRequest) (<-chan *TaobaoFilmGetHotShowsResponse, <-chan error)
- func (client *Client) TaobaoFilmGetRegionList(request *TaobaoFilmGetRegionListRequest) (response *TaobaoFilmGetRegionListResponse, err error)
- func (client *Client) TaobaoFilmGetRegionListWithCallback(request *TaobaoFilmGetRegionListRequest, ...) <-chan int
- func (client *Client) TaobaoFilmGetRegionListWithChan(request *TaobaoFilmGetRegionListRequest) (<-chan *TaobaoFilmGetRegionListResponse, <-chan error)
- func (client *Client) TaobaoFilmGetSchedules(request *TaobaoFilmGetSchedulesRequest) (response *TaobaoFilmGetSchedulesResponse, err error)
- func (client *Client) TaobaoFilmGetSchedulesWithCallback(request *TaobaoFilmGetSchedulesRequest, ...) <-chan int
- func (client *Client) TaobaoFilmGetSchedulesWithChan(request *TaobaoFilmGetSchedulesRequest) (<-chan *TaobaoFilmGetSchedulesResponse, <-chan error)
- func (client *Client) TaobaoFilmGetSeats(request *TaobaoFilmGetSeatsRequest) (response *TaobaoFilmGetSeatsResponse, err error)
- func (client *Client) TaobaoFilmGetSeatsWithCallback(request *TaobaoFilmGetSeatsRequest, ...) <-chan int
- func (client *Client) TaobaoFilmGetSeatsWithChan(request *TaobaoFilmGetSeatsRequest) (<-chan *TaobaoFilmGetSeatsResponse, <-chan error)
- func (client *Client) TaobaoFilmGetShowComments(request *TaobaoFilmGetShowCommentsRequest) (response *TaobaoFilmGetShowCommentsResponse, err error)
- func (client *Client) TaobaoFilmGetShowCommentsWithCallback(request *TaobaoFilmGetShowCommentsRequest, ...) <-chan int
- func (client *Client) TaobaoFilmGetShowCommentsWithChan(request *TaobaoFilmGetShowCommentsRequest) (<-chan *TaobaoFilmGetShowCommentsResponse, <-chan error)
- func (client *Client) TaobaoFilmGetSoonShows(request *TaobaoFilmGetSoonShowsRequest) (response *TaobaoFilmGetSoonShowsResponse, err error)
- func (client *Client) TaobaoFilmGetSoonShowsWithCallback(request *TaobaoFilmGetSoonShowsRequest, ...) <-chan int
- func (client *Client) TaobaoFilmGetSoonShowsWithChan(request *TaobaoFilmGetSoonShowsRequest) (<-chan *TaobaoFilmGetSoonShowsResponse, <-chan error)
- func (client *Client) TaobaoFilmIssueOrder(request *TaobaoFilmIssueOrderRequest) (response *TaobaoFilmIssueOrderResponse, err error)
- func (client *Client) TaobaoFilmIssueOrderWithCallback(request *TaobaoFilmIssueOrderRequest, ...) <-chan int
- func (client *Client) TaobaoFilmIssueOrderWithChan(request *TaobaoFilmIssueOrderRequest) (<-chan *TaobaoFilmIssueOrderResponse, <-chan error)
- func (client *Client) TaobaoFilmLockSeat(request *TaobaoFilmLockSeatRequest) (response *TaobaoFilmLockSeatResponse, err error)
- func (client *Client) TaobaoFilmLockSeatWithCallback(request *TaobaoFilmLockSeatRequest, ...) <-chan int
- func (client *Client) TaobaoFilmLockSeatWithChan(request *TaobaoFilmLockSeatRequest) (<-chan *TaobaoFilmLockSeatResponse, <-chan error)
- func (client *Client) TaobaoFilmUnLockSeat(request *TaobaoFilmUnLockSeatRequest) (response *TaobaoFilmUnLockSeatResponse, err error)
- func (client *Client) TaobaoFilmUnLockSeatWithCallback(request *TaobaoFilmUnLockSeatRequest, ...) <-chan int
- func (client *Client) TaobaoFilmUnLockSeatWithChan(request *TaobaoFilmUnLockSeatRequest) (<-chan *TaobaoFilmUnLockSeatResponse, <-chan error)
- type CommentList
- type CommentListItem
- type GetMessagesRequest
- type GetMessagesResponse
- type Regions
- type RegionsItem
- type RemoveMessagesRequest
- type RemoveMessagesResponse
- type Schedules
- type SchedulesItem
- type SeatLocked
- type SeatMap
- type Seats
- type SeatsItem
- type ShowVersionListInTaobaoFilmGetHotShows
- type ShowVersionListInTaobaoFilmGetSoonShows
- type ShowsInTaobaoFilmGetHotShows
- type ShowsInTaobaoFilmGetSoonShows
- type ShowsItem
- type TaobaoFilmGetCinemasRequest
- type TaobaoFilmGetCinemasResponse
- type TaobaoFilmGetHotShowsRequest
- type TaobaoFilmGetHotShowsResponse
- type TaobaoFilmGetRegionListRequest
- type TaobaoFilmGetRegionListResponse
- type TaobaoFilmGetSchedulesRequest
- type TaobaoFilmGetSchedulesResponse
- type TaobaoFilmGetSeatsRequest
- type TaobaoFilmGetSeatsResponse
- type TaobaoFilmGetShowCommentsRequest
- type TaobaoFilmGetShowCommentsResponse
- type TaobaoFilmGetSoonShowsRequest
- type TaobaoFilmGetSoonShowsResponse
- type TaobaoFilmIssueOrderRequest
- type TaobaoFilmIssueOrderResponse
- type TaobaoFilmLockSeatRequest
- type TaobaoFilmLockSeatResponse
- type TaobaoFilmUnLockSeatRequest
- type TaobaoFilmUnLockSeatResponse
- type TrailerListInTaobaoFilmGetHotShows
- type TrailerListInTaobaoFilmGetSoonShows
Constants ¶
This section is empty.
Variables ¶
var EndpointMap map[string]string
EndpointMap Endpoint Data
var EndpointType = "regional"
EndpointType regional or central
Functions ¶
func SetClientProperty ¶
SetClientProperty Set Property by Reflect
func SetEndpointDataToClient ¶
func SetEndpointDataToClient(client *Client)
SetEndpointDataToClient Set EndpointMap and ENdpointType
Types ¶
type BizMessages ¶
type BizMessages struct {
BizMessagesItem []BizMessagesItem `json:"BizMessagesItem" xml:"BizMessagesItem"`
}
BizMessages is a nested struct in appmallsservice response
type BizMessagesItem ¶
type BizMessagesItem struct {
PubTime string `json:"PubTime" xml:"PubTime"`
Topic string `json:"Topic" xml:"Topic"`
DataId int64 `json:"DataId" xml:"DataId"`
ContentMapJson string `json:"ContentMapJson" xml:"ContentMapJson"`
}
BizMessagesItem is a nested struct in appmallsservice response
type Cinemas ¶
type Cinemas struct {
CinemasItem []CinemasItem `json:"CinemasItem" xml:"CinemasItem"`
}
Cinemas is a nested struct in appmallsservice response
type CinemasItem ¶
type CinemasItem struct {
Address string `json:"Address" xml:"Address"`
CinemaName string `json:"CinemaName" xml:"CinemaName"`
CityId int64 `json:"CityId" xml:"CityId"`
Id int64 `json:"Id" xml:"Id"`
Latitude string `json:"Latitude" xml:"Latitude"`
Longitude string `json:"Longitude" xml:"Longitude"`
Phone string `json:"Phone" xml:"Phone"`
RegionName string `json:"RegionName" xml:"RegionName"`
ScheduleCloseTime int64 `json:"ScheduleCloseTime" xml:"ScheduleCloseTime"`
StandardId string `json:"StandardId" xml:"StandardId"`
}
CinemasItem is a nested struct in appmallsservice response
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) GetMessages ¶
func (client *Client) GetMessages(request *GetMessagesRequest) (response *GetMessagesResponse, err error)
GetMessages invokes the appmallsservice.GetMessages API synchronously api document: https://help.aliyun.com/api/appmallsservice/getmessages.html
func (*Client) GetMessagesWithCallback ¶
func (client *Client) GetMessagesWithCallback(request *GetMessagesRequest, callback func(response *GetMessagesResponse, err error)) <-chan int
GetMessagesWithCallback invokes the appmallsservice.GetMessages API asynchronously api document: https://help.aliyun.com/api/appmallsservice/getmessages.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) GetMessagesWithChan ¶
func (client *Client) GetMessagesWithChan(request *GetMessagesRequest) (<-chan *GetMessagesResponse, <-chan error)
GetMessagesWithChan invokes the appmallsservice.GetMessages API asynchronously api document: https://help.aliyun.com/api/appmallsservice/getmessages.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) RemoveMessages ¶
func (client *Client) RemoveMessages(request *RemoveMessagesRequest) (response *RemoveMessagesResponse, err error)
RemoveMessages invokes the appmallsservice.RemoveMessages API synchronously api document: https://help.aliyun.com/api/appmallsservice/removemessages.html
func (*Client) RemoveMessagesWithCallback ¶
func (client *Client) RemoveMessagesWithCallback(request *RemoveMessagesRequest, callback func(response *RemoveMessagesResponse, err error)) <-chan int
RemoveMessagesWithCallback invokes the appmallsservice.RemoveMessages API asynchronously api document: https://help.aliyun.com/api/appmallsservice/removemessages.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) RemoveMessagesWithChan ¶
func (client *Client) RemoveMessagesWithChan(request *RemoveMessagesRequest) (<-chan *RemoveMessagesResponse, <-chan error)
RemoveMessagesWithChan invokes the appmallsservice.RemoveMessages API asynchronously api document: https://help.aliyun.com/api/appmallsservice/removemessages.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetCinemas ¶
func (client *Client) TaobaoFilmGetCinemas(request *TaobaoFilmGetCinemasRequest) (response *TaobaoFilmGetCinemasResponse, err error)
TaobaoFilmGetCinemas invokes the appmallsservice.TaobaoFilmGetCinemas API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetcinemas.html
func (*Client) TaobaoFilmGetCinemasWithCallback ¶
func (client *Client) TaobaoFilmGetCinemasWithCallback(request *TaobaoFilmGetCinemasRequest, callback func(response *TaobaoFilmGetCinemasResponse, err error)) <-chan int
TaobaoFilmGetCinemasWithCallback invokes the appmallsservice.TaobaoFilmGetCinemas API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetcinemas.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetCinemasWithChan ¶
func (client *Client) TaobaoFilmGetCinemasWithChan(request *TaobaoFilmGetCinemasRequest) (<-chan *TaobaoFilmGetCinemasResponse, <-chan error)
TaobaoFilmGetCinemasWithChan invokes the appmallsservice.TaobaoFilmGetCinemas API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetcinemas.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetHotShows ¶
func (client *Client) TaobaoFilmGetHotShows(request *TaobaoFilmGetHotShowsRequest) (response *TaobaoFilmGetHotShowsResponse, err error)
TaobaoFilmGetHotShows invokes the appmallsservice.TaobaoFilmGetHotShows API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgethotshows.html
func (*Client) TaobaoFilmGetHotShowsWithCallback ¶
func (client *Client) TaobaoFilmGetHotShowsWithCallback(request *TaobaoFilmGetHotShowsRequest, callback func(response *TaobaoFilmGetHotShowsResponse, err error)) <-chan int
TaobaoFilmGetHotShowsWithCallback invokes the appmallsservice.TaobaoFilmGetHotShows API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgethotshows.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetHotShowsWithChan ¶
func (client *Client) TaobaoFilmGetHotShowsWithChan(request *TaobaoFilmGetHotShowsRequest) (<-chan *TaobaoFilmGetHotShowsResponse, <-chan error)
TaobaoFilmGetHotShowsWithChan invokes the appmallsservice.TaobaoFilmGetHotShows API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgethotshows.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetRegionList ¶
func (client *Client) TaobaoFilmGetRegionList(request *TaobaoFilmGetRegionListRequest) (response *TaobaoFilmGetRegionListResponse, err error)
TaobaoFilmGetRegionList invokes the appmallsservice.TaobaoFilmGetRegionList API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetregionlist.html
func (*Client) TaobaoFilmGetRegionListWithCallback ¶
func (client *Client) TaobaoFilmGetRegionListWithCallback(request *TaobaoFilmGetRegionListRequest, callback func(response *TaobaoFilmGetRegionListResponse, err error)) <-chan int
TaobaoFilmGetRegionListWithCallback invokes the appmallsservice.TaobaoFilmGetRegionList API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetregionlist.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetRegionListWithChan ¶
func (client *Client) TaobaoFilmGetRegionListWithChan(request *TaobaoFilmGetRegionListRequest) (<-chan *TaobaoFilmGetRegionListResponse, <-chan error)
TaobaoFilmGetRegionListWithChan invokes the appmallsservice.TaobaoFilmGetRegionList API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetregionlist.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetSchedules ¶
func (client *Client) TaobaoFilmGetSchedules(request *TaobaoFilmGetSchedulesRequest) (response *TaobaoFilmGetSchedulesResponse, err error)
TaobaoFilmGetSchedules invokes the appmallsservice.TaobaoFilmGetSchedules API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetschedules.html
func (*Client) TaobaoFilmGetSchedulesWithCallback ¶
func (client *Client) TaobaoFilmGetSchedulesWithCallback(request *TaobaoFilmGetSchedulesRequest, callback func(response *TaobaoFilmGetSchedulesResponse, err error)) <-chan int
TaobaoFilmGetSchedulesWithCallback invokes the appmallsservice.TaobaoFilmGetSchedules API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetschedules.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetSchedulesWithChan ¶
func (client *Client) TaobaoFilmGetSchedulesWithChan(request *TaobaoFilmGetSchedulesRequest) (<-chan *TaobaoFilmGetSchedulesResponse, <-chan error)
TaobaoFilmGetSchedulesWithChan invokes the appmallsservice.TaobaoFilmGetSchedules API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetschedules.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetSeats ¶
func (client *Client) TaobaoFilmGetSeats(request *TaobaoFilmGetSeatsRequest) (response *TaobaoFilmGetSeatsResponse, err error)
TaobaoFilmGetSeats invokes the appmallsservice.TaobaoFilmGetSeats API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetseats.html
func (*Client) TaobaoFilmGetSeatsWithCallback ¶
func (client *Client) TaobaoFilmGetSeatsWithCallback(request *TaobaoFilmGetSeatsRequest, callback func(response *TaobaoFilmGetSeatsResponse, err error)) <-chan int
TaobaoFilmGetSeatsWithCallback invokes the appmallsservice.TaobaoFilmGetSeats API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetseats.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetSeatsWithChan ¶
func (client *Client) TaobaoFilmGetSeatsWithChan(request *TaobaoFilmGetSeatsRequest) (<-chan *TaobaoFilmGetSeatsResponse, <-chan error)
TaobaoFilmGetSeatsWithChan invokes the appmallsservice.TaobaoFilmGetSeats API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetseats.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetShowComments ¶
func (client *Client) TaobaoFilmGetShowComments(request *TaobaoFilmGetShowCommentsRequest) (response *TaobaoFilmGetShowCommentsResponse, err error)
TaobaoFilmGetShowComments invokes the appmallsservice.TaobaoFilmGetShowComments API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetshowcomments.html
func (*Client) TaobaoFilmGetShowCommentsWithCallback ¶
func (client *Client) TaobaoFilmGetShowCommentsWithCallback(request *TaobaoFilmGetShowCommentsRequest, callback func(response *TaobaoFilmGetShowCommentsResponse, err error)) <-chan int
TaobaoFilmGetShowCommentsWithCallback invokes the appmallsservice.TaobaoFilmGetShowComments API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetshowcomments.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetShowCommentsWithChan ¶
func (client *Client) TaobaoFilmGetShowCommentsWithChan(request *TaobaoFilmGetShowCommentsRequest) (<-chan *TaobaoFilmGetShowCommentsResponse, <-chan error)
TaobaoFilmGetShowCommentsWithChan invokes the appmallsservice.TaobaoFilmGetShowComments API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetshowcomments.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetSoonShows ¶
func (client *Client) TaobaoFilmGetSoonShows(request *TaobaoFilmGetSoonShowsRequest) (response *TaobaoFilmGetSoonShowsResponse, err error)
TaobaoFilmGetSoonShows invokes the appmallsservice.TaobaoFilmGetSoonShows API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetsoonshows.html
func (*Client) TaobaoFilmGetSoonShowsWithCallback ¶
func (client *Client) TaobaoFilmGetSoonShowsWithCallback(request *TaobaoFilmGetSoonShowsRequest, callback func(response *TaobaoFilmGetSoonShowsResponse, err error)) <-chan int
TaobaoFilmGetSoonShowsWithCallback invokes the appmallsservice.TaobaoFilmGetSoonShows API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetsoonshows.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmGetSoonShowsWithChan ¶
func (client *Client) TaobaoFilmGetSoonShowsWithChan(request *TaobaoFilmGetSoonShowsRequest) (<-chan *TaobaoFilmGetSoonShowsResponse, <-chan error)
TaobaoFilmGetSoonShowsWithChan invokes the appmallsservice.TaobaoFilmGetSoonShows API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmgetsoonshows.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmIssueOrder ¶
func (client *Client) TaobaoFilmIssueOrder(request *TaobaoFilmIssueOrderRequest) (response *TaobaoFilmIssueOrderResponse, err error)
TaobaoFilmIssueOrder invokes the appmallsservice.TaobaoFilmIssueOrder API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmissueorder.html
func (*Client) TaobaoFilmIssueOrderWithCallback ¶
func (client *Client) TaobaoFilmIssueOrderWithCallback(request *TaobaoFilmIssueOrderRequest, callback func(response *TaobaoFilmIssueOrderResponse, err error)) <-chan int
TaobaoFilmIssueOrderWithCallback invokes the appmallsservice.TaobaoFilmIssueOrder API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmissueorder.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmIssueOrderWithChan ¶
func (client *Client) TaobaoFilmIssueOrderWithChan(request *TaobaoFilmIssueOrderRequest) (<-chan *TaobaoFilmIssueOrderResponse, <-chan error)
TaobaoFilmIssueOrderWithChan invokes the appmallsservice.TaobaoFilmIssueOrder API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmissueorder.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmLockSeat ¶
func (client *Client) TaobaoFilmLockSeat(request *TaobaoFilmLockSeatRequest) (response *TaobaoFilmLockSeatResponse, err error)
TaobaoFilmLockSeat invokes the appmallsservice.TaobaoFilmLockSeat API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmlockseat.html
func (*Client) TaobaoFilmLockSeatWithCallback ¶
func (client *Client) TaobaoFilmLockSeatWithCallback(request *TaobaoFilmLockSeatRequest, callback func(response *TaobaoFilmLockSeatResponse, err error)) <-chan int
TaobaoFilmLockSeatWithCallback invokes the appmallsservice.TaobaoFilmLockSeat API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmlockseat.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmLockSeatWithChan ¶
func (client *Client) TaobaoFilmLockSeatWithChan(request *TaobaoFilmLockSeatRequest) (<-chan *TaobaoFilmLockSeatResponse, <-chan error)
TaobaoFilmLockSeatWithChan invokes the appmallsservice.TaobaoFilmLockSeat API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmlockseat.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmUnLockSeat ¶
func (client *Client) TaobaoFilmUnLockSeat(request *TaobaoFilmUnLockSeatRequest) (response *TaobaoFilmUnLockSeatResponse, err error)
TaobaoFilmUnLockSeat invokes the appmallsservice.TaobaoFilmUnLockSeat API synchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmunlockseat.html
func (*Client) TaobaoFilmUnLockSeatWithCallback ¶
func (client *Client) TaobaoFilmUnLockSeatWithCallback(request *TaobaoFilmUnLockSeatRequest, callback func(response *TaobaoFilmUnLockSeatResponse, err error)) <-chan int
TaobaoFilmUnLockSeatWithCallback invokes the appmallsservice.TaobaoFilmUnLockSeat API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmunlockseat.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) TaobaoFilmUnLockSeatWithChan ¶
func (client *Client) TaobaoFilmUnLockSeatWithChan(request *TaobaoFilmUnLockSeatRequest) (<-chan *TaobaoFilmUnLockSeatResponse, <-chan error)
TaobaoFilmUnLockSeatWithChan invokes the appmallsservice.TaobaoFilmUnLockSeat API asynchronously api document: https://help.aliyun.com/api/appmallsservice/taobaofilmunlockseat.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
type CommentList ¶
type CommentList struct {
CommentListItem []CommentListItem `json:"CommentListItem" xml:"CommentListItem"`
}
CommentList is a nested struct in appmallsservice response
type CommentListItem ¶
type CommentListItem struct {
CommentTime string `json:"CommentTime" xml:"CommentTime"`
Content string `json:"Content" xml:"Content"`
FavorCount int64 `json:"FavorCount" xml:"FavorCount"`
Id int64 `json:"Id" xml:"Id"`
NickName string `json:"NickName" xml:"NickName"`
Remark int64 `json:"Remark" xml:"Remark"`
ShowId int64 `json:"ShowId" xml:"ShowId"`
Subject string `json:"Subject" xml:"Subject"`
}
CommentListItem is a nested struct in appmallsservice response
type GetMessagesRequest ¶
type GetMessagesRequest struct {
*requests.RpcRequest
Topic string `position:"Query" name:"Topic"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
GetMessagesRequest is the request struct for api GetMessages
func CreateGetMessagesRequest ¶
func CreateGetMessagesRequest() (request *GetMessagesRequest)
CreateGetMessagesRequest creates a request to invoke GetMessages API
type GetMessagesResponse ¶
type GetMessagesResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
BizMessages []BizMessagesItem `json:"BizMessages" xml:"BizMessages"`
}
GetMessagesResponse is the response struct for api GetMessages
func CreateGetMessagesResponse ¶
func CreateGetMessagesResponse() (response *GetMessagesResponse)
CreateGetMessagesResponse creates a response to parse from GetMessages response
type Regions ¶
type Regions struct {
RegionsItem []RegionsItem `json:"RegionsItem" xml:"RegionsItem"`
}
Regions is a nested struct in appmallsservice response
type RegionsItem ¶
type RegionsItem struct {
CityCode int64 `json:"CityCode" xml:"CityCode"`
Id int64 `json:"Id" xml:"Id"`
ParentId int64 `json:"ParentId" xml:"ParentId"`
PinYin string `json:"PinYin" xml:"PinYin"`
RegionName string `json:"RegionName" xml:"RegionName"`
}
RegionsItem is a nested struct in appmallsservice response
type RemoveMessagesRequest ¶
type RemoveMessagesRequest struct {
*requests.RpcRequest
MsgIds string `position:"Query" name:"MsgIds"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
RemoveMessagesRequest is the request struct for api RemoveMessages
func CreateRemoveMessagesRequest ¶
func CreateRemoveMessagesRequest() (request *RemoveMessagesRequest)
CreateRemoveMessagesRequest creates a request to invoke RemoveMessages API
type RemoveMessagesResponse ¶
type RemoveMessagesResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
ReturnCode string `json:"ReturnCode" xml:"ReturnCode"`
ReturnMessage string `json:"ReturnMessage" xml:"ReturnMessage"`
ReturnValue string `json:"ReturnValue" xml:"ReturnValue"`
}
RemoveMessagesResponse is the response struct for api RemoveMessages
func CreateRemoveMessagesResponse ¶
func CreateRemoveMessagesResponse() (response *RemoveMessagesResponse)
CreateRemoveMessagesResponse creates a response to parse from RemoveMessages response
type Schedules ¶
type Schedules struct {
SchedulesItem []SchedulesItem `json:"SchedulesItem" xml:"SchedulesItem"`
}
Schedules is a nested struct in appmallsservice response
type SchedulesItem ¶
type SchedulesItem struct {
CinemaId int64 `json:"CinemaId" xml:"CinemaId"`
CloseTime string `json:"CloseTime" xml:"CloseTime"`
HallName string `json:"HallName" xml:"HallName"`
Id int64 `json:"Id" xml:"Id"`
IsExpired bool `json:"IsExpired" xml:"IsExpired"`
MaxCanBuy int64 `json:"MaxCanBuy" xml:"MaxCanBuy"`
Price int64 `json:"Price" xml:"Price"`
ScheduleArea string `json:"ScheduleArea" xml:"ScheduleArea"`
SectionId string `json:"SectionId" xml:"SectionId"`
ServiceFee int64 `json:"ServiceFee" xml:"ServiceFee"`
ShowDate string `json:"ShowDate" xml:"ShowDate"`
ShowId int64 `json:"ShowId" xml:"ShowId"`
ShowTime string `json:"ShowTime" xml:"ShowTime"`
ShowVersion string `json:"ShowVersion" xml:"ShowVersion"`
HallId string `json:"HallId" xml:"HallId"`
}
SchedulesItem is a nested struct in appmallsservice response
type SeatLocked ¶
type SeatLocked struct {
ApplyKey string `json:"ApplyKey" xml:"ApplyKey"`
DefaultLockSecond int64 `json:"DefaultLockSecond" xml:"DefaultLockSecond"`
LockTime int64 `json:"LockTime" xml:"LockTime"`
Status string `json:"Status" xml:"Status"`
}
SeatLocked is a nested struct in appmallsservice response
type SeatMap ¶
type SeatMap struct {
MaxCanBuy int64 `json:"MaxCanBuy" xml:"MaxCanBuy"`
MaxColumn int64 `json:"MaxColumn" xml:"MaxColumn"`
MaxLeftPx int64 `json:"MaxLeftPx" xml:"MaxLeftPx"`
MaxRow int64 `json:"MaxRow" xml:"MaxRow"`
MaxTopPx int64 `json:"MaxTopPx" xml:"MaxTopPx"`
MinColumn int64 `json:"MinColumn" xml:"MinColumn"`
MinLeftPx int64 `json:"MinLeftPx" xml:"MinLeftPx"`
MinRow int64 `json:"MinRow" xml:"MinRow"`
MinTopPx int64 `json:"MinTopPx" xml:"MinTopPx"`
Notice string `json:"Notice" xml:"Notice"`
Regular bool `json:"Regular" xml:"Regular"`
SeatCount int64 `json:"SeatCount" xml:"SeatCount"`
SoldCount int64 `json:"SoldCount" xml:"SoldCount"`
TipMessage string `json:"TipMessage" xml:"TipMessage"`
Seats []SeatsItem `json:"Seats" xml:"Seats"`
}
SeatMap is a nested struct in appmallsservice response
type Seats ¶
type Seats struct {
SeatsItem []SeatsItem `json:"SeatsItem" xml:"SeatsItem"`
}
Seats is a nested struct in appmallsservice response
type SeatsItem ¶
type SeatsItem struct {
Area string `json:"Area" xml:"Area"`
Column int64 `json:"Column" xml:"Column"`
ExtId string `json:"ExtId" xml:"ExtId"`
Flag int64 `json:"Flag" xml:"Flag"`
LeftPx int64 `json:"LeftPx" xml:"LeftPx"`
Name string `json:"Name" xml:"Name"`
Row int64 `json:"Row" xml:"Row"`
RowName string `json:"RowName" xml:"RowName"`
Status int64 `json:"Status" xml:"Status"`
TopPx int64 `json:"TopPx" xml:"TopPx"`
}
SeatsItem is a nested struct in appmallsservice response
type ShowVersionListInTaobaoFilmGetHotShows ¶
type ShowVersionListInTaobaoFilmGetHotShows struct {
ShowVersionList []string `json:"ShowVersionList" xml:"ShowVersionList"`
}
ShowVersionListInTaobaoFilmGetHotShows is a nested struct in appmallsservice response
type ShowVersionListInTaobaoFilmGetSoonShows ¶
type ShowVersionListInTaobaoFilmGetSoonShows struct {
ShowVersionList []string `json:"ShowVersionList" xml:"ShowVersionList"`
}
ShowVersionListInTaobaoFilmGetSoonShows is a nested struct in appmallsservice response
type ShowsInTaobaoFilmGetHotShows ¶
type ShowsInTaobaoFilmGetHotShows struct {
ShowsItem []ShowsItem `json:"ShowsItem" xml:"ShowsItem"`
}
ShowsInTaobaoFilmGetHotShows is a nested struct in appmallsservice response
type ShowsInTaobaoFilmGetSoonShows ¶
type ShowsInTaobaoFilmGetSoonShows struct {
ShowsItem []ShowsItem `json:"ShowsItem" xml:"ShowsItem"`
}
ShowsInTaobaoFilmGetSoonShows is a nested struct in appmallsservice response
type ShowsItem ¶
type ShowsItem struct {
Country string `json:"Country" xml:"Country"`
ShowName string `json:"ShowName" xml:"ShowName"`
Remark string `json:"Remark" xml:"Remark"`
Language string `json:"Language" xml:"Language"`
Id int64 `json:"Id" xml:"Id"`
BackgroundPicture string `json:"BackgroundPicture" xml:"BackgroundPicture"`
OpenTime string `json:"OpenTime" xml:"OpenTime"`
ShowNameEn string `json:"ShowNameEn" xml:"ShowNameEn"`
LeadingRole string `json:"LeadingRole" xml:"LeadingRole"`
Highlight string `json:"Highlight" xml:"Highlight"`
Description string `json:"Description" xml:"Description"`
Duration int64 `json:"Duration" xml:"Duration"`
OpenDay string `json:"OpenDay" xml:"OpenDay"`
ShowMark string `json:"ShowMark" xml:"ShowMark"`
Poster string `json:"Poster" xml:"Poster"`
Director string `json:"Director" xml:"Director"`
Type string `json:"Type" xml:"Type"`
TrailerList []string `json:"TrailerList" xml:"TrailerList"`
ShowVersionList []string `json:"ShowVersionList" xml:"ShowVersionList"`
}
ShowsItem is a nested struct in appmallsservice response
type TaobaoFilmGetCinemasRequest ¶
type TaobaoFilmGetCinemasRequest struct {
*requests.RpcRequest
PageIndex requests.Integer `position:"Query" name:"PageIndex"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmGetCinemasRequest is the request struct for api TaobaoFilmGetCinemas
func CreateTaobaoFilmGetCinemasRequest ¶
func CreateTaobaoFilmGetCinemasRequest() (request *TaobaoFilmGetCinemasRequest)
CreateTaobaoFilmGetCinemasRequest creates a request to invoke TaobaoFilmGetCinemas API
type TaobaoFilmGetCinemasResponse ¶
type TaobaoFilmGetCinemasResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
TotalCount int64 `json:"TotalCount" xml:"TotalCount"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
Cinemas []CinemasItem `json:"Cinemas" xml:"Cinemas"`
}
TaobaoFilmGetCinemasResponse is the response struct for api TaobaoFilmGetCinemas
func CreateTaobaoFilmGetCinemasResponse ¶
func CreateTaobaoFilmGetCinemasResponse() (response *TaobaoFilmGetCinemasResponse)
CreateTaobaoFilmGetCinemasResponse creates a response to parse from TaobaoFilmGetCinemas response
type TaobaoFilmGetHotShowsRequest ¶
type TaobaoFilmGetHotShowsRequest struct {
*requests.RpcRequest
CityCode requests.Integer `position:"Query" name:"CityCode"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmGetHotShowsRequest is the request struct for api TaobaoFilmGetHotShows
func CreateTaobaoFilmGetHotShowsRequest ¶
func CreateTaobaoFilmGetHotShowsRequest() (request *TaobaoFilmGetHotShowsRequest)
CreateTaobaoFilmGetHotShowsRequest creates a request to invoke TaobaoFilmGetHotShows API
type TaobaoFilmGetHotShowsResponse ¶
type TaobaoFilmGetHotShowsResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
Shows []ShowsItem `json:"Shows" xml:"Shows"`
}
TaobaoFilmGetHotShowsResponse is the response struct for api TaobaoFilmGetHotShows
func CreateTaobaoFilmGetHotShowsResponse ¶
func CreateTaobaoFilmGetHotShowsResponse() (response *TaobaoFilmGetHotShowsResponse)
CreateTaobaoFilmGetHotShowsResponse creates a response to parse from TaobaoFilmGetHotShows response
type TaobaoFilmGetRegionListRequest ¶
type TaobaoFilmGetRegionListRequest struct {
*requests.RpcRequest
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmGetRegionListRequest is the request struct for api TaobaoFilmGetRegionList
func CreateTaobaoFilmGetRegionListRequest ¶
func CreateTaobaoFilmGetRegionListRequest() (request *TaobaoFilmGetRegionListRequest)
CreateTaobaoFilmGetRegionListRequest creates a request to invoke TaobaoFilmGetRegionList API
type TaobaoFilmGetRegionListResponse ¶
type TaobaoFilmGetRegionListResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
Regions []RegionsItem `json:"Regions" xml:"Regions"`
}
TaobaoFilmGetRegionListResponse is the response struct for api TaobaoFilmGetRegionList
func CreateTaobaoFilmGetRegionListResponse ¶
func CreateTaobaoFilmGetRegionListResponse() (response *TaobaoFilmGetRegionListResponse)
CreateTaobaoFilmGetRegionListResponse creates a response to parse from TaobaoFilmGetRegionList response
type TaobaoFilmGetSchedulesRequest ¶
type TaobaoFilmGetSchedulesRequest struct {
*requests.RpcRequest
CinemaId requests.Integer `position:"Query" name:"CinemaId"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmGetSchedulesRequest is the request struct for api TaobaoFilmGetSchedules
func CreateTaobaoFilmGetSchedulesRequest ¶
func CreateTaobaoFilmGetSchedulesRequest() (request *TaobaoFilmGetSchedulesRequest)
CreateTaobaoFilmGetSchedulesRequest creates a request to invoke TaobaoFilmGetSchedules API
type TaobaoFilmGetSchedulesResponse ¶
type TaobaoFilmGetSchedulesResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
Schedules []SchedulesItem `json:"Schedules" xml:"Schedules"`
}
TaobaoFilmGetSchedulesResponse is the response struct for api TaobaoFilmGetSchedules
func CreateTaobaoFilmGetSchedulesResponse ¶
func CreateTaobaoFilmGetSchedulesResponse() (response *TaobaoFilmGetSchedulesResponse)
CreateTaobaoFilmGetSchedulesResponse creates a response to parse from TaobaoFilmGetSchedules response
type TaobaoFilmGetSeatsRequest ¶
type TaobaoFilmGetSeatsRequest struct {
*requests.RpcRequest
ScheduleId requests.Integer `position:"Query" name:"ScheduleId"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmGetSeatsRequest is the request struct for api TaobaoFilmGetSeats
func CreateTaobaoFilmGetSeatsRequest ¶
func CreateTaobaoFilmGetSeatsRequest() (request *TaobaoFilmGetSeatsRequest)
CreateTaobaoFilmGetSeatsRequest creates a request to invoke TaobaoFilmGetSeats API
type TaobaoFilmGetSeatsResponse ¶
type TaobaoFilmGetSeatsResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
SeatMap SeatMap `json:"SeatMap" xml:"SeatMap"`
}
TaobaoFilmGetSeatsResponse is the response struct for api TaobaoFilmGetSeats
func CreateTaobaoFilmGetSeatsResponse ¶
func CreateTaobaoFilmGetSeatsResponse() (response *TaobaoFilmGetSeatsResponse)
CreateTaobaoFilmGetSeatsResponse creates a response to parse from TaobaoFilmGetSeats response
type TaobaoFilmGetShowCommentsRequest ¶
type TaobaoFilmGetShowCommentsRequest struct {
*requests.RpcRequest
ShowId requests.Integer `position:"Query" name:"ShowId"`
PageIndex requests.Integer `position:"Query" name:"PageIndex"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmGetShowCommentsRequest is the request struct for api TaobaoFilmGetShowComments
func CreateTaobaoFilmGetShowCommentsRequest ¶
func CreateTaobaoFilmGetShowCommentsRequest() (request *TaobaoFilmGetShowCommentsRequest)
CreateTaobaoFilmGetShowCommentsRequest creates a request to invoke TaobaoFilmGetShowComments API
type TaobaoFilmGetShowCommentsResponse ¶
type TaobaoFilmGetShowCommentsResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
Count int64 `json:"Count" xml:"Count"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
CommentList []CommentListItem `json:"CommentList" xml:"CommentList"`
}
TaobaoFilmGetShowCommentsResponse is the response struct for api TaobaoFilmGetShowComments
func CreateTaobaoFilmGetShowCommentsResponse ¶
func CreateTaobaoFilmGetShowCommentsResponse() (response *TaobaoFilmGetShowCommentsResponse)
CreateTaobaoFilmGetShowCommentsResponse creates a response to parse from TaobaoFilmGetShowComments response
type TaobaoFilmGetSoonShowsRequest ¶
type TaobaoFilmGetSoonShowsRequest struct {
*requests.RpcRequest
CityCode requests.Integer `position:"Query" name:"CityCode"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmGetSoonShowsRequest is the request struct for api TaobaoFilmGetSoonShows
func CreateTaobaoFilmGetSoonShowsRequest ¶
func CreateTaobaoFilmGetSoonShowsRequest() (request *TaobaoFilmGetSoonShowsRequest)
CreateTaobaoFilmGetSoonShowsRequest creates a request to invoke TaobaoFilmGetSoonShows API
type TaobaoFilmGetSoonShowsResponse ¶
type TaobaoFilmGetSoonShowsResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
Shows []ShowsItem `json:"Shows" xml:"Shows"`
}
TaobaoFilmGetSoonShowsResponse is the response struct for api TaobaoFilmGetSoonShows
func CreateTaobaoFilmGetSoonShowsResponse ¶
func CreateTaobaoFilmGetSoonShowsResponse() (response *TaobaoFilmGetSoonShowsResponse)
CreateTaobaoFilmGetSoonShowsResponse creates a response to parse from TaobaoFilmGetSoonShows response
type TaobaoFilmIssueOrderRequest ¶
type TaobaoFilmIssueOrderRequest struct {
*requests.RpcRequest
LockSeatApplyKey string `position:"Query" name:"LockSeatApplyKey"`
ExtUserId string `position:"Query" name:"ExtUserId"`
ExtOrderId string `position:"Query" name:"ExtOrderId"`
TotalPrice requests.Integer `position:"Query" name:"TotalPrice"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmIssueOrderRequest is the request struct for api TaobaoFilmIssueOrder
func CreateTaobaoFilmIssueOrderRequest ¶
func CreateTaobaoFilmIssueOrderRequest() (request *TaobaoFilmIssueOrderRequest)
CreateTaobaoFilmIssueOrderRequest creates a request to invoke TaobaoFilmIssueOrder API
type TaobaoFilmIssueOrderResponse ¶
type TaobaoFilmIssueOrderResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
Message string `json:"Message" xml:"Message"`
Status string `json:"Status" xml:"Status"`
TbOrderId string `json:"TbOrderId" xml:"TbOrderId"`
TicketContents string `json:"TicketContents" xml:"TicketContents"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
}
TaobaoFilmIssueOrderResponse is the response struct for api TaobaoFilmIssueOrder
func CreateTaobaoFilmIssueOrderResponse ¶
func CreateTaobaoFilmIssueOrderResponse() (response *TaobaoFilmIssueOrderResponse)
CreateTaobaoFilmIssueOrderResponse creates a response to parse from TaobaoFilmIssueOrder response
type TaobaoFilmLockSeatRequest ¶
type TaobaoFilmLockSeatRequest struct {
*requests.RpcRequest
ScheduleId requests.Integer `position:"Query" name:"ScheduleId"`
SeatIds string `position:"Query" name:"SeatIds"`
SeatNames string `position:"Query" name:"SeatNames"`
Mobile string `position:"Query" name:"Mobile"`
ExtUserId string `position:"Query" name:"ExtUserId"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmLockSeatRequest is the request struct for api TaobaoFilmLockSeat
func CreateTaobaoFilmLockSeatRequest ¶
func CreateTaobaoFilmLockSeatRequest() (request *TaobaoFilmLockSeatRequest)
CreateTaobaoFilmLockSeatRequest creates a request to invoke TaobaoFilmLockSeat API
type TaobaoFilmLockSeatResponse ¶
type TaobaoFilmLockSeatResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
SeatLocked SeatLocked `json:"SeatLocked" xml:"SeatLocked"`
}
TaobaoFilmLockSeatResponse is the response struct for api TaobaoFilmLockSeat
func CreateTaobaoFilmLockSeatResponse ¶
func CreateTaobaoFilmLockSeatResponse() (response *TaobaoFilmLockSeatResponse)
CreateTaobaoFilmLockSeatResponse creates a response to parse from TaobaoFilmLockSeat response
type TaobaoFilmUnLockSeatRequest ¶
type TaobaoFilmUnLockSeatRequest struct {
*requests.RpcRequest
LockSeatApplyKey string `position:"Query" name:"LockSeatApplyKey"`
ExtUserId string `position:"Query" name:"ExtUserId"`
ParamsJson string `position:"Query" name:"ParamsJson"`
}
TaobaoFilmUnLockSeatRequest is the request struct for api TaobaoFilmUnLockSeat
func CreateTaobaoFilmUnLockSeatRequest ¶
func CreateTaobaoFilmUnLockSeatRequest() (request *TaobaoFilmUnLockSeatRequest)
CreateTaobaoFilmUnLockSeatRequest creates a request to invoke TaobaoFilmUnLockSeat API
type TaobaoFilmUnLockSeatResponse ¶
type TaobaoFilmUnLockSeatResponse struct {
*responses.BaseResponse
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
Msg string `json:"Msg" xml:"Msg"`
SubCode string `json:"SubCode" xml:"SubCode"`
SubMsg string `json:"SubMsg" xml:"SubMsg"`
ReturnCode string `json:"ReturnCode" xml:"ReturnCode"`
ReturnMessage string `json:"ReturnMessage" xml:"ReturnMessage"`
ReturnValue bool `json:"ReturnValue" xml:"ReturnValue"`
LogsId string `json:"LogsId" xml:"LogsId"`
RequestId string `json:"RequestId" xml:"RequestId"`
}
TaobaoFilmUnLockSeatResponse is the response struct for api TaobaoFilmUnLockSeat
func CreateTaobaoFilmUnLockSeatResponse ¶
func CreateTaobaoFilmUnLockSeatResponse() (response *TaobaoFilmUnLockSeatResponse)
CreateTaobaoFilmUnLockSeatResponse creates a response to parse from TaobaoFilmUnLockSeat response
type TrailerListInTaobaoFilmGetHotShows ¶
type TrailerListInTaobaoFilmGetHotShows struct {
TrailerList []string `json:"TrailerList" xml:"TrailerList"`
}
TrailerListInTaobaoFilmGetHotShows is a nested struct in appmallsservice response
type TrailerListInTaobaoFilmGetSoonShows ¶
type TrailerListInTaobaoFilmGetSoonShows struct {
TrailerList []string `json:"TrailerList" xml:"TrailerList"`
}
TrailerListInTaobaoFilmGetSoonShows is a nested struct in appmallsservice response
Source Files
¶
- client.go
- endpoint.go
- get_messages.go
- remove_messages.go
- struct_biz_messages.go
- struct_biz_messages_item.go
- struct_cinemas.go
- struct_cinemas_item.go
- struct_comment_list.go
- struct_comment_list_item.go
- struct_regions.go
- struct_regions_item.go
- struct_schedules.go
- struct_schedules_item.go
- struct_seat_locked.go
- struct_seat_map.go
- struct_seats.go
- struct_seats_item.go
- struct_show_version_list_in_taobao_film_get_hot_shows.go
- struct_show_version_list_in_taobao_film_get_soon_shows.go
- struct_shows_in_taobao_film_get_hot_shows.go
- struct_shows_in_taobao_film_get_soon_shows.go
- struct_shows_item.go
- struct_trailer_list_in_taobao_film_get_hot_shows.go
- struct_trailer_list_in_taobao_film_get_soon_shows.go
- taobao_film_get_cinemas.go
- taobao_film_get_hot_shows.go
- taobao_film_get_region_list.go
- taobao_film_get_schedules.go
- taobao_film_get_seats.go
- taobao_film_get_show_comments.go
- taobao_film_get_soon_shows.go
- taobao_film_issue_order.go
- taobao_film_lock_seat.go
- taobao_film_un_lock_seat.go