Documentation
¶
Index ¶
- Variables
- func GetEndpointMap() map[string]string
- func GetEndpointType() string
- func SetClientProperty(client *Client, propertyName string, propertyValue interface{})
- func SetEndpointDataToClient(client *Client)
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) QueryQuotaPlanSchedule(request *QueryQuotaPlanScheduleRequest) (response *QueryQuotaPlanScheduleResponse, err error)
- func (client *Client) QueryQuotaPlanScheduleWithCallback(request *QueryQuotaPlanScheduleRequest, ...) <-chan int
- func (client *Client) QueryQuotaPlanScheduleWithChan(request *QueryQuotaPlanScheduleRequest) (<-chan *QueryQuotaPlanScheduleResponse, <-chan error)
- func (client *Client) SubmitPlanningResult(request *SubmitPlanningResultRequest) (response *SubmitPlanningResultResponse, err error)
- func (client *Client) SubmitPlanningResultWithCallback(request *SubmitPlanningResultRequest, ...) <-chan int
- func (client *Client) SubmitPlanningResultWithChan(request *SubmitPlanningResultRequest) (<-chan *SubmitPlanningResultResponse, <-chan error)
- type LadingScheduleList
- type LadingScheduleListItem
- type QueryQuotaPlanScheduleRequest
- type QueryQuotaPlanScheduleResponse
- type Result
- type ResultItem
- type ServerScheduleList
- type ServerScheduleListItem
- type SubmitPlanningResultRequest
- type SubmitPlanningResultResourceMethod
- type SubmitPlanningResultResponse
- type SubmitPlanningResultSupplyPlan
Constants ¶
This section is empty.
Variables ¶
var EndpointMap map[string]string
EndpointMap Endpoint Data
var EndpointType = "regional"
EndpointType regional or central
Functions ¶
func SetClientProperty ¶
SetClientProperty Set Property by Reflect
func SetEndpointDataToClient ¶
func SetEndpointDataToClient(client *Client)
SetEndpointDataToClient Set EndpointMap and ENdpointType
Types ¶
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) QueryQuotaPlanSchedule ¶
func (client *Client) QueryQuotaPlanSchedule(request *QueryQuotaPlanScheduleRequest) (response *QueryQuotaPlanScheduleResponse, err error)
QueryQuotaPlanSchedule invokes the brinekingdom.QueryQuotaPlanSchedule API synchronously
func (*Client) QueryQuotaPlanScheduleWithCallback ¶
func (client *Client) QueryQuotaPlanScheduleWithCallback(request *QueryQuotaPlanScheduleRequest, callback func(response *QueryQuotaPlanScheduleResponse, err error)) <-chan int
QueryQuotaPlanScheduleWithCallback invokes the brinekingdom.QueryQuotaPlanSchedule API asynchronously
func (*Client) QueryQuotaPlanScheduleWithChan ¶
func (client *Client) QueryQuotaPlanScheduleWithChan(request *QueryQuotaPlanScheduleRequest) (<-chan *QueryQuotaPlanScheduleResponse, <-chan error)
QueryQuotaPlanScheduleWithChan invokes the brinekingdom.QueryQuotaPlanSchedule API asynchronously
func (*Client) SubmitPlanningResult ¶
func (client *Client) SubmitPlanningResult(request *SubmitPlanningResultRequest) (response *SubmitPlanningResultResponse, err error)
SubmitPlanningResult invokes the brinekingdom.SubmitPlanningResult API synchronously
func (*Client) SubmitPlanningResultWithCallback ¶
func (client *Client) SubmitPlanningResultWithCallback(request *SubmitPlanningResultRequest, callback func(response *SubmitPlanningResultResponse, err error)) <-chan int
SubmitPlanningResultWithCallback invokes the brinekingdom.SubmitPlanningResult API asynchronously
func (*Client) SubmitPlanningResultWithChan ¶
func (client *Client) SubmitPlanningResultWithChan(request *SubmitPlanningResultRequest) (<-chan *SubmitPlanningResultResponse, <-chan error)
SubmitPlanningResultWithChan invokes the brinekingdom.SubmitPlanningResult API asynchronously
type LadingScheduleList ¶
type LadingScheduleList struct {
LadingScheduleListItem []LadingScheduleListItem `json:"LadingScheduleList" xml:"LadingScheduleList"`
}
LadingScheduleList is a nested struct in brinekingdom response
type LadingScheduleListItem ¶
type LadingScheduleListItem struct {
LadingId string `json:"LadingId" xml:"LadingId"`
Quantity int `json:"Quantity" xml:"Quantity"`
DeliveryQuantity int `json:"DeliveryQuantity" xml:"DeliveryQuantity"`
Status string `json:"Status" xml:"Status"`
ServerScheduleList []ServerScheduleListItem `json:"ServerScheduleList" xml:"ServerScheduleList"`
}
LadingScheduleListItem is a nested struct in brinekingdom response
type QueryQuotaPlanScheduleRequest ¶
type QueryQuotaPlanScheduleRequest struct {
*requests.RpcRequest
QuotaPlanIds *[]string `position:"Query" name:"QuotaPlanIds" type:"Repeated"`
}
QueryQuotaPlanScheduleRequest is the request struct for api QueryQuotaPlanSchedule
func CreateQueryQuotaPlanScheduleRequest ¶
func CreateQueryQuotaPlanScheduleRequest() (request *QueryQuotaPlanScheduleRequest)
CreateQueryQuotaPlanScheduleRequest creates a request to invoke QueryQuotaPlanSchedule API
type QueryQuotaPlanScheduleResponse ¶
type QueryQuotaPlanScheduleResponse struct {
*responses.BaseResponse
Success bool `json:"Success" xml:"Success"`
ErrorMessage string `json:"ErrorMessage" xml:"ErrorMessage"`
ResultCode string `json:"ResultCode" xml:"ResultCode"`
RequestId string `json:"RequestId" xml:"RequestId"`
Result []ResultItem `json:"Result" xml:"Result"`
}
QueryQuotaPlanScheduleResponse is the response struct for api QueryQuotaPlanSchedule
func CreateQueryQuotaPlanScheduleResponse ¶
func CreateQueryQuotaPlanScheduleResponse() (response *QueryQuotaPlanScheduleResponse)
CreateQueryQuotaPlanScheduleResponse creates a response to parse from QueryQuotaPlanSchedule response
type Result ¶
type Result struct {
ResultItem []ResultItem `json:"Result" xml:"Result"`
}
Result is a nested struct in brinekingdom response
type ResultItem ¶
type ResultItem struct {
QuotaPlanId int64 `json:"QuotaPlanId" xml:"QuotaPlanId"`
ProductCode string `json:"ProductCode" xml:"ProductCode"`
CreatorNick string `json:"CreatorNick" xml:"CreatorNick"`
CreatorWorkNo string `json:"CreatorWorkNo" xml:"CreatorWorkNo"`
ConfigModel string `json:"ConfigModel" xml:"ConfigModel"`
Quantity int `json:"Quantity" xml:"Quantity"`
DeliveryDate int64 `json:"DeliveryDate" xml:"DeliveryDate"`
TenantName string `json:"TenantName" xml:"TenantName"`
Status string `json:"Status" xml:"Status"`
LadingScheduleList []LadingScheduleListItem `json:"LadingScheduleList" xml:"LadingScheduleList"`
}
ResultItem is a nested struct in brinekingdom response
type ServerScheduleList ¶
type ServerScheduleList struct {
ServerScheduleListItem []ServerScheduleListItem `json:"ServerScheduleList" xml:"ServerScheduleList"`
}
ServerScheduleList is a nested struct in brinekingdom response
type ServerScheduleListItem ¶
type ServerScheduleListItem struct {
SerialNumber string `json:"SerialNumber" xml:"SerialNumber"`
Status string `json:"Status" xml:"Status"`
Delivery bool `json:"Delivery" xml:"Delivery"`
Type string `json:"Type" xml:"Type"`
}
ServerScheduleListItem is a nested struct in brinekingdom response
type SubmitPlanningResultRequest ¶
type SubmitPlanningResultRequest struct {
*requests.RpcRequest
RequireCnt requests.Integer `position:"Query" name:"RequireCnt"`
DemandId requests.Integer `position:"Query" name:"DemandId"`
SubDemandId requests.Integer `position:"Query" name:"SubDemandId"`
BufferCnt requests.Integer `position:"Query" name:"BufferCnt"`
DemandCount requests.Integer `position:"Query" name:"DemandCount"`
ResourceMethod *[]SubmitPlanningResultResourceMethod `position:"Query" name:"ResourceMethod" type:"Repeated"`
}
SubmitPlanningResultRequest is the request struct for api SubmitPlanningResult
func CreateSubmitPlanningResultRequest ¶
func CreateSubmitPlanningResultRequest() (request *SubmitPlanningResultRequest)
CreateSubmitPlanningResultRequest creates a request to invoke SubmitPlanningResult API
type SubmitPlanningResultResourceMethod ¶
type SubmitPlanningResultResourceMethod struct {
FinalAvzone string `name:"FinalAvzone"`
Cluster string `name:"Cluster"`
ConvertHostCnt string `name:"ConvertHostCnt"`
BufferCnt string `name:"BufferCnt"`
SupplyPlan *[]SubmitPlanningResultSupplyPlan `name:"SupplyPlan" type:"Repeated"`
RoomCode string `name:"RoomCode"`
Comment string `name:"Comment"`
Region string `name:"Region"`
ConvertHostType string `name:"ConvertHostType"`
Azone string `name:"Azone"`
GapCnt string `name:"GapCnt"`
}
SubmitPlanningResultResourceMethod is a repeated param struct in SubmitPlanningResultRequest
type SubmitPlanningResultResponse ¶
type SubmitPlanningResultResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Code string `json:"Code" xml:"Code"`
Message string `json:"Message" xml:"Message"`
Success bool `json:"Success" xml:"Success"`
}
SubmitPlanningResultResponse is the response struct for api SubmitPlanningResult
func CreateSubmitPlanningResultResponse ¶
func CreateSubmitPlanningResultResponse() (response *SubmitPlanningResultResponse)
CreateSubmitPlanningResultResponse creates a response to parse from SubmitPlanningResult response
type SubmitPlanningResultSupplyPlan ¶
type SubmitPlanningResultSupplyPlan struct {
SafeZone string `name:"SafeZone"`
NetArch string `name:"NetArch"`
SupplyType string `name:"SupplyType"`
LogicZone string `name:"LogicZone"`
SupplyAmount string `name:"SupplyAmount"`
SupplyDate string `name:"SupplyDate"`
Nic string `name:"Nic"`
ClassZone string `name:"ClassZone"`
ConvertHostType string `name:"ConvertHostType"`
Product3 string `name:"Product3"`
}
SubmitPlanningResultSupplyPlan is a repeated param struct in SubmitPlanningResultRequest