Documentation
¶
Index ¶
- Variables
- func GetEndpointMap() map[string]string
- func GetEndpointType() string
- func SetClientProperty(client *Client, propertyName string, propertyValue interface{})
- func SetEndpointDataToClient(client *Client)
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) ContinueDeployServiceInstance(request *ContinueDeployServiceInstanceRequest) (response *ContinueDeployServiceInstanceResponse, err error)
- func (client *Client) ContinueDeployServiceInstanceWithCallback(request *ContinueDeployServiceInstanceRequest, ...) <-chan int
- func (client *Client) ContinueDeployServiceInstanceWithChan(request *ContinueDeployServiceInstanceRequest) (<-chan *ContinueDeployServiceInstanceResponse, <-chan error)
- func (client *Client) CreateServiceInstance(request *CreateServiceInstanceRequest) (response *CreateServiceInstanceResponse, err error)
- func (client *Client) CreateServiceInstanceWithCallback(request *CreateServiceInstanceRequest, ...) <-chan int
- func (client *Client) CreateServiceInstanceWithChan(request *CreateServiceInstanceRequest) (<-chan *CreateServiceInstanceResponse, <-chan error)
- func (client *Client) DeleteServiceInstances(request *DeleteServiceInstancesRequest) (response *DeleteServiceInstancesResponse, err error)
- func (client *Client) DeleteServiceInstancesWithCallback(request *DeleteServiceInstancesRequest, ...) <-chan int
- func (client *Client) DeleteServiceInstancesWithChan(request *DeleteServiceInstancesRequest) (<-chan *DeleteServiceInstancesResponse, <-chan error)
- func (client *Client) GetServiceInstance(request *GetServiceInstanceRequest) (response *GetServiceInstanceResponse, err error)
- func (client *Client) GetServiceInstanceWithCallback(request *GetServiceInstanceRequest, ...) <-chan int
- func (client *Client) GetServiceInstanceWithChan(request *GetServiceInstanceRequest) (<-chan *GetServiceInstanceResponse, <-chan error)
- func (client *Client) ListServiceInstanceLogs(request *ListServiceInstanceLogsRequest) (response *ListServiceInstanceLogsResponse, err error)
- func (client *Client) ListServiceInstanceLogsWithCallback(request *ListServiceInstanceLogsRequest, ...) <-chan int
- func (client *Client) ListServiceInstanceLogsWithChan(request *ListServiceInstanceLogsRequest) (<-chan *ListServiceInstanceLogsResponse, <-chan error)
- func (client *Client) ListServiceInstanceResources(request *ListServiceInstanceResourcesRequest) (response *ListServiceInstanceResourcesResponse, err error)
- func (client *Client) ListServiceInstanceResourcesWithCallback(request *ListServiceInstanceResourcesRequest, ...) <-chan int
- func (client *Client) ListServiceInstanceResourcesWithChan(request *ListServiceInstanceResourcesRequest) (<-chan *ListServiceInstanceResourcesResponse, <-chan error)
- func (client *Client) ListServiceInstances(request *ListServiceInstancesRequest) (response *ListServiceInstancesResponse, err error)
- func (client *Client) ListServiceInstancesWithCallback(request *ListServiceInstancesRequest, ...) <-chan int
- func (client *Client) ListServiceInstancesWithChan(request *ListServiceInstancesRequest) (<-chan *ListServiceInstancesResponse, <-chan error)
- type ConnectionConfig
- type ConnectionConfigs
- type ContinueDeployServiceInstanceRequest
- type ContinueDeployServiceInstanceResponse
- type CreateServiceInstanceCommodity
- type CreateServiceInstanceOperationMetadata
- type CreateServiceInstanceRequest
- type CreateServiceInstanceResponse
- type CreateServiceInstanceTag
- type DeleteServiceInstancesRequest
- type DeleteServiceInstancesResponse
- type DryRunResult
- type EndpointIps
- type GetServiceInstanceRequest
- type GetServiceInstanceResponse
- type ListServiceInstanceLogsRequest
- type ListServiceInstanceLogsResponse
- type ListServiceInstanceResourcesRequest
- type ListServiceInstanceResourcesResponse
- type ListServiceInstanceResourcesTag
- type ListServiceInstancesFilter
- type ListServiceInstancesRequest
- type ListServiceInstancesResponse
- type ListServiceInstancesTag
- type NetworkConfig
- type ParametersAllowedToBeModified
- type ParametersConditionallyAllowedToBeModified
- type ParametersNotAllowedToBeModified
- type PrivateVpcConnection
- type PrivateVpcConnections
- type Resources
- type ResourcesItem
- type ReversePrivateVpcConnection
- type ReversePrivateVpcConnections
- type SecurityGroups
- type Service
- type ServiceInfo
- type ServiceInfosInGetServiceInstance
- type ServiceInfosInListServiceInstances
- type ServiceInstance
- type ServiceInstanceLogs
- type ServiceInstances
- type ServiceInstancesLogs
- type Tag
- type TagsInGetServiceInstance
- type TagsInListServiceInstances
- type UpgradableServiceVersions
- type VSwitches
Constants ¶
This section is empty.
Variables ¶
var EndpointMap map[string]string
EndpointMap Endpoint Data
var EndpointType = "regional"
EndpointType regional or central
Functions ¶
func SetClientProperty ¶
SetClientProperty Set Property by Reflect
func SetEndpointDataToClient ¶
func SetEndpointDataToClient(client *Client)
SetEndpointDataToClient Set EndpointMap and ENdpointType
Types ¶
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) ContinueDeployServiceInstance ¶
func (client *Client) ContinueDeployServiceInstance(request *ContinueDeployServiceInstanceRequest) (response *ContinueDeployServiceInstanceResponse, err error)
ContinueDeployServiceInstance invokes the computenest.ContinueDeployServiceInstance API synchronously
func (*Client) ContinueDeployServiceInstanceWithCallback ¶
func (client *Client) ContinueDeployServiceInstanceWithCallback(request *ContinueDeployServiceInstanceRequest, callback func(response *ContinueDeployServiceInstanceResponse, err error)) <-chan int
ContinueDeployServiceInstanceWithCallback invokes the computenest.ContinueDeployServiceInstance API asynchronously
func (*Client) ContinueDeployServiceInstanceWithChan ¶
func (client *Client) ContinueDeployServiceInstanceWithChan(request *ContinueDeployServiceInstanceRequest) (<-chan *ContinueDeployServiceInstanceResponse, <-chan error)
ContinueDeployServiceInstanceWithChan invokes the computenest.ContinueDeployServiceInstance API asynchronously
func (*Client) CreateServiceInstance ¶
func (client *Client) CreateServiceInstance(request *CreateServiceInstanceRequest) (response *CreateServiceInstanceResponse, err error)
CreateServiceInstance invokes the computenest.CreateServiceInstance API synchronously
func (*Client) CreateServiceInstanceWithCallback ¶
func (client *Client) CreateServiceInstanceWithCallback(request *CreateServiceInstanceRequest, callback func(response *CreateServiceInstanceResponse, err error)) <-chan int
CreateServiceInstanceWithCallback invokes the computenest.CreateServiceInstance API asynchronously
func (*Client) CreateServiceInstanceWithChan ¶
func (client *Client) CreateServiceInstanceWithChan(request *CreateServiceInstanceRequest) (<-chan *CreateServiceInstanceResponse, <-chan error)
CreateServiceInstanceWithChan invokes the computenest.CreateServiceInstance API asynchronously
func (*Client) DeleteServiceInstances ¶
func (client *Client) DeleteServiceInstances(request *DeleteServiceInstancesRequest) (response *DeleteServiceInstancesResponse, err error)
DeleteServiceInstances invokes the computenest.DeleteServiceInstances API synchronously
func (*Client) DeleteServiceInstancesWithCallback ¶
func (client *Client) DeleteServiceInstancesWithCallback(request *DeleteServiceInstancesRequest, callback func(response *DeleteServiceInstancesResponse, err error)) <-chan int
DeleteServiceInstancesWithCallback invokes the computenest.DeleteServiceInstances API asynchronously
func (*Client) DeleteServiceInstancesWithChan ¶
func (client *Client) DeleteServiceInstancesWithChan(request *DeleteServiceInstancesRequest) (<-chan *DeleteServiceInstancesResponse, <-chan error)
DeleteServiceInstancesWithChan invokes the computenest.DeleteServiceInstances API asynchronously
func (*Client) GetServiceInstance ¶
func (client *Client) GetServiceInstance(request *GetServiceInstanceRequest) (response *GetServiceInstanceResponse, err error)
GetServiceInstance invokes the computenest.GetServiceInstance API synchronously
func (*Client) GetServiceInstanceWithCallback ¶
func (client *Client) GetServiceInstanceWithCallback(request *GetServiceInstanceRequest, callback func(response *GetServiceInstanceResponse, err error)) <-chan int
GetServiceInstanceWithCallback invokes the computenest.GetServiceInstance API asynchronously
func (*Client) GetServiceInstanceWithChan ¶
func (client *Client) GetServiceInstanceWithChan(request *GetServiceInstanceRequest) (<-chan *GetServiceInstanceResponse, <-chan error)
GetServiceInstanceWithChan invokes the computenest.GetServiceInstance API asynchronously
func (*Client) ListServiceInstanceLogs ¶
func (client *Client) ListServiceInstanceLogs(request *ListServiceInstanceLogsRequest) (response *ListServiceInstanceLogsResponse, err error)
ListServiceInstanceLogs invokes the computenest.ListServiceInstanceLogs API synchronously
func (*Client) ListServiceInstanceLogsWithCallback ¶
func (client *Client) ListServiceInstanceLogsWithCallback(request *ListServiceInstanceLogsRequest, callback func(response *ListServiceInstanceLogsResponse, err error)) <-chan int
ListServiceInstanceLogsWithCallback invokes the computenest.ListServiceInstanceLogs API asynchronously
func (*Client) ListServiceInstanceLogsWithChan ¶
func (client *Client) ListServiceInstanceLogsWithChan(request *ListServiceInstanceLogsRequest) (<-chan *ListServiceInstanceLogsResponse, <-chan error)
ListServiceInstanceLogsWithChan invokes the computenest.ListServiceInstanceLogs API asynchronously
func (*Client) ListServiceInstanceResources ¶
func (client *Client) ListServiceInstanceResources(request *ListServiceInstanceResourcesRequest) (response *ListServiceInstanceResourcesResponse, err error)
ListServiceInstanceResources invokes the computenest.ListServiceInstanceResources API synchronously
func (*Client) ListServiceInstanceResourcesWithCallback ¶
func (client *Client) ListServiceInstanceResourcesWithCallback(request *ListServiceInstanceResourcesRequest, callback func(response *ListServiceInstanceResourcesResponse, err error)) <-chan int
ListServiceInstanceResourcesWithCallback invokes the computenest.ListServiceInstanceResources API asynchronously
func (*Client) ListServiceInstanceResourcesWithChan ¶
func (client *Client) ListServiceInstanceResourcesWithChan(request *ListServiceInstanceResourcesRequest) (<-chan *ListServiceInstanceResourcesResponse, <-chan error)
ListServiceInstanceResourcesWithChan invokes the computenest.ListServiceInstanceResources API asynchronously
func (*Client) ListServiceInstances ¶
func (client *Client) ListServiceInstances(request *ListServiceInstancesRequest) (response *ListServiceInstancesResponse, err error)
ListServiceInstances invokes the computenest.ListServiceInstances API synchronously
func (*Client) ListServiceInstancesWithCallback ¶
func (client *Client) ListServiceInstancesWithCallback(request *ListServiceInstancesRequest, callback func(response *ListServiceInstancesResponse, err error)) <-chan int
ListServiceInstancesWithCallback invokes the computenest.ListServiceInstances API asynchronously
func (*Client) ListServiceInstancesWithChan ¶
func (client *Client) ListServiceInstancesWithChan(request *ListServiceInstancesRequest) (<-chan *ListServiceInstancesResponse, <-chan error)
ListServiceInstancesWithChan invokes the computenest.ListServiceInstances API asynchronously
type ConnectionConfig ¶
type ConnectionConfig struct {
VpcId string `json:"VpcId" xml:"VpcId"`
IngressEndpointStatus string `json:"IngressEndpointStatus" xml:"IngressEndpointStatus"`
NetworkServiceStatus string `json:"NetworkServiceStatus" xml:"NetworkServiceStatus"`
DomainName string `json:"DomainName" xml:"DomainName"`
RegionId string `json:"RegionId" xml:"RegionId"`
ConnectBandwidth int `json:"ConnectBandwidth" xml:"ConnectBandwidth"`
SecurityGroups []string `json:"SecurityGroups" xml:"SecurityGroups"`
VSwitches []string `json:"VSwitches" xml:"VSwitches"`
EndpointIps []string `json:"EndpointIps" xml:"EndpointIps"`
}
ConnectionConfig is a nested struct in computenest response
type ConnectionConfigs ¶
type ConnectionConfigs struct {
ConnectionConfig []ConnectionConfig `json:"ConnectionConfig" xml:"ConnectionConfig"`
}
ConnectionConfigs is a nested struct in computenest response
type ContinueDeployServiceInstanceRequest ¶
type ContinueDeployServiceInstanceRequest struct {
*requests.RpcRequest
ClientToken string `position:"Query" name:"ClientToken"`
ServiceInstanceId string `position:"Query" name:"ServiceInstanceId"`
DryRun requests.Boolean `position:"Query" name:"DryRun"`
Parameters string `position:"Query" name:"Parameters"`
Option *[]string `position:"Query" name:"Option" type:"Repeated"`
}
ContinueDeployServiceInstanceRequest is the request struct for api ContinueDeployServiceInstance
func CreateContinueDeployServiceInstanceRequest ¶
func CreateContinueDeployServiceInstanceRequest() (request *ContinueDeployServiceInstanceRequest)
CreateContinueDeployServiceInstanceRequest creates a request to invoke ContinueDeployServiceInstance API
type ContinueDeployServiceInstanceResponse ¶
type ContinueDeployServiceInstanceResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
ServiceInstanceId string `json:"ServiceInstanceId" xml:"ServiceInstanceId"`
DryRunResult DryRunResult `json:"DryRunResult" xml:"DryRunResult"`
}
ContinueDeployServiceInstanceResponse is the response struct for api ContinueDeployServiceInstance
func CreateContinueDeployServiceInstanceResponse ¶
func CreateContinueDeployServiceInstanceResponse() (response *ContinueDeployServiceInstanceResponse)
CreateContinueDeployServiceInstanceResponse creates a response to parse from ContinueDeployServiceInstance response
type CreateServiceInstanceCommodity ¶
type CreateServiceInstanceCommodity struct {
PayPeriod string `name:"PayPeriod"`
PayPeriodUnit string `name:"PayPeriodUnit"`
}
CreateServiceInstanceCommodity is a repeated param struct in CreateServiceInstanceRequest
type CreateServiceInstanceOperationMetadata ¶
type CreateServiceInstanceOperationMetadata struct {
EndTime string `name:"EndTime"`
Resources string `name:"Resources"`
StartTime string `name:"StartTime"`
ExtraInfo string `name:"ExtraInfo"`
ServiceInstanceId string `name:"ServiceInstanceId"`
}
CreateServiceInstanceOperationMetadata is a repeated param struct in CreateServiceInstanceRequest
type CreateServiceInstanceRequest ¶
type CreateServiceInstanceRequest struct {
*requests.RpcRequest
Commodity CreateServiceInstanceCommodity `position:"Query" name:"Commodity" type:"Struct"`
ContactGroup string `position:"Query" name:"ContactGroup"`
ClientToken string `position:"Query" name:"ClientToken"`
SpecificationCode string `position:"Query" name:"SpecificationCode"`
ResourceGroupId string `position:"Query" name:"ResourceGroupId"`
EnableInstanceOps requests.Boolean `position:"Query" name:"EnableInstanceOps"`
TemplateName string `position:"Query" name:"TemplateName"`
Tag *[]CreateServiceInstanceTag `position:"Query" name:"Tag" type:"Repeated"`
DryRun requests.Boolean `position:"Query" name:"DryRun"`
EnableUserPrometheus requests.Boolean `position:"Query" name:"EnableUserPrometheus"`
SpecificationName string `position:"Query" name:"SpecificationName"`
TrialType string `position:"Query" name:"TrialType"`
Name string `position:"Query" name:"Name"`
ServiceVersion string `position:"Query" name:"ServiceVersion"`
ServiceId string `position:"Query" name:"ServiceId"`
Parameters string `position:"Query" name:"Parameters"`
PayType requests.Integer `position:"Query" name:"PayType"`
OperationMetadata CreateServiceInstanceOperationMetadata `position:"Query" name:"OperationMetadata" type:"Struct"`
}
CreateServiceInstanceRequest is the request struct for api CreateServiceInstance
func CreateCreateServiceInstanceRequest ¶
func CreateCreateServiceInstanceRequest() (request *CreateServiceInstanceRequest)
CreateCreateServiceInstanceRequest creates a request to invoke CreateServiceInstance API
type CreateServiceInstanceResponse ¶
type CreateServiceInstanceResponse struct {
*responses.BaseResponse
Status string `json:"Status" xml:"Status"`
RequestId string `json:"RequestId" xml:"RequestId"`
ServiceInstanceId string `json:"ServiceInstanceId" xml:"ServiceInstanceId"`
MarketInstanceId string `json:"MarketInstanceId" xml:"MarketInstanceId"`
}
CreateServiceInstanceResponse is the response struct for api CreateServiceInstance
func CreateCreateServiceInstanceResponse ¶
func CreateCreateServiceInstanceResponse() (response *CreateServiceInstanceResponse)
CreateCreateServiceInstanceResponse creates a response to parse from CreateServiceInstance response
type CreateServiceInstanceTag ¶
CreateServiceInstanceTag is a repeated param struct in CreateServiceInstanceRequest
type DeleteServiceInstancesRequest ¶
type DeleteServiceInstancesRequest struct {
*requests.RpcRequest
ClientToken string `position:"Query" name:"ClientToken"`
ServiceInstanceId *[]string `position:"Query" name:"ServiceInstanceId" type:"Repeated"`
}
DeleteServiceInstancesRequest is the request struct for api DeleteServiceInstances
func CreateDeleteServiceInstancesRequest ¶
func CreateDeleteServiceInstancesRequest() (request *DeleteServiceInstancesRequest)
CreateDeleteServiceInstancesRequest creates a request to invoke DeleteServiceInstances API
type DeleteServiceInstancesResponse ¶
type DeleteServiceInstancesResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
}
DeleteServiceInstancesResponse is the response struct for api DeleteServiceInstances
func CreateDeleteServiceInstancesResponse ¶
func CreateDeleteServiceInstancesResponse() (response *DeleteServiceInstancesResponse)
CreateDeleteServiceInstancesResponse creates a response to parse from DeleteServiceInstances response
type DryRunResult ¶
type DryRunResult struct {
ParametersNotAllowedToBeModified []string `json:"ParametersNotAllowedToBeModified" xml:"ParametersNotAllowedToBeModified"`
ParametersConditionallyAllowedToBeModified []string `json:"ParametersConditionallyAllowedToBeModified" xml:"ParametersConditionallyAllowedToBeModified"`
ParametersAllowedToBeModified []string `json:"ParametersAllowedToBeModified" xml:"ParametersAllowedToBeModified"`
}
DryRunResult is a nested struct in computenest response
type EndpointIps ¶
type EndpointIps struct {
EndpointIp []string `json:"EndpointIp" xml:"EndpointIp"`
}
EndpointIps is a nested struct in computenest response
type GetServiceInstanceRequest ¶
type GetServiceInstanceRequest struct {
*requests.RpcRequest
ServiceInstanceId string `position:"Query" name:"ServiceInstanceId"`
MarketInstanceId string `position:"Query" name:"MarketInstanceId"`
}
GetServiceInstanceRequest is the request struct for api GetServiceInstance
func CreateGetServiceInstanceRequest ¶
func CreateGetServiceInstanceRequest() (request *GetServiceInstanceRequest)
CreateGetServiceInstanceRequest creates a request to invoke GetServiceInstance API
type GetServiceInstanceResponse ¶
type GetServiceInstanceResponse struct {
*responses.BaseResponse
Outputs string `json:"Outputs" xml:"Outputs"`
Status string `json:"Status" xml:"Status"`
TemplateName string `json:"TemplateName" xml:"TemplateName"`
UpdateTime string `json:"UpdateTime" xml:"UpdateTime"`
Progress int64 `json:"Progress" xml:"Progress"`
Parameters string `json:"Parameters" xml:"Parameters"`
RequestId string `json:"RequestId" xml:"RequestId"`
ServiceInstanceId string `json:"ServiceInstanceId" xml:"ServiceInstanceId"`
CreateTime string `json:"CreateTime" xml:"CreateTime"`
StatusDetail string `json:"StatusDetail" xml:"StatusDetail"`
Resources string `json:"Resources" xml:"Resources"`
OperationStartTime string `json:"OperationStartTime" xml:"OperationStartTime"`
OperationEndTime string `json:"OperationEndTime" xml:"OperationEndTime"`
OperatedServiceInstanceId string `json:"OperatedServiceInstanceId" xml:"OperatedServiceInstanceId"`
EnableInstanceOps bool `json:"EnableInstanceOps" xml:"EnableInstanceOps"`
IsOperated bool `json:"IsOperated" xml:"IsOperated"`
LicenseEndTime string `json:"LicenseEndTime" xml:"LicenseEndTime"`
UserId int64 `json:"UserId" xml:"UserId"`
SupplierUid int64 `json:"SupplierUid" xml:"SupplierUid"`
EndTime string `json:"EndTime" xml:"EndTime"`
Source string `json:"Source" xml:"Source"`
ServiceType string `json:"ServiceType" xml:"ServiceType"`
PayType string `json:"PayType" xml:"PayType"`
Name string `json:"Name" xml:"Name"`
EnableUserPrometheus bool `json:"EnableUserPrometheus" xml:"EnableUserPrometheus"`
Components string `json:"Components" xml:"Components"`
PredefinedParameterName string `json:"PredefinedParameterName" xml:"PredefinedParameterName"`
MarketInstanceId string `json:"MarketInstanceId" xml:"MarketInstanceId"`
ResourceGroupId string `json:"ResourceGroupId" xml:"ResourceGroupId"`
Service Service `json:"Service" xml:"Service"`
NetworkConfig NetworkConfig `json:"NetworkConfig" xml:"NetworkConfig"`
Tags []Tag `json:"Tags" xml:"Tags"`
}
GetServiceInstanceResponse is the response struct for api GetServiceInstance
func CreateGetServiceInstanceResponse ¶
func CreateGetServiceInstanceResponse() (response *GetServiceInstanceResponse)
CreateGetServiceInstanceResponse creates a response to parse from GetServiceInstance response
type ListServiceInstanceLogsRequest ¶
type ListServiceInstanceLogsRequest struct {
*requests.RpcRequest
NextToken string `position:"Query" name:"NextToken"`
ServiceInstanceId string `position:"Query" name:"ServiceInstanceId"`
MaxResults string `position:"Query" name:"MaxResults"`
}
ListServiceInstanceLogsRequest is the request struct for api ListServiceInstanceLogs
func CreateListServiceInstanceLogsRequest ¶
func CreateListServiceInstanceLogsRequest() (request *ListServiceInstanceLogsRequest)
CreateListServiceInstanceLogsRequest creates a request to invoke ListServiceInstanceLogs API
type ListServiceInstanceLogsResponse ¶
type ListServiceInstanceLogsResponse struct {
*responses.BaseResponse
NextToken string `json:"NextToken" xml:"NextToken"`
RequestId string `json:"RequestId" xml:"RequestId"`
MaxResults string `json:"MaxResults" xml:"MaxResults"`
ServiceInstancesLogs []ServiceInstanceLogs `json:"ServiceInstancesLogs" xml:"ServiceInstancesLogs"`
}
ListServiceInstanceLogsResponse is the response struct for api ListServiceInstanceLogs
func CreateListServiceInstanceLogsResponse ¶
func CreateListServiceInstanceLogsResponse() (response *ListServiceInstanceLogsResponse)
CreateListServiceInstanceLogsResponse creates a response to parse from ListServiceInstanceLogs response
type ListServiceInstanceResourcesRequest ¶
type ListServiceInstanceResourcesRequest struct {
*requests.RpcRequest
ExpireTimeEnd string `position:"Query" name:"ExpireTimeEnd"`
NextToken string `position:"Query" name:"NextToken"`
ResourceARN *[]string `position:"Query" name:"ResourceARN" type:"Repeated"`
Tag *[]ListServiceInstanceResourcesTag `position:"Query" name:"Tag" type:"Repeated"`
ServiceInstanceId string `position:"Query" name:"ServiceInstanceId"`
ExpireTimeStart string `position:"Query" name:"ExpireTimeStart"`
MaxResults string `position:"Query" name:"MaxResults"`
PayType string `position:"Query" name:"PayType"`
}
ListServiceInstanceResourcesRequest is the request struct for api ListServiceInstanceResources
func CreateListServiceInstanceResourcesRequest ¶
func CreateListServiceInstanceResourcesRequest() (request *ListServiceInstanceResourcesRequest)
CreateListServiceInstanceResourcesRequest creates a request to invoke ListServiceInstanceResources API
type ListServiceInstanceResourcesResponse ¶
type ListServiceInstanceResourcesResponse struct {
*responses.BaseResponse
NextToken string `json:"NextToken" xml:"NextToken"`
RequestId string `json:"RequestId" xml:"RequestId"`
MaxResults string `json:"MaxResults" xml:"MaxResults"`
Resources []ResourcesItem `json:"Resources" xml:"Resources"`
}
ListServiceInstanceResourcesResponse is the response struct for api ListServiceInstanceResources
func CreateListServiceInstanceResourcesResponse ¶
func CreateListServiceInstanceResourcesResponse() (response *ListServiceInstanceResourcesResponse)
CreateListServiceInstanceResourcesResponse creates a response to parse from ListServiceInstanceResources response
type ListServiceInstanceResourcesTag ¶
ListServiceInstanceResourcesTag is a repeated param struct in ListServiceInstanceResourcesRequest
type ListServiceInstancesFilter ¶
type ListServiceInstancesFilter struct {
Name string `name:"Name"`
Value *[]string `name:"Value" type:"Repeated"`
}
ListServiceInstancesFilter is a repeated param struct in ListServiceInstancesRequest
type ListServiceInstancesRequest ¶
type ListServiceInstancesRequest struct {
*requests.RpcRequest
ResourceGroupId string `position:"Query" name:"ResourceGroupId"`
NextToken string `position:"Query" name:"NextToken"`
Tag *[]ListServiceInstancesTag `position:"Query" name:"Tag" type:"Repeated"`
Filter *[]ListServiceInstancesFilter `position:"Query" name:"Filter" type:"Repeated"`
MaxResults string `position:"Query" name:"MaxResults"`
}
ListServiceInstancesRequest is the request struct for api ListServiceInstances
func CreateListServiceInstancesRequest ¶
func CreateListServiceInstancesRequest() (request *ListServiceInstancesRequest)
CreateListServiceInstancesRequest creates a request to invoke ListServiceInstances API
type ListServiceInstancesResponse ¶
type ListServiceInstancesResponse struct {
*responses.BaseResponse
NextToken string `json:"NextToken" xml:"NextToken"`
RequestId string `json:"RequestId" xml:"RequestId"`
TotalCount int64 `json:"TotalCount" xml:"TotalCount"`
MaxResults string `json:"MaxResults" xml:"MaxResults"`
ServiceInstances []ServiceInstance `json:"ServiceInstances" xml:"ServiceInstances"`
}
ListServiceInstancesResponse is the response struct for api ListServiceInstances
func CreateListServiceInstancesResponse ¶
func CreateListServiceInstancesResponse() (response *ListServiceInstancesResponse)
CreateListServiceInstancesResponse creates a response to parse from ListServiceInstances response
type ListServiceInstancesTag ¶
ListServiceInstancesTag is a repeated param struct in ListServiceInstancesRequest
type NetworkConfig ¶
type NetworkConfig struct {
EndpointId string `json:"EndpointId" xml:"EndpointId"`
PrivateZoneId string `json:"PrivateZoneId" xml:"PrivateZoneId"`
PrivateVpcConnections []PrivateVpcConnection `json:"PrivateVpcConnections" xml:"PrivateVpcConnections"`
ReversePrivateVpcConnections []ReversePrivateVpcConnection `json:"ReversePrivateVpcConnections" xml:"ReversePrivateVpcConnections"`
}
NetworkConfig is a nested struct in computenest response
type ParametersAllowedToBeModified ¶
type ParametersAllowedToBeModified struct {
ParameterAllowedToBeModified []string `json:"parameterAllowedToBeModified" xml:"parameterAllowedToBeModified"`
}
ParametersAllowedToBeModified is a nested struct in computenest response
type ParametersConditionallyAllowedToBeModified ¶
type ParametersConditionallyAllowedToBeModified struct {
ParameterConditionallyAllowedToBeModified []string `json:"parameterConditionallyAllowedToBeModified" xml:"parameterConditionallyAllowedToBeModified"`
}
ParametersConditionallyAllowedToBeModified is a nested struct in computenest response
type ParametersNotAllowedToBeModified ¶
type ParametersNotAllowedToBeModified struct {
ParameterNotAllowedToBeModified []string `json:"parameterNotAllowedToBeModified" xml:"parameterNotAllowedToBeModified"`
}
ParametersNotAllowedToBeModified is a nested struct in computenest response
type PrivateVpcConnection ¶
type PrivateVpcConnection struct {
EndpointId string `json:"EndpointId" xml:"EndpointId"`
PrivateZoneId string `json:"PrivateZoneId" xml:"PrivateZoneId"`
PrivateZoneName string `json:"PrivateZoneName" xml:"PrivateZoneName"`
RegionId string `json:"RegionId" xml:"RegionId"`
ConnectionConfigs []ConnectionConfig `json:"ConnectionConfigs" xml:"ConnectionConfigs"`
}
PrivateVpcConnection is a nested struct in computenest response
type PrivateVpcConnections ¶
type PrivateVpcConnections struct {
PrivateVpcConnection []PrivateVpcConnection `json:"PrivateVpcConnection" xml:"PrivateVpcConnection"`
}
PrivateVpcConnections is a nested struct in computenest response
type Resources ¶
type Resources struct {
ResourcesItem []ResourcesItem `json:"Resources" xml:"Resources"`
}
Resources is a nested struct in computenest response
type ResourcesItem ¶
type ResourcesItem struct {
ResourceARN string `json:"ResourceARN" xml:"ResourceARN"`
PayType string `json:"PayType" xml:"PayType"`
RenewStatus string `json:"RenewStatus" xml:"RenewStatus"`
CreateTime string `json:"CreateTime" xml:"CreateTime"`
ExpireTime string `json:"ExpireTime" xml:"ExpireTime"`
RenewalPeriod int `json:"RenewalPeriod" xml:"RenewalPeriod"`
RenewalPeriodUnit string `json:"RenewalPeriodUnit" xml:"RenewalPeriodUnit"`
ProductType string `json:"ProductType" xml:"ProductType"`
ProductCode string `json:"ProductCode" xml:"ProductCode"`
}
ResourcesItem is a nested struct in computenest response
type ReversePrivateVpcConnection ¶
type ReversePrivateVpcConnection struct {
EndpointId string `json:"EndpointId" xml:"EndpointId"`
}
ReversePrivateVpcConnection is a nested struct in computenest response
type ReversePrivateVpcConnections ¶
type ReversePrivateVpcConnections struct {
ReversePrivateVpcConnection []ReversePrivateVpcConnection `json:"ReversePrivateVpcConnection" xml:"ReversePrivateVpcConnection"`
}
ReversePrivateVpcConnections is a nested struct in computenest response
type SecurityGroups ¶
type SecurityGroups struct {
SecurityGroup []string `json:"SecurityGroup" xml:"SecurityGroup"`
}
SecurityGroups is a nested struct in computenest response
type Service ¶
type Service struct {
VersionName string `json:"VersionName" xml:"VersionName"`
SupplierUrl string `json:"SupplierUrl" xml:"SupplierUrl"`
Version string `json:"Version" xml:"Version"`
DeployType string `json:"DeployType" xml:"DeployType"`
DeployMetadata string `json:"DeployMetadata" xml:"DeployMetadata"`
ServiceId string `json:"ServiceId" xml:"ServiceId"`
ServiceProductUrl string `json:"ServiceProductUrl" xml:"ServiceProductUrl"`
ServiceDocUrl string `json:"ServiceDocUrl" xml:"ServiceDocUrl"`
SupplierName string `json:"SupplierName" xml:"SupplierName"`
Status string `json:"Status" xml:"Status"`
PublishTime string `json:"PublishTime" xml:"PublishTime"`
ServiceType string `json:"ServiceType" xml:"ServiceType"`
UpgradeMetadata string `json:"UpgradeMetadata" xml:"UpgradeMetadata"`
UpgradableServiceVersions []string `json:"UpgradableServiceVersions" xml:"UpgradableServiceVersions"`
ServiceInfos []ServiceInfo `json:"ServiceInfos" xml:"ServiceInfos"`
}
Service is a nested struct in computenest response
type ServiceInfo ¶
type ServiceInfo struct {
Name string `json:"Name" xml:"Name"`
ShortDescription string `json:"ShortDescription" xml:"ShortDescription"`
Image string `json:"Image" xml:"Image"`
Locale string `json:"Locale" xml:"Locale"`
}
ServiceInfo is a nested struct in computenest response
type ServiceInfosInGetServiceInstance ¶
type ServiceInfosInGetServiceInstance struct {
ServiceInfo []ServiceInfo `json:"ServiceInfo" xml:"ServiceInfo"`
}
ServiceInfosInGetServiceInstance is a nested struct in computenest response
type ServiceInfosInListServiceInstances ¶
type ServiceInfosInListServiceInstances struct {
ServiceInfo []ServiceInfo `json:"ServiceInfo" xml:"ServiceInfo"`
}
ServiceInfosInListServiceInstances is a nested struct in computenest response
type ServiceInstance ¶
type ServiceInstance struct {
Name string `json:"Name" xml:"Name"`
Status string `json:"Status" xml:"Status"`
Outputs string `json:"Outputs" xml:"Outputs"`
UpdateTime string `json:"UpdateTime" xml:"UpdateTime"`
Parameters string `json:"Parameters" xml:"Parameters"`
ServiceInstanceId string `json:"ServiceInstanceId" xml:"ServiceInstanceId"`
CreateTime string `json:"CreateTime" xml:"CreateTime"`
StatusDetail string `json:"StatusDetail" xml:"StatusDetail"`
Progress int64 `json:"Progress" xml:"Progress"`
Resources string `json:"Resources" xml:"Resources"`
TemplateName string `json:"TemplateName" xml:"TemplateName"`
OperatedServiceInstanceId string `json:"OperatedServiceInstanceId" xml:"OperatedServiceInstanceId"`
OperationStartTime string `json:"OperationStartTime" xml:"OperationStartTime"`
OperationEndTime string `json:"OperationEndTime" xml:"OperationEndTime"`
EnableInstanceOps bool `json:"EnableInstanceOps" xml:"EnableInstanceOps"`
Source string `json:"Source" xml:"Source"`
EndTime string `json:"EndTime" xml:"EndTime"`
ServiceType string `json:"ServiceType" xml:"ServiceType"`
PayType string `json:"PayType" xml:"PayType"`
MarketInstanceId string `json:"MarketInstanceId" xml:"MarketInstanceId"`
ResourceGroupId string `json:"ResourceGroupId" xml:"ResourceGroupId"`
Service Service `json:"Service" xml:"Service"`
Tags []Tag `json:"Tags" xml:"Tags"`
}
ServiceInstance is a nested struct in computenest response
type ServiceInstanceLogs ¶
type ServiceInstanceLogs struct {
Timestamp string `json:"Timestamp" xml:"Timestamp"`
ServiceInstanceId string `json:"ServiceInstanceId" xml:"ServiceInstanceId"`
Source string `json:"Source" xml:"Source"`
Content string `json:"Content" xml:"Content"`
LogType string `json:"LogType" xml:"LogType"`
ResourceType string `json:"ResourceType" xml:"ResourceType"`
ResourceId string `json:"ResourceId" xml:"ResourceId"`
Status string `json:"Status" xml:"Status"`
}
ServiceInstanceLogs is a nested struct in computenest response
type ServiceInstances ¶
type ServiceInstances struct {
ServiceInstance []ServiceInstance `json:"ServiceInstance" xml:"ServiceInstance"`
}
ServiceInstances is a nested struct in computenest response
type ServiceInstancesLogs ¶
type ServiceInstancesLogs struct {
ServiceInstanceLogs []ServiceInstanceLogs `json:"ServiceInstanceLogs" xml:"ServiceInstanceLogs"`
}
ServiceInstancesLogs is a nested struct in computenest response
type TagsInGetServiceInstance ¶
type TagsInGetServiceInstance struct {
Tag []Tag `json:"Tag" xml:"Tag"`
}
TagsInGetServiceInstance is a nested struct in computenest response
type TagsInListServiceInstances ¶
type TagsInListServiceInstances struct {
Tag []Tag `json:"Tag" xml:"Tag"`
}
TagsInListServiceInstances is a nested struct in computenest response
type UpgradableServiceVersions ¶
type UpgradableServiceVersions struct {
UpgradableServiceVersion []string `json:"UpgradableServiceVersion" xml:"UpgradableServiceVersion"`
}
UpgradableServiceVersions is a nested struct in computenest response
Source Files
¶
- client.go
- continue_deploy_service_instance.go
- create_service_instance.go
- delete_service_instances.go
- endpoint.go
- get_service_instance.go
- list_service_instance_logs.go
- list_service_instance_resources.go
- list_service_instances.go
- struct_connection_config.go
- struct_connection_configs.go
- struct_dry_run_result.go
- struct_endpoint_ips.go
- struct_network_config.go
- struct_parameters_allowed_to_be_modified.go
- struct_parameters_conditionally_allowed_to_be_modified.go
- struct_parameters_not_allowed_to_be_modified.go
- struct_private_vpc_connection.go
- struct_private_vpc_connections.go
- struct_resources.go
- struct_resources_item.go
- struct_reverse_private_vpc_connection.go
- struct_reverse_private_vpc_connections.go
- struct_security_groups.go
- struct_service.go
- struct_service_info.go
- struct_service_infos_in_get_service_instance.go
- struct_service_infos_in_list_service_instances.go
- struct_service_instance.go
- struct_service_instance_logs.go
- struct_service_instances.go
- struct_service_instances_logs.go
- struct_tag.go
- struct_tags_in_get_service_instance.go
- struct_tags_in_list_service_instances.go
- struct_upgradable_service_versions.go
- struct_v_switches.go