Documentation
¶
Index ¶
- type CheckVerificationRequest
- type CheckVerificationResponse
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) CheckVerification(request *CheckVerificationRequest) (response *CheckVerificationResponse, err error)
- func (client *Client) CheckVerificationWithCallback(request *CheckVerificationRequest, ...) <-chan int
- func (client *Client) CheckVerificationWithChan(request *CheckVerificationRequest) (<-chan *CheckVerificationResponse, <-chan error)
- func (client *Client) SearchVerification(request *SearchVerificationRequest) (response *SearchVerificationResponse, err error)
- func (client *Client) SearchVerificationWithCallback(request *SearchVerificationRequest, ...) <-chan int
- func (client *Client) SearchVerificationWithChan(request *SearchVerificationRequest) (<-chan *SearchVerificationResponse, <-chan error)
- func (client *Client) StartVerification(request *StartVerificationRequest) (response *StartVerificationResponse, err error)
- func (client *Client) StartVerificationWithCallback(request *StartVerificationRequest, ...) <-chan int
- func (client *Client) StartVerificationWithChan(request *StartVerificationRequest) (<-chan *StartVerificationResponse, <-chan error)
- type SearchVerificationRequest
- type SearchVerificationResponse
- type StartVerificationRequest
- type StartVerificationResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CheckVerificationRequest ¶
type CheckVerificationRequest struct {
*requests.RpcRequest
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Code string `position:"Query" name:"Code"`
ServiceSid string `position:"Query" name:"ServiceSid"`
RouteName string `position:"Query" name:"RouteName"`
VerificationId string `position:"Query" name:"VerificationId"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
OwnerId requests.Integer `position:"Query" name:"OwnerId"`
To string `position:"Query" name:"To"`
}
CheckVerificationRequest is the request struct for api CheckVerification
func CreateCheckVerificationRequest ¶
func CreateCheckVerificationRequest() (request *CheckVerificationRequest)
CreateCheckVerificationRequest creates a request to invoke CheckVerification API
type CheckVerificationResponse ¶
type CheckVerificationResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Message string `json:"Message" xml:"Message"`
Model map[string]interface{} `json:"Model" xml:"Model"`
Code string `json:"Code" xml:"Code"`
Success string `json:"Success" xml:"Success"`
}
CheckVerificationResponse is the response struct for api CheckVerification
func CreateCheckVerificationResponse ¶
func CreateCheckVerificationResponse() (response *CheckVerificationResponse)
CreateCheckVerificationResponse creates a response to parse from CheckVerification response
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) CheckVerification ¶
func (client *Client) CheckVerification(request *CheckVerificationRequest) (response *CheckVerificationResponse, err error)
CheckVerification invokes the dypnsapi_intl.CheckVerification API synchronously
func (*Client) CheckVerificationWithCallback ¶
func (client *Client) CheckVerificationWithCallback(request *CheckVerificationRequest, callback func(response *CheckVerificationResponse, err error)) <-chan int
CheckVerificationWithCallback invokes the dypnsapi_intl.CheckVerification API asynchronously
func (*Client) CheckVerificationWithChan ¶
func (client *Client) CheckVerificationWithChan(request *CheckVerificationRequest) (<-chan *CheckVerificationResponse, <-chan error)
CheckVerificationWithChan invokes the dypnsapi_intl.CheckVerification API asynchronously
func (*Client) SearchVerification ¶
func (client *Client) SearchVerification(request *SearchVerificationRequest) (response *SearchVerificationResponse, err error)
SearchVerification invokes the dypnsapi_intl.SearchVerification API synchronously
func (*Client) SearchVerificationWithCallback ¶
func (client *Client) SearchVerificationWithCallback(request *SearchVerificationRequest, callback func(response *SearchVerificationResponse, err error)) <-chan int
SearchVerificationWithCallback invokes the dypnsapi_intl.SearchVerification API asynchronously
func (*Client) SearchVerificationWithChan ¶
func (client *Client) SearchVerificationWithChan(request *SearchVerificationRequest) (<-chan *SearchVerificationResponse, <-chan error)
SearchVerificationWithChan invokes the dypnsapi_intl.SearchVerification API asynchronously
func (*Client) StartVerification ¶
func (client *Client) StartVerification(request *StartVerificationRequest) (response *StartVerificationResponse, err error)
StartVerification invokes the dypnsapi_intl.StartVerification API synchronously
func (*Client) StartVerificationWithCallback ¶
func (client *Client) StartVerificationWithCallback(request *StartVerificationRequest, callback func(response *StartVerificationResponse, err error)) <-chan int
StartVerificationWithCallback invokes the dypnsapi_intl.StartVerification API asynchronously
func (*Client) StartVerificationWithChan ¶
func (client *Client) StartVerificationWithChan(request *StartVerificationRequest) (<-chan *StartVerificationResponse, <-chan error)
StartVerificationWithChan invokes the dypnsapi_intl.StartVerification API asynchronously
type SearchVerificationRequest ¶
type SearchVerificationRequest struct {
*requests.RpcRequest
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Code string `position:"Query" name:"Code"`
ServiceSid string `position:"Query" name:"ServiceSid"`
SendDate requests.Integer `position:"Query" name:"SendDate"`
PageSize requests.Integer `position:"Query" name:"PageSize"`
RouteName string `position:"Query" name:"RouteName"`
VerificationId string `position:"Query" name:"VerificationId"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
CurrentPage requests.Integer `position:"Query" name:"CurrentPage"`
OwnerId requests.Integer `position:"Query" name:"OwnerId"`
To string `position:"Query" name:"To"`
}
SearchVerificationRequest is the request struct for api SearchVerification
func CreateSearchVerificationRequest ¶
func CreateSearchVerificationRequest() (request *SearchVerificationRequest)
CreateSearchVerificationRequest creates a request to invoke SearchVerification API
type SearchVerificationResponse ¶
type SearchVerificationResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Message string `json:"Message" xml:"Message"`
Model map[string]interface{} `json:"Model" xml:"Model"`
Code string `json:"Code" xml:"Code"`
Success bool `json:"Success" xml:"Success"`
}
SearchVerificationResponse is the response struct for api SearchVerification
func CreateSearchVerificationResponse ¶
func CreateSearchVerificationResponse() (response *SearchVerificationResponse)
CreateSearchVerificationResponse creates a response to parse from SearchVerification response
type StartVerificationRequest ¶
type StartVerificationRequest struct {
*requests.RpcRequest
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Channel string `position:"Query" name:"Channel"`
ServiceSid string `position:"Query" name:"ServiceSid"`
RouteName string `position:"Query" name:"RouteName"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
OwnerId requests.Integer `position:"Query" name:"OwnerId"`
To string `position:"Query" name:"To"`
}
StartVerificationRequest is the request struct for api StartVerification
func CreateStartVerificationRequest ¶
func CreateStartVerificationRequest() (request *StartVerificationRequest)
CreateStartVerificationRequest creates a request to invoke StartVerification API
type StartVerificationResponse ¶
type StartVerificationResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Message string `json:"Message" xml:"Message"`
Model map[string]interface{} `json:"Model" xml:"Model"`
Code string `json:"Code" xml:"Code"`
Success bool `json:"Success" xml:"Success"`
}
StartVerificationResponse is the response struct for api StartVerification
func CreateStartVerificationResponse ¶
func CreateStartVerificationResponse() (response *StartVerificationResponse)
CreateStartVerificationResponse creates a response to parse from StartVerification response