Documentation
¶
Index ¶
- type ApiList
- type Carrier
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) CreateNetworkDiagnostic(request *CreateNetworkDiagnosticRequest) (response *CreateNetworkDiagnosticResponse, err error)
- func (client *Client) CreateNetworkDiagnosticWithCallback(request *CreateNetworkDiagnosticRequest, ...) <-chan int
- func (client *Client) CreateNetworkDiagnosticWithChan(request *CreateNetworkDiagnosticRequest) (<-chan *CreateNetworkDiagnosticResponse, <-chan error)
- func (client *Client) CreateNetworkQuotaRequest(request *CreateNetworkQuotaRequestRequest) (response *CreateNetworkQuotaRequestResponse, err error)
- func (client *Client) CreateNetworkQuotaRequestWithCallback(request *CreateNetworkQuotaRequestRequest, ...) <-chan int
- func (client *Client) CreateNetworkQuotaRequestWithChan(request *CreateNetworkQuotaRequestRequest) (<-chan *CreateNetworkQuotaRequestResponse, <-chan error)
- func (client *Client) DescribeDiagnosticConfig(request *DescribeDiagnosticConfigRequest) (response *DescribeDiagnosticConfigResponse, err error)
- func (client *Client) DescribeDiagnosticConfigWithCallback(request *DescribeDiagnosticConfigRequest, ...) <-chan int
- func (client *Client) DescribeDiagnosticConfigWithChan(request *DescribeDiagnosticConfigRequest) (<-chan *DescribeDiagnosticConfigResponse, <-chan error)
- func (client *Client) DescribeIpLocationAndIsp(request *DescribeIpLocationAndIspRequest) (response *DescribeIpLocationAndIspResponse, err error)
- func (client *Client) DescribeIpLocationAndIspWithCallback(request *DescribeIpLocationAndIspRequest, ...) <-chan int
- func (client *Client) DescribeIpLocationAndIspWithChan(request *DescribeIpLocationAndIspRequest) (<-chan *DescribeIpLocationAndIspResponse, <-chan error)
- func (client *Client) DescribeIpv6LocationAndIsp(request *DescribeIpv6LocationAndIspRequest) (response *DescribeIpv6LocationAndIspResponse, err error)
- func (client *Client) DescribeIpv6LocationAndIspWithCallback(request *DescribeIpv6LocationAndIspRequest, ...) <-chan int
- func (client *Client) DescribeIpv6LocationAndIspWithChan(request *DescribeIpv6LocationAndIspRequest) (<-chan *DescribeIpv6LocationAndIspResponse, <-chan error)
- func (client *Client) DescribeNetworkAnalyticsDataTransfer(request *DescribeNetworkAnalyticsDataTransferRequest) (response *DescribeNetworkAnalyticsDataTransferResponse, err error)
- func (client *Client) DescribeNetworkAnalyticsDataTransferWithCallback(request *DescribeNetworkAnalyticsDataTransferRequest, ...) <-chan int
- func (client *Client) DescribeNetworkAnalyticsDataTransferWithChan(request *DescribeNetworkAnalyticsDataTransferRequest) (<-chan *DescribeNetworkAnalyticsDataTransferResponse, <-chan error)
- func (client *Client) DescribeNetworkAnalyticsLatency(request *DescribeNetworkAnalyticsLatencyRequest) (response *DescribeNetworkAnalyticsLatencyResponse, err error)
- func (client *Client) DescribeNetworkAnalyticsLatencyWithCallback(request *DescribeNetworkAnalyticsLatencyRequest, ...) <-chan int
- func (client *Client) DescribeNetworkAnalyticsLatencyWithChan(request *DescribeNetworkAnalyticsLatencyRequest) (<-chan *DescribeNetworkAnalyticsLatencyResponse, <-chan error)
- func (client *Client) DescribeNetworkAnalyticsNetQuality(request *DescribeNetworkAnalyticsNetQualityRequest) (response *DescribeNetworkAnalyticsNetQualityResponse, err error)
- func (client *Client) DescribeNetworkAnalyticsNetQualityWithCallback(request *DescribeNetworkAnalyticsNetQualityRequest, ...) <-chan int
- func (client *Client) DescribeNetworkAnalyticsNetQualityWithChan(request *DescribeNetworkAnalyticsNetQualityRequest) (<-chan *DescribeNetworkAnalyticsNetQualityResponse, <-chan error)
- func (client *Client) DescribeNetworkAnalyticsPacketLoss(request *DescribeNetworkAnalyticsPacketLossRequest) (response *DescribeNetworkAnalyticsPacketLossResponse, err error)
- func (client *Client) DescribeNetworkAnalyticsPacketLossWithCallback(request *DescribeNetworkAnalyticsPacketLossRequest, ...) <-chan int
- func (client *Client) DescribeNetworkAnalyticsPacketLossWithChan(request *DescribeNetworkAnalyticsPacketLossRequest) (<-chan *DescribeNetworkAnalyticsPacketLossResponse, <-chan error)
- func (client *Client) DescribeNetworkQuotaRequestResult(request *DescribeNetworkQuotaRequestResultRequest) (response *DescribeNetworkQuotaRequestResultResponse, err error)
- func (client *Client) DescribeNetworkQuotaRequestResultWithCallback(request *DescribeNetworkQuotaRequestResultRequest, ...) <-chan int
- func (client *Client) DescribeNetworkQuotaRequestResultWithChan(request *DescribeNetworkQuotaRequestResultRequest) (<-chan *DescribeNetworkQuotaRequestResultResponse, <-chan error)
- func (client *Client) DescribeNetworkQuotas(request *DescribeNetworkQuotasRequest) (response *DescribeNetworkQuotasResponse, err error)
- func (client *Client) DescribeNetworkQuotasWithCallback(request *DescribeNetworkQuotasRequest, ...) <-chan int
- func (client *Client) DescribeNetworkQuotasWithChan(request *DescribeNetworkQuotasRequest) (<-chan *DescribeNetworkQuotasResponse, <-chan error)
- type Country
- type CreateNetworkDiagnosticRequest
- type CreateNetworkDiagnosticResponse
- type CreateNetworkQuotaRequestRequest
- type CreateNetworkQuotaRequestResponse
- type DataTransferInfo
- type DataTransferInfos
- type DescribeDiagnosticConfigRequest
- type DescribeDiagnosticConfigResponse
- type DescribeIpLocationAndIspRequest
- type DescribeIpLocationAndIspResponse
- type DescribeIpv6LocationAndIspRequest
- type DescribeIpv6LocationAndIspResponse
- type DescribeNetworkAnalyticsDataTransferRequest
- type DescribeNetworkAnalyticsDataTransferResponse
- type DescribeNetworkAnalyticsLatencyRequest
- type DescribeNetworkAnalyticsLatencyResponse
- type DescribeNetworkAnalyticsNetQualityRequest
- type DescribeNetworkAnalyticsNetQualityResponse
- type DescribeNetworkAnalyticsPacketLossRequest
- type DescribeNetworkAnalyticsPacketLossResponse
- type DescribeNetworkQuotaRequestResultRequest
- type DescribeNetworkQuotaRequestResultResponse
- type DescribeNetworkQuotasRequest
- type DescribeNetworkQuotasResponse
- type NetQualities
- type NetQuality
- type NetworkQuota
- type NetworkQuotaInfo
- type NetworkQuotaInfos
- type NetworkQuotas
- type PacketLossInfo
- type PacketLossInfos
- type Privilege
- type Privileges
- type Province
- type QuotaRequest
- type QuotaRequests
- type RoundTripLatencies
- type RoundTripLatencyInfo
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApiList ¶
type ApiList struct {
ApiList []string `json:"ApiList" xml:"ApiList"`
}
ApiList is a nested struct in netana response
type Carrier ¶
type Carrier struct {
CarrierCode string `json:"CarrierCode" xml:"CarrierCode"`
CarrierEn string `json:"CarrierEn" xml:"CarrierEn"`
CarrierCn bool `json:"CarrierCn" xml:"CarrierCn"`
}
Carrier is a nested struct in netana response
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) CreateNetworkDiagnostic ¶
func (client *Client) CreateNetworkDiagnostic(request *CreateNetworkDiagnosticRequest) (response *CreateNetworkDiagnosticResponse, err error)
CreateNetworkDiagnostic invokes the netana.CreateNetworkDiagnostic API synchronously api document: https://help.aliyun.com/api/netana/createnetworkdiagnostic.html
func (*Client) CreateNetworkDiagnosticWithCallback ¶
func (client *Client) CreateNetworkDiagnosticWithCallback(request *CreateNetworkDiagnosticRequest, callback func(response *CreateNetworkDiagnosticResponse, err error)) <-chan int
CreateNetworkDiagnosticWithCallback invokes the netana.CreateNetworkDiagnostic API asynchronously api document: https://help.aliyun.com/api/netana/createnetworkdiagnostic.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CreateNetworkDiagnosticWithChan ¶
func (client *Client) CreateNetworkDiagnosticWithChan(request *CreateNetworkDiagnosticRequest) (<-chan *CreateNetworkDiagnosticResponse, <-chan error)
CreateNetworkDiagnosticWithChan invokes the netana.CreateNetworkDiagnostic API asynchronously api document: https://help.aliyun.com/api/netana/createnetworkdiagnostic.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CreateNetworkQuotaRequest ¶
func (client *Client) CreateNetworkQuotaRequest(request *CreateNetworkQuotaRequestRequest) (response *CreateNetworkQuotaRequestResponse, err error)
CreateNetworkQuotaRequest invokes the netana.CreateNetworkQuotaRequest API synchronously api document: https://help.aliyun.com/api/netana/createnetworkquotarequest.html
func (*Client) CreateNetworkQuotaRequestWithCallback ¶
func (client *Client) CreateNetworkQuotaRequestWithCallback(request *CreateNetworkQuotaRequestRequest, callback func(response *CreateNetworkQuotaRequestResponse, err error)) <-chan int
CreateNetworkQuotaRequestWithCallback invokes the netana.CreateNetworkQuotaRequest API asynchronously api document: https://help.aliyun.com/api/netana/createnetworkquotarequest.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) CreateNetworkQuotaRequestWithChan ¶
func (client *Client) CreateNetworkQuotaRequestWithChan(request *CreateNetworkQuotaRequestRequest) (<-chan *CreateNetworkQuotaRequestResponse, <-chan error)
CreateNetworkQuotaRequestWithChan invokes the netana.CreateNetworkQuotaRequest API asynchronously api document: https://help.aliyun.com/api/netana/createnetworkquotarequest.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeDiagnosticConfig ¶
func (client *Client) DescribeDiagnosticConfig(request *DescribeDiagnosticConfigRequest) (response *DescribeDiagnosticConfigResponse, err error)
DescribeDiagnosticConfig invokes the netana.DescribeDiagnosticConfig API synchronously api document: https://help.aliyun.com/api/netana/describediagnosticconfig.html
func (*Client) DescribeDiagnosticConfigWithCallback ¶
func (client *Client) DescribeDiagnosticConfigWithCallback(request *DescribeDiagnosticConfigRequest, callback func(response *DescribeDiagnosticConfigResponse, err error)) <-chan int
DescribeDiagnosticConfigWithCallback invokes the netana.DescribeDiagnosticConfig API asynchronously api document: https://help.aliyun.com/api/netana/describediagnosticconfig.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeDiagnosticConfigWithChan ¶
func (client *Client) DescribeDiagnosticConfigWithChan(request *DescribeDiagnosticConfigRequest) (<-chan *DescribeDiagnosticConfigResponse, <-chan error)
DescribeDiagnosticConfigWithChan invokes the netana.DescribeDiagnosticConfig API asynchronously api document: https://help.aliyun.com/api/netana/describediagnosticconfig.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeIpLocationAndIsp ¶
func (client *Client) DescribeIpLocationAndIsp(request *DescribeIpLocationAndIspRequest) (response *DescribeIpLocationAndIspResponse, err error)
DescribeIpLocationAndIsp invokes the netana.DescribeIpLocationAndIsp API synchronously api document: https://help.aliyun.com/api/netana/describeiplocationandisp.html
func (*Client) DescribeIpLocationAndIspWithCallback ¶
func (client *Client) DescribeIpLocationAndIspWithCallback(request *DescribeIpLocationAndIspRequest, callback func(response *DescribeIpLocationAndIspResponse, err error)) <-chan int
DescribeIpLocationAndIspWithCallback invokes the netana.DescribeIpLocationAndIsp API asynchronously api document: https://help.aliyun.com/api/netana/describeiplocationandisp.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeIpLocationAndIspWithChan ¶
func (client *Client) DescribeIpLocationAndIspWithChan(request *DescribeIpLocationAndIspRequest) (<-chan *DescribeIpLocationAndIspResponse, <-chan error)
DescribeIpLocationAndIspWithChan invokes the netana.DescribeIpLocationAndIsp API asynchronously api document: https://help.aliyun.com/api/netana/describeiplocationandisp.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeIpv6LocationAndIsp ¶
func (client *Client) DescribeIpv6LocationAndIsp(request *DescribeIpv6LocationAndIspRequest) (response *DescribeIpv6LocationAndIspResponse, err error)
DescribeIpv6LocationAndIsp invokes the netana.DescribeIpv6LocationAndIsp API synchronously api document: https://help.aliyun.com/api/netana/describeipv6locationandisp.html
func (*Client) DescribeIpv6LocationAndIspWithCallback ¶
func (client *Client) DescribeIpv6LocationAndIspWithCallback(request *DescribeIpv6LocationAndIspRequest, callback func(response *DescribeIpv6LocationAndIspResponse, err error)) <-chan int
DescribeIpv6LocationAndIspWithCallback invokes the netana.DescribeIpv6LocationAndIsp API asynchronously api document: https://help.aliyun.com/api/netana/describeipv6locationandisp.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeIpv6LocationAndIspWithChan ¶
func (client *Client) DescribeIpv6LocationAndIspWithChan(request *DescribeIpv6LocationAndIspRequest) (<-chan *DescribeIpv6LocationAndIspResponse, <-chan error)
DescribeIpv6LocationAndIspWithChan invokes the netana.DescribeIpv6LocationAndIsp API asynchronously api document: https://help.aliyun.com/api/netana/describeipv6locationandisp.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkAnalyticsDataTransfer ¶
func (client *Client) DescribeNetworkAnalyticsDataTransfer(request *DescribeNetworkAnalyticsDataTransferRequest) (response *DescribeNetworkAnalyticsDataTransferResponse, err error)
DescribeNetworkAnalyticsDataTransfer invokes the netana.DescribeNetworkAnalyticsDataTransfer API synchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticsdatatransfer.html
func (*Client) DescribeNetworkAnalyticsDataTransferWithCallback ¶
func (client *Client) DescribeNetworkAnalyticsDataTransferWithCallback(request *DescribeNetworkAnalyticsDataTransferRequest, callback func(response *DescribeNetworkAnalyticsDataTransferResponse, err error)) <-chan int
DescribeNetworkAnalyticsDataTransferWithCallback invokes the netana.DescribeNetworkAnalyticsDataTransfer API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticsdatatransfer.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkAnalyticsDataTransferWithChan ¶
func (client *Client) DescribeNetworkAnalyticsDataTransferWithChan(request *DescribeNetworkAnalyticsDataTransferRequest) (<-chan *DescribeNetworkAnalyticsDataTransferResponse, <-chan error)
DescribeNetworkAnalyticsDataTransferWithChan invokes the netana.DescribeNetworkAnalyticsDataTransfer API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticsdatatransfer.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkAnalyticsLatency ¶
func (client *Client) DescribeNetworkAnalyticsLatency(request *DescribeNetworkAnalyticsLatencyRequest) (response *DescribeNetworkAnalyticsLatencyResponse, err error)
DescribeNetworkAnalyticsLatency invokes the netana.DescribeNetworkAnalyticsLatency API synchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticslatency.html
func (*Client) DescribeNetworkAnalyticsLatencyWithCallback ¶
func (client *Client) DescribeNetworkAnalyticsLatencyWithCallback(request *DescribeNetworkAnalyticsLatencyRequest, callback func(response *DescribeNetworkAnalyticsLatencyResponse, err error)) <-chan int
DescribeNetworkAnalyticsLatencyWithCallback invokes the netana.DescribeNetworkAnalyticsLatency API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticslatency.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkAnalyticsLatencyWithChan ¶
func (client *Client) DescribeNetworkAnalyticsLatencyWithChan(request *DescribeNetworkAnalyticsLatencyRequest) (<-chan *DescribeNetworkAnalyticsLatencyResponse, <-chan error)
DescribeNetworkAnalyticsLatencyWithChan invokes the netana.DescribeNetworkAnalyticsLatency API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticslatency.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkAnalyticsNetQuality ¶
func (client *Client) DescribeNetworkAnalyticsNetQuality(request *DescribeNetworkAnalyticsNetQualityRequest) (response *DescribeNetworkAnalyticsNetQualityResponse, err error)
DescribeNetworkAnalyticsNetQuality invokes the netana.DescribeNetworkAnalyticsNetQuality API synchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticsnetquality.html
func (*Client) DescribeNetworkAnalyticsNetQualityWithCallback ¶
func (client *Client) DescribeNetworkAnalyticsNetQualityWithCallback(request *DescribeNetworkAnalyticsNetQualityRequest, callback func(response *DescribeNetworkAnalyticsNetQualityResponse, err error)) <-chan int
DescribeNetworkAnalyticsNetQualityWithCallback invokes the netana.DescribeNetworkAnalyticsNetQuality API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticsnetquality.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkAnalyticsNetQualityWithChan ¶
func (client *Client) DescribeNetworkAnalyticsNetQualityWithChan(request *DescribeNetworkAnalyticsNetQualityRequest) (<-chan *DescribeNetworkAnalyticsNetQualityResponse, <-chan error)
DescribeNetworkAnalyticsNetQualityWithChan invokes the netana.DescribeNetworkAnalyticsNetQuality API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticsnetquality.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkAnalyticsPacketLoss ¶
func (client *Client) DescribeNetworkAnalyticsPacketLoss(request *DescribeNetworkAnalyticsPacketLossRequest) (response *DescribeNetworkAnalyticsPacketLossResponse, err error)
DescribeNetworkAnalyticsPacketLoss invokes the netana.DescribeNetworkAnalyticsPacketLoss API synchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticspacketloss.html
func (*Client) DescribeNetworkAnalyticsPacketLossWithCallback ¶
func (client *Client) DescribeNetworkAnalyticsPacketLossWithCallback(request *DescribeNetworkAnalyticsPacketLossRequest, callback func(response *DescribeNetworkAnalyticsPacketLossResponse, err error)) <-chan int
DescribeNetworkAnalyticsPacketLossWithCallback invokes the netana.DescribeNetworkAnalyticsPacketLoss API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticspacketloss.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkAnalyticsPacketLossWithChan ¶
func (client *Client) DescribeNetworkAnalyticsPacketLossWithChan(request *DescribeNetworkAnalyticsPacketLossRequest) (<-chan *DescribeNetworkAnalyticsPacketLossResponse, <-chan error)
DescribeNetworkAnalyticsPacketLossWithChan invokes the netana.DescribeNetworkAnalyticsPacketLoss API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkanalyticspacketloss.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkQuotaRequestResult ¶
func (client *Client) DescribeNetworkQuotaRequestResult(request *DescribeNetworkQuotaRequestResultRequest) (response *DescribeNetworkQuotaRequestResultResponse, err error)
DescribeNetworkQuotaRequestResult invokes the netana.DescribeNetworkQuotaRequestResult API synchronously api document: https://help.aliyun.com/api/netana/describenetworkquotarequestresult.html
func (*Client) DescribeNetworkQuotaRequestResultWithCallback ¶
func (client *Client) DescribeNetworkQuotaRequestResultWithCallback(request *DescribeNetworkQuotaRequestResultRequest, callback func(response *DescribeNetworkQuotaRequestResultResponse, err error)) <-chan int
DescribeNetworkQuotaRequestResultWithCallback invokes the netana.DescribeNetworkQuotaRequestResult API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkquotarequestresult.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkQuotaRequestResultWithChan ¶
func (client *Client) DescribeNetworkQuotaRequestResultWithChan(request *DescribeNetworkQuotaRequestResultRequest) (<-chan *DescribeNetworkQuotaRequestResultResponse, <-chan error)
DescribeNetworkQuotaRequestResultWithChan invokes the netana.DescribeNetworkQuotaRequestResult API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkquotarequestresult.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkQuotas ¶
func (client *Client) DescribeNetworkQuotas(request *DescribeNetworkQuotasRequest) (response *DescribeNetworkQuotasResponse, err error)
DescribeNetworkQuotas invokes the netana.DescribeNetworkQuotas API synchronously api document: https://help.aliyun.com/api/netana/describenetworkquotas.html
func (*Client) DescribeNetworkQuotasWithCallback ¶
func (client *Client) DescribeNetworkQuotasWithCallback(request *DescribeNetworkQuotasRequest, callback func(response *DescribeNetworkQuotasResponse, err error)) <-chan int
DescribeNetworkQuotasWithCallback invokes the netana.DescribeNetworkQuotas API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkquotas.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
func (*Client) DescribeNetworkQuotasWithChan ¶
func (client *Client) DescribeNetworkQuotasWithChan(request *DescribeNetworkQuotasRequest) (<-chan *DescribeNetworkQuotasResponse, <-chan error)
DescribeNetworkQuotasWithChan invokes the netana.DescribeNetworkQuotas API asynchronously api document: https://help.aliyun.com/api/netana/describenetworkquotas.html asynchronous document: https://help.aliyun.com/document_detail/66220.html
type Country ¶
type Country struct {
CountryEn string `json:"CountryEn" xml:"CountryEn"`
CountryCn bool `json:"CountryCn" xml:"CountryCn"`
CountryCode string `json:"CountryCode" xml:"CountryCode"`
}
Country is a nested struct in netana response
type CreateNetworkDiagnosticRequest ¶
type CreateNetworkDiagnosticRequest struct {
*requests.RpcRequest
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
RequestParams string `position:"Query" name:"RequestParams"`
InstanceId string `position:"Query" name:"InstanceId"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
UserRequestId string `position:"Query" name:"UserRequestId"`
Type string `position:"Query" name:"Type"`
RequestApiName string `position:"Query" name:"RequestApiName"`
ErrorCode string `position:"Query" name:"ErrorCode"`
ProductType string `position:"Query" name:"ProductType"`
ResponseParams string `position:"Query" name:"ResponseParams"`
}
CreateNetworkDiagnosticRequest is the request struct for api CreateNetworkDiagnostic
func CreateCreateNetworkDiagnosticRequest ¶
func CreateCreateNetworkDiagnosticRequest() (request *CreateNetworkDiagnosticRequest)
CreateCreateNetworkDiagnosticRequest creates a request to invoke CreateNetworkDiagnostic API
type CreateNetworkDiagnosticResponse ¶
type CreateNetworkDiagnosticResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Status string `json:"Status" xml:"Status"`
Tpl string `json:"Tpl" xml:"Tpl"`
Params string `json:"Params" xml:"Params"`
}
CreateNetworkDiagnosticResponse is the response struct for api CreateNetworkDiagnostic
func CreateCreateNetworkDiagnosticResponse ¶
func CreateCreateNetworkDiagnosticResponse() (response *CreateNetworkDiagnosticResponse)
CreateCreateNetworkDiagnosticResponse creates a response to parse from CreateNetworkDiagnostic response
type CreateNetworkQuotaRequestRequest ¶
type CreateNetworkQuotaRequestRequest struct {
*requests.RpcRequest
RequestReason string `position:"Query" name:"RequestReason"`
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Product string `position:"Query" name:"Product"`
QuotaPublicityName string `position:"Query" name:"QuotaPublicityName"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
RequestQuantity string `position:"Query" name:"RequestQuantity"`
MobilePhone string `position:"Query" name:"MobilePhone"`
ResourceType string `position:"Query" name:"ResourceType"`
Email string `position:"Query" name:"Email"`
}
CreateNetworkQuotaRequestRequest is the request struct for api CreateNetworkQuotaRequest
func CreateCreateNetworkQuotaRequestRequest ¶
func CreateCreateNetworkQuotaRequestRequest() (request *CreateNetworkQuotaRequestRequest)
CreateCreateNetworkQuotaRequestRequest creates a request to invoke CreateNetworkQuotaRequest API
type CreateNetworkQuotaRequestResponse ¶
type CreateNetworkQuotaRequestResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
}
CreateNetworkQuotaRequestResponse is the response struct for api CreateNetworkQuotaRequest
func CreateCreateNetworkQuotaRequestResponse ¶
func CreateCreateNetworkQuotaRequestResponse() (response *CreateNetworkQuotaRequestResponse)
CreateCreateNetworkQuotaRequestResponse creates a response to parse from CreateNetworkQuotaRequest response
type DataTransferInfo ¶
type DataTransferInfo struct {
InBoundTotalBytes string `json:"InBoundTotalBytes" xml:"InBoundTotalBytes"`
OutBoundTotalBytes string `json:"OutBoundTotalBytes" xml:"OutBoundTotalBytes"`
DataType string `json:"DataType" xml:"DataType"`
DateTime string `json:"DateTime" xml:"DateTime"`
Ip string `json:"Ip" xml:"Ip"`
Country Country `json:"Country" xml:"Country"`
Province Province `json:"Province" xml:"Province"`
Carrier Carrier `json:"Carrier" xml:"Carrier"`
}
DataTransferInfo is a nested struct in netana response
type DataTransferInfos ¶
type DataTransferInfos struct {
DataTransferInfo []DataTransferInfo `json:"DataTransferInfo" xml:"DataTransferInfo"`
}
DataTransferInfos is a nested struct in netana response
type DescribeDiagnosticConfigRequest ¶
type DescribeDiagnosticConfigRequest struct {
*requests.RpcRequest
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
ProductType string `position:"Query" name:"ProductType"`
}
DescribeDiagnosticConfigRequest is the request struct for api DescribeDiagnosticConfig
func CreateDescribeDiagnosticConfigRequest ¶
func CreateDescribeDiagnosticConfigRequest() (request *DescribeDiagnosticConfigRequest)
CreateDescribeDiagnosticConfigRequest creates a request to invoke DescribeDiagnosticConfig API
type DescribeDiagnosticConfigResponse ¶
type DescribeDiagnosticConfigResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
ApiList ApiList `json:"ApiList" xml:"ApiList"`
}
DescribeDiagnosticConfigResponse is the response struct for api DescribeDiagnosticConfig
func CreateDescribeDiagnosticConfigResponse ¶
func CreateDescribeDiagnosticConfigResponse() (response *DescribeDiagnosticConfigResponse)
CreateDescribeDiagnosticConfigResponse creates a response to parse from DescribeDiagnosticConfig response
type DescribeIpLocationAndIspRequest ¶
type DescribeIpLocationAndIspRequest struct {
*requests.RpcRequest
IpAddress string `position:"Query" name:"IpAddress"`
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
}
DescribeIpLocationAndIspRequest is the request struct for api DescribeIpLocationAndIsp
func CreateDescribeIpLocationAndIspRequest ¶
func CreateDescribeIpLocationAndIspRequest() (request *DescribeIpLocationAndIspRequest)
CreateDescribeIpLocationAndIspRequest creates a request to invoke DescribeIpLocationAndIsp API
type DescribeIpLocationAndIspResponse ¶
type DescribeIpLocationAndIspResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
IpAddress string `json:"IpAddress" xml:"IpAddress"`
Country string `json:"Country" xml:"Country"`
City string `json:"City" xml:"City"`
ISP string `json:"ISP" xml:"ISP"`
CountryCode string `json:"CountryCode" xml:"CountryCode"`
CityCode string `json:"CityCode" xml:"CityCode"`
ISPCode string `json:"ISPCode" xml:"ISPCode"`
}
DescribeIpLocationAndIspResponse is the response struct for api DescribeIpLocationAndIsp
func CreateDescribeIpLocationAndIspResponse ¶
func CreateDescribeIpLocationAndIspResponse() (response *DescribeIpLocationAndIspResponse)
CreateDescribeIpLocationAndIspResponse creates a response to parse from DescribeIpLocationAndIsp response
type DescribeIpv6LocationAndIspRequest ¶
type DescribeIpv6LocationAndIspRequest struct {
*requests.RpcRequest
IpAddress string `position:"Query" name:"IpAddress"`
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
}
DescribeIpv6LocationAndIspRequest is the request struct for api DescribeIpv6LocationAndIsp
func CreateDescribeIpv6LocationAndIspRequest ¶
func CreateDescribeIpv6LocationAndIspRequest() (request *DescribeIpv6LocationAndIspRequest)
CreateDescribeIpv6LocationAndIspRequest creates a request to invoke DescribeIpv6LocationAndIsp API
type DescribeIpv6LocationAndIspResponse ¶
type DescribeIpv6LocationAndIspResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
IpAddress string `json:"IpAddress" xml:"IpAddress"`
Country string `json:"Country" xml:"Country"`
City string `json:"City" xml:"City"`
ISP string `json:"ISP" xml:"ISP"`
CountryCode string `json:"CountryCode" xml:"CountryCode"`
CityCode string `json:"CityCode" xml:"CityCode"`
ISPCode string `json:"ISPCode" xml:"ISPCode"`
}
DescribeIpv6LocationAndIspResponse is the response struct for api DescribeIpv6LocationAndIsp
func CreateDescribeIpv6LocationAndIspResponse ¶
func CreateDescribeIpv6LocationAndIspResponse() (response *DescribeIpv6LocationAndIspResponse)
CreateDescribeIpv6LocationAndIspResponse creates a response to parse from DescribeIpv6LocationAndIsp response
type DescribeNetworkAnalyticsDataTransferRequest ¶
type DescribeNetworkAnalyticsDataTransferRequest struct {
*requests.RpcRequest
Country string `position:"Query" name:"Country"`
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Product string `position:"Query" name:"Product"`
Period string `position:"Query" name:"Period"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
Ip string `position:"Query" name:"Ip"`
EndTime string `position:"Query" name:"EndTime"`
StartTime string `position:"Query" name:"StartTime"`
PageNumber string `position:"Query" name:"PageNumber"`
Carrier string `position:"Query" name:"Carrier"`
InstanceId string `position:"Query" name:"InstanceId"`
Province string `position:"Query" name:"Province"`
InternetChargeType string `position:"Query" name:"InternetChargeType"`
Grade string `position:"Query" name:"Grade"`
PageSize string `position:"Query" name:"PageSize"`
Direction string `position:"Query" name:"Direction"`
}
DescribeNetworkAnalyticsDataTransferRequest is the request struct for api DescribeNetworkAnalyticsDataTransfer
func CreateDescribeNetworkAnalyticsDataTransferRequest ¶
func CreateDescribeNetworkAnalyticsDataTransferRequest() (request *DescribeNetworkAnalyticsDataTransferRequest)
CreateDescribeNetworkAnalyticsDataTransferRequest creates a request to invoke DescribeNetworkAnalyticsDataTransfer API
type DescribeNetworkAnalyticsDataTransferResponse ¶
type DescribeNetworkAnalyticsDataTransferResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalCount int `json:"TotalCount" xml:"TotalCount"`
PageNumber int `json:"PageNumber" xml:"PageNumber"`
PageSize int `json:"PageSize" xml:"PageSize"`
DataTransferInfos DataTransferInfos `json:"DataTransferInfos" xml:"DataTransferInfos"`
}
DescribeNetworkAnalyticsDataTransferResponse is the response struct for api DescribeNetworkAnalyticsDataTransfer
func CreateDescribeNetworkAnalyticsDataTransferResponse ¶
func CreateDescribeNetworkAnalyticsDataTransferResponse() (response *DescribeNetworkAnalyticsDataTransferResponse)
CreateDescribeNetworkAnalyticsDataTransferResponse creates a response to parse from DescribeNetworkAnalyticsDataTransfer response
type DescribeNetworkAnalyticsLatencyRequest ¶
type DescribeNetworkAnalyticsLatencyRequest struct {
*requests.RpcRequest
Country string `position:"Query" name:"Country"`
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Product string `position:"Query" name:"Product"`
Period string `position:"Query" name:"Period"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
Ip string `position:"Query" name:"Ip"`
EndTime string `position:"Query" name:"EndTime"`
StartTime string `position:"Query" name:"StartTime"`
PageNumber string `position:"Query" name:"PageNumber"`
Carrier string `position:"Query" name:"Carrier"`
InstanceId string `position:"Query" name:"InstanceId"`
Province string `position:"Query" name:"Province"`
InternetChargeType string `position:"Query" name:"InternetChargeType"`
Grade string `position:"Query" name:"Grade"`
PageSize string `position:"Query" name:"PageSize"`
}
DescribeNetworkAnalyticsLatencyRequest is the request struct for api DescribeNetworkAnalyticsLatency
func CreateDescribeNetworkAnalyticsLatencyRequest ¶
func CreateDescribeNetworkAnalyticsLatencyRequest() (request *DescribeNetworkAnalyticsLatencyRequest)
CreateDescribeNetworkAnalyticsLatencyRequest creates a request to invoke DescribeNetworkAnalyticsLatency API
type DescribeNetworkAnalyticsLatencyResponse ¶
type DescribeNetworkAnalyticsLatencyResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalCount int `json:"TotalCount" xml:"TotalCount"`
PageNumber int `json:"PageNumber" xml:"PageNumber"`
PageSize int `json:"PageSize" xml:"PageSize"`
RoundTripLatencies RoundTripLatencies `json:"RoundTripLatencies" xml:"RoundTripLatencies"`
}
DescribeNetworkAnalyticsLatencyResponse is the response struct for api DescribeNetworkAnalyticsLatency
func CreateDescribeNetworkAnalyticsLatencyResponse ¶
func CreateDescribeNetworkAnalyticsLatencyResponse() (response *DescribeNetworkAnalyticsLatencyResponse)
CreateDescribeNetworkAnalyticsLatencyResponse creates a response to parse from DescribeNetworkAnalyticsLatency response
type DescribeNetworkAnalyticsNetQualityRequest ¶
type DescribeNetworkAnalyticsNetQualityRequest struct {
*requests.RpcRequest
Country string `position:"Query" name:"Country"`
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Period string `position:"Query" name:"Period"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
EndTime string `position:"Query" name:"EndTime"`
StartTime string `position:"Query" name:"StartTime"`
PageNumber string `position:"Query" name:"PageNumber"`
Carrier string `position:"Query" name:"Carrier"`
Province string `position:"Query" name:"Province"`
Grade string `position:"Query" name:"Grade"`
PageSize string `position:"Query" name:"PageSize"`
}
DescribeNetworkAnalyticsNetQualityRequest is the request struct for api DescribeNetworkAnalyticsNetQuality
func CreateDescribeNetworkAnalyticsNetQualityRequest ¶
func CreateDescribeNetworkAnalyticsNetQualityRequest() (request *DescribeNetworkAnalyticsNetQualityRequest)
CreateDescribeNetworkAnalyticsNetQualityRequest creates a request to invoke DescribeNetworkAnalyticsNetQuality API
type DescribeNetworkAnalyticsNetQualityResponse ¶
type DescribeNetworkAnalyticsNetQualityResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalCount int `json:"TotalCount" xml:"TotalCount"`
PageNumber int `json:"PageNumber" xml:"PageNumber"`
PageSize int `json:"PageSize" xml:"PageSize"`
NetQualities NetQualities `json:"NetQualities" xml:"NetQualities"`
}
DescribeNetworkAnalyticsNetQualityResponse is the response struct for api DescribeNetworkAnalyticsNetQuality
func CreateDescribeNetworkAnalyticsNetQualityResponse ¶
func CreateDescribeNetworkAnalyticsNetQualityResponse() (response *DescribeNetworkAnalyticsNetQualityResponse)
CreateDescribeNetworkAnalyticsNetQualityResponse creates a response to parse from DescribeNetworkAnalyticsNetQuality response
type DescribeNetworkAnalyticsPacketLossRequest ¶
type DescribeNetworkAnalyticsPacketLossRequest struct {
*requests.RpcRequest
Country string `position:"Query" name:"Country"`
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Product string `position:"Query" name:"Product"`
Period string `position:"Query" name:"Period"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
Ip string `position:"Query" name:"Ip"`
EndTime string `position:"Query" name:"EndTime"`
StartTime string `position:"Query" name:"StartTime"`
PageNumber string `position:"Query" name:"PageNumber"`
Carrier string `position:"Query" name:"Carrier"`
InstanceId string `position:"Query" name:"InstanceId"`
Province string `position:"Query" name:"Province"`
InternetChargeType string `position:"Query" name:"InternetChargeType"`
Grade string `position:"Query" name:"Grade"`
PageSize string `position:"Query" name:"PageSize"`
Direction string `position:"Query" name:"Direction"`
}
DescribeNetworkAnalyticsPacketLossRequest is the request struct for api DescribeNetworkAnalyticsPacketLoss
func CreateDescribeNetworkAnalyticsPacketLossRequest ¶
func CreateDescribeNetworkAnalyticsPacketLossRequest() (request *DescribeNetworkAnalyticsPacketLossRequest)
CreateDescribeNetworkAnalyticsPacketLossRequest creates a request to invoke DescribeNetworkAnalyticsPacketLoss API
type DescribeNetworkAnalyticsPacketLossResponse ¶
type DescribeNetworkAnalyticsPacketLossResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalCount int `json:"TotalCount" xml:"TotalCount"`
PageNumber int `json:"PageNumber" xml:"PageNumber"`
PageSize int `json:"PageSize" xml:"PageSize"`
PacketLossInfos PacketLossInfos `json:"PacketLossInfos" xml:"PacketLossInfos"`
}
DescribeNetworkAnalyticsPacketLossResponse is the response struct for api DescribeNetworkAnalyticsPacketLoss
func CreateDescribeNetworkAnalyticsPacketLossResponse ¶
func CreateDescribeNetworkAnalyticsPacketLossResponse() (response *DescribeNetworkAnalyticsPacketLossResponse)
CreateDescribeNetworkAnalyticsPacketLossResponse creates a response to parse from DescribeNetworkAnalyticsPacketLoss response
type DescribeNetworkQuotaRequestResultRequest ¶
type DescribeNetworkQuotaRequestResultRequest struct {
*requests.RpcRequest
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Product string `position:"Query" name:"Product"`
QuotaPublicityName string `position:"Query" name:"QuotaPublicityName"`
QuotaRequestId string `position:"Query" name:"QuotaRequestId"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
PageNo string `position:"Query" name:"PageNo"`
PageSize string `position:"Query" name:"PageSize"`
ResourceType string `position:"Query" name:"ResourceType"`
}
DescribeNetworkQuotaRequestResultRequest is the request struct for api DescribeNetworkQuotaRequestResult
func CreateDescribeNetworkQuotaRequestResultRequest ¶
func CreateDescribeNetworkQuotaRequestResultRequest() (request *DescribeNetworkQuotaRequestResultRequest)
CreateDescribeNetworkQuotaRequestResultRequest creates a request to invoke DescribeNetworkQuotaRequestResult API
type DescribeNetworkQuotaRequestResultResponse ¶
type DescribeNetworkQuotaRequestResultResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalCount int `json:"TotalCount" xml:"TotalCount"`
PageNumber int `json:"PageNumber" xml:"PageNumber"`
PageSize int `json:"PageSize" xml:"PageSize"`
QuotaRequests QuotaRequests `json:"QuotaRequests" xml:"QuotaRequests"`
}
DescribeNetworkQuotaRequestResultResponse is the response struct for api DescribeNetworkQuotaRequestResult
func CreateDescribeNetworkQuotaRequestResultResponse ¶
func CreateDescribeNetworkQuotaRequestResultResponse() (response *DescribeNetworkQuotaRequestResultResponse)
CreateDescribeNetworkQuotaRequestResultResponse creates a response to parse from DescribeNetworkQuotaRequestResult response
type DescribeNetworkQuotasRequest ¶
type DescribeNetworkQuotasRequest struct {
*requests.RpcRequest
ResourceOwnerId requests.Integer `position:"Query" name:"ResourceOwnerId"`
Product string `position:"Query" name:"Product"`
QuotaPublicityName string `position:"Query" name:"QuotaPublicityName"`
ResourceOwnerAccount string `position:"Query" name:"ResourceOwnerAccount"`
ResourceType string `position:"Query" name:"ResourceType"`
}
DescribeNetworkQuotasRequest is the request struct for api DescribeNetworkQuotas
func CreateDescribeNetworkQuotasRequest ¶
func CreateDescribeNetworkQuotasRequest() (request *DescribeNetworkQuotasRequest)
CreateDescribeNetworkQuotasRequest creates a request to invoke DescribeNetworkQuotas API
type DescribeNetworkQuotasResponse ¶
type DescribeNetworkQuotasResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
TotalCount int `json:"TotalCount" xml:"TotalCount"`
NetworkQuotas NetworkQuotas `json:"NetworkQuotas" xml:"NetworkQuotas"`
}
DescribeNetworkQuotasResponse is the response struct for api DescribeNetworkQuotas
func CreateDescribeNetworkQuotasResponse ¶
func CreateDescribeNetworkQuotasResponse() (response *DescribeNetworkQuotasResponse)
CreateDescribeNetworkQuotasResponse creates a response to parse from DescribeNetworkQuotas response
type NetQualities ¶
type NetQualities struct {
NetQuality []NetQuality `json:"NetQuality" xml:"NetQuality"`
}
NetQualities is a nested struct in netana response
type NetQuality ¶
type NetQuality struct {
RoundTripLatency string `json:"RoundTripLatency" xml:"RoundTripLatency"`
NetLevel string `json:"NetLevel" xml:"NetLevel"`
DataType string `json:"DataType" xml:"DataType"`
DateTime string `json:"DateTime" xml:"DateTime"`
Country Country `json:"Country" xml:"Country"`
Province Province `json:"Province" xml:"Province"`
Carrier Carrier `json:"Carrier" xml:"Carrier"`
}
NetQuality is a nested struct in netana response
type NetworkQuota ¶
type NetworkQuota struct {
Product string `json:"Product" xml:"Product"`
ResourceType string `json:"ResourceType" xml:"ResourceType"`
Privileges Privileges `json:"Privileges" xml:"Privileges"`
NetworkQuotaInfos NetworkQuotaInfos `json:"NetworkQuotaInfos" xml:"NetworkQuotaInfos"`
}
NetworkQuota is a nested struct in netana response
type NetworkQuotaInfo ¶
type NetworkQuotaInfo struct {
QuotaName string `json:"QuotaName" xml:"QuotaName"`
QuotaDescription string `json:"QuotaDescription" xml:"QuotaDescription"`
QuotaQuantity string `json:"QuotaQuantity" xml:"QuotaQuantity"`
InstanceQuantity string `json:"InstanceQuantity" xml:"InstanceQuantity"`
CanExceptional string `json:"CanExceptional" xml:"CanExceptional"`
QuotaDescriptionCn string `json:"QuotaDescriptionCn" xml:"QuotaDescriptionCn"`
Sequence string `json:"Sequence" xml:"Sequence"`
}
NetworkQuotaInfo is a nested struct in netana response
type NetworkQuotaInfos ¶
type NetworkQuotaInfos struct {
NetworkQuotaInfo []NetworkQuotaInfo `json:"NetworkQuotaInfo" xml:"NetworkQuotaInfo"`
}
NetworkQuotaInfos is a nested struct in netana response
type NetworkQuotas ¶
type NetworkQuotas struct {
NetworkQuota []NetworkQuota `json:"NetworkQuota" xml:"NetworkQuota"`
}
NetworkQuotas is a nested struct in netana response
type PacketLossInfo ¶
type PacketLossInfo struct {
InBoundTotalPacket string `json:"InBoundTotalPacket" xml:"InBoundTotalPacket"`
OutBoundTotalPacket string `json:"OutBoundTotalPacket" xml:"OutBoundTotalPacket"`
DataType string `json:"DataType" xml:"DataType"`
DateTime string `json:"DateTime" xml:"DateTime"`
Ip string `json:"Ip" xml:"Ip"`
Country Country `json:"Country" xml:"Country"`
Province Province `json:"Province" xml:"Province"`
Carrier Carrier `json:"Carrier" xml:"Carrier"`
}
PacketLossInfo is a nested struct in netana response
type PacketLossInfos ¶
type PacketLossInfos struct {
PacketLossInfo []PacketLossInfo `json:"PacketLossInfo" xml:"PacketLossInfo"`
}
PacketLossInfos is a nested struct in netana response
type Privilege ¶
type Privilege struct {
Privilege string `json:"Privilege" xml:"Privilege"`
Description string `json:"Description" xml:"Description"`
Enabled bool `json:"Enabled" xml:"Enabled"`
DescriptionCn string `json:"DescriptionCn" xml:"DescriptionCn"`
}
Privilege is a nested struct in netana response
type Privileges ¶
type Privileges struct {
Privilege []Privilege `json:"Privilege" xml:"Privilege"`
}
Privileges is a nested struct in netana response
type Province ¶
type Province struct {
ProvinceCn bool `json:"ProvinceCn" xml:"ProvinceCn"`
ProvinceEn string `json:"ProvinceEn" xml:"ProvinceEn"`
ProvinceCode string `json:"ProvinceCode" xml:"ProvinceCode"`
}
Province is a nested struct in netana response
type QuotaRequest ¶
type QuotaRequest struct {
RegionId string `json:"RegionId" xml:"RegionId"`
Product string `json:"Product" xml:"Product"`
ResourceType string `json:"ResourceType" xml:"ResourceType"`
QuotaPublicityName string `json:"QuotaPublicityName" xml:"QuotaPublicityName"`
RequestReason string `json:"RequestReason" xml:"RequestReason"`
MobilePhone string `json:"MobilePhone" xml:"MobilePhone"`
Email string `json:"Email" xml:"Email"`
RequestResult string `json:"RequestResult" xml:"RequestResult"`
ResultQuantity string `json:"ResultQuantity" xml:"ResultQuantity"`
ResultReason string `json:"ResultReason" xml:"ResultReason"`
RequestId string `json:"RequestId" xml:"RequestId"`
CreateTime string `json:"CreateTime" xml:"CreateTime"`
RequestQuantity string `json:"RequestQuantity" xml:"RequestQuantity"`
}
QuotaRequest is a nested struct in netana response
type QuotaRequests ¶
type QuotaRequests struct {
QuotaRequest []QuotaRequest `json:"QuotaRequest" xml:"QuotaRequest"`
}
QuotaRequests is a nested struct in netana response
type RoundTripLatencies ¶
type RoundTripLatencies struct {
RoundTripLatencyInfo []RoundTripLatencyInfo `json:"RoundTripLatencyInfo" xml:"RoundTripLatencyInfo"`
}
RoundTripLatencies is a nested struct in netana response
type RoundTripLatencyInfo ¶
type RoundTripLatencyInfo struct {
RoundTripLatency string `json:"RoundTripLatency" xml:"RoundTripLatency"`
DataType string `json:"DataType" xml:"DataType"`
DateTime string `json:"DateTime" xml:"DateTime"`
Ip string `json:"Ip" xml:"Ip"`
Country Country `json:"Country" xml:"Country"`
Province Province `json:"Province" xml:"Province"`
Carrier Carrier `json:"Carrier" xml:"Carrier"`
}
RoundTripLatencyInfo is a nested struct in netana response
Source Files
¶
- client.go
- create_network_diagnostic.go
- create_network_quota_request.go
- describe_diagnostic_config.go
- describe_ip_location_and_isp.go
- describe_ipv6_location_and_isp.go
- describe_network_analytics_data_transfer.go
- describe_network_analytics_latency.go
- describe_network_analytics_net_quality.go
- describe_network_analytics_packet_loss.go
- describe_network_quota_request_result.go
- describe_network_quotas.go
- struct_api_list.go
- struct_carrier.go
- struct_country.go
- struct_data_transfer_info.go
- struct_data_transfer_infos.go
- struct_net_qualities.go
- struct_net_quality.go
- struct_network_quota.go
- struct_network_quota_info.go
- struct_network_quota_infos.go
- struct_network_quotas.go
- struct_packet_loss_info.go
- struct_packet_loss_infos.go
- struct_privilege.go
- struct_privileges.go
- struct_province.go
- struct_quota_request.go
- struct_quota_requests.go
- struct_round_trip_latencies.go
- struct_round_trip_latency_info.go