Documentation
¶
Index ¶
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) DescribeDomainReport(request *DescribeDomainReportRequest) (response *DescribeDomainReportResponse, err error)
- func (client *Client) DescribeDomainReportWithCallback(request *DescribeDomainReportRequest, ...) <-chan int
- func (client *Client) DescribeDomainReportWithChan(request *DescribeDomainReportRequest) (<-chan *DescribeDomainReportResponse, <-chan error)
- func (client *Client) DescribeFileReport(request *DescribeFileReportRequest) (response *DescribeFileReportResponse, err error)
- func (client *Client) DescribeFileReportWithCallback(request *DescribeFileReportRequest, ...) <-chan int
- func (client *Client) DescribeFileReportWithChan(request *DescribeFileReportRequest) (<-chan *DescribeFileReportResponse, <-chan error)
- func (client *Client) DescribeIpReport(request *DescribeIpReportRequest) (response *DescribeIpReportResponse, err error)
- func (client *Client) DescribeIpReportWithCallback(request *DescribeIpReportRequest, ...) <-chan int
- func (client *Client) DescribeIpReportWithChan(request *DescribeIpReportRequest) (<-chan *DescribeIpReportResponse, <-chan error)
- func (client *Client) GetGraphQueryTemplates(request *GetGraphQueryTemplatesRequest) (response *GetGraphQueryTemplatesResponse, err error)
- func (client *Client) GetGraphQueryTemplatesWithCallback(request *GetGraphQueryTemplatesRequest, ...) <-chan int
- func (client *Client) GetGraphQueryTemplatesWithChan(request *GetGraphQueryTemplatesRequest) (<-chan *GetGraphQueryTemplatesResponse, <-chan error)
- type Data
- type DataItem
- type DescribeDomainReportRequest
- type DescribeDomainReportResponse
- type DescribeFileReportRequest
- type DescribeFileReportResponse
- type DescribeIpReportRequest
- type DescribeIpReportResponse
- type GetGraphQueryTemplatesRequest
- type GetGraphQueryTemplatesResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) DescribeDomainReport ¶
func (client *Client) DescribeDomainReport(request *DescribeDomainReportRequest) (response *DescribeDomainReportResponse, err error)
DescribeDomainReport invokes the sasti.DescribeDomainReport API synchronously
func (*Client) DescribeDomainReportWithCallback ¶
func (client *Client) DescribeDomainReportWithCallback(request *DescribeDomainReportRequest, callback func(response *DescribeDomainReportResponse, err error)) <-chan int
DescribeDomainReportWithCallback invokes the sasti.DescribeDomainReport API asynchronously
func (*Client) DescribeDomainReportWithChan ¶
func (client *Client) DescribeDomainReportWithChan(request *DescribeDomainReportRequest) (<-chan *DescribeDomainReportResponse, <-chan error)
DescribeDomainReportWithChan invokes the sasti.DescribeDomainReport API asynchronously
func (*Client) DescribeFileReport ¶
func (client *Client) DescribeFileReport(request *DescribeFileReportRequest) (response *DescribeFileReportResponse, err error)
DescribeFileReport invokes the sasti.DescribeFileReport API synchronously
func (*Client) DescribeFileReportWithCallback ¶
func (client *Client) DescribeFileReportWithCallback(request *DescribeFileReportRequest, callback func(response *DescribeFileReportResponse, err error)) <-chan int
DescribeFileReportWithCallback invokes the sasti.DescribeFileReport API asynchronously
func (*Client) DescribeFileReportWithChan ¶
func (client *Client) DescribeFileReportWithChan(request *DescribeFileReportRequest) (<-chan *DescribeFileReportResponse, <-chan error)
DescribeFileReportWithChan invokes the sasti.DescribeFileReport API asynchronously
func (*Client) DescribeIpReport ¶
func (client *Client) DescribeIpReport(request *DescribeIpReportRequest) (response *DescribeIpReportResponse, err error)
DescribeIpReport invokes the sasti.DescribeIpReport API synchronously
func (*Client) DescribeIpReportWithCallback ¶
func (client *Client) DescribeIpReportWithCallback(request *DescribeIpReportRequest, callback func(response *DescribeIpReportResponse, err error)) <-chan int
DescribeIpReportWithCallback invokes the sasti.DescribeIpReport API asynchronously
func (*Client) DescribeIpReportWithChan ¶
func (client *Client) DescribeIpReportWithChan(request *DescribeIpReportRequest) (<-chan *DescribeIpReportResponse, <-chan error)
DescribeIpReportWithChan invokes the sasti.DescribeIpReport API asynchronously
func (*Client) GetGraphQueryTemplates ¶
func (client *Client) GetGraphQueryTemplates(request *GetGraphQueryTemplatesRequest) (response *GetGraphQueryTemplatesResponse, err error)
GetGraphQueryTemplates invokes the sasti.GetGraphQueryTemplates API synchronously
func (*Client) GetGraphQueryTemplatesWithCallback ¶
func (client *Client) GetGraphQueryTemplatesWithCallback(request *GetGraphQueryTemplatesRequest, callback func(response *GetGraphQueryTemplatesResponse, err error)) <-chan int
GetGraphQueryTemplatesWithCallback invokes the sasti.GetGraphQueryTemplates API asynchronously
func (*Client) GetGraphQueryTemplatesWithChan ¶
func (client *Client) GetGraphQueryTemplatesWithChan(request *GetGraphQueryTemplatesRequest) (<-chan *GetGraphQueryTemplatesResponse, <-chan error)
GetGraphQueryTemplatesWithChan invokes the sasti.GetGraphQueryTemplates API asynchronously
type Data ¶
type Data struct {
DataItem []DataItem `json:"Data" xml:"Data"`
}
Data is a nested struct in sasti response
type DataItem ¶
type DataItem struct {
Id int64 `json:"Id" xml:"Id"`
GmtCreate string `json:"GmtCreate" xml:"GmtCreate"`
GmtModified string `json:"GmtModified" xml:"GmtModified"`
Scenario string `json:"Scenario" xml:"Scenario"`
GremlinTemplate string `json:"GremlinTemplate" xml:"GremlinTemplate"`
LastModifier string `json:"LastModifier" xml:"LastModifier"`
Status int `json:"Status" xml:"Status"`
ScenarioDesc string `json:"ScenarioDesc" xml:"ScenarioDesc"`
}
DataItem is a nested struct in sasti response
type DescribeDomainReportRequest ¶
type DescribeDomainReportRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
Field string `position:"Query" name:"Field"`
Domain string `position:"Query" name:"Domain"`
ServiceLang string `position:"Query" name:"ServiceLang"`
}
DescribeDomainReportRequest is the request struct for api DescribeDomainReport
func CreateDescribeDomainReportRequest ¶
func CreateDescribeDomainReportRequest() (request *DescribeDomainReportRequest)
CreateDescribeDomainReportRequest creates a request to invoke DescribeDomainReport API
type DescribeDomainReportResponse ¶
type DescribeDomainReportResponse struct {
*responses.BaseResponse
Intelligences string `json:"Intelligences" xml:"Intelligences"`
Domain string `json:"Domain" xml:"Domain"`
SslCert string `json:"SslCert" xml:"SslCert"`
AttackPreferenceTop5 string `json:"AttackPreferenceTop5" xml:"AttackPreferenceTop5"`
ThreatTypes string `json:"ThreatTypes" xml:"ThreatTypes"`
Confidence string `json:"Confidence" xml:"Confidence"`
ThreatLevel string `json:"ThreatLevel" xml:"ThreatLevel"`
AttackCntByThreatType string `json:"AttackCntByThreatType" xml:"AttackCntByThreatType"`
Context string `json:"Context" xml:"Context"`
Whois string `json:"Whois" xml:"Whois"`
RequestId string `json:"RequestId" xml:"RequestId"`
Scenario string `json:"Scenario" xml:"Scenario"`
Basic string `json:"Basic" xml:"Basic"`
Group string `json:"Group" xml:"Group"`
}
DescribeDomainReportResponse is the response struct for api DescribeDomainReport
func CreateDescribeDomainReportResponse ¶
func CreateDescribeDomainReportResponse() (response *DescribeDomainReportResponse)
CreateDescribeDomainReportResponse creates a response to parse from DescribeDomainReport response
type DescribeFileReportRequest ¶
type DescribeFileReportRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
Field string `position:"Query" name:"Field"`
ServiceLang string `position:"Query" name:"ServiceLang"`
FileHash string `position:"Query" name:"FileHash"`
}
DescribeFileReportRequest is the request struct for api DescribeFileReport
func CreateDescribeFileReportRequest ¶
func CreateDescribeFileReportRequest() (request *DescribeFileReportRequest)
CreateDescribeFileReportRequest creates a request to invoke DescribeFileReport API
type DescribeFileReportResponse ¶
type DescribeFileReportResponse struct {
*responses.BaseResponse
Intelligences string `json:"Intelligences" xml:"Intelligences"`
RequestId string `json:"RequestId" xml:"RequestId"`
FileHash string `json:"FileHash" xml:"FileHash"`
ThreatTypes string `json:"ThreatTypes" xml:"ThreatTypes"`
Basic string `json:"Basic" xml:"Basic"`
ThreatLevel string `json:"ThreatLevel" xml:"ThreatLevel"`
Sandbox string `json:"Sandbox" xml:"Sandbox"`
}
DescribeFileReportResponse is the response struct for api DescribeFileReport
func CreateDescribeFileReportResponse ¶
func CreateDescribeFileReportResponse() (response *DescribeFileReportResponse)
CreateDescribeFileReportResponse creates a response to parse from DescribeFileReport response
type DescribeIpReportRequest ¶
type DescribeIpReportRequest struct {
*requests.RpcRequest
SourceIp string `position:"Query" name:"SourceIp"`
Ip string `position:"Query" name:"Ip"`
Field string `position:"Query" name:"Field"`
ServiceLang string `position:"Query" name:"ServiceLang"`
}
DescribeIpReportRequest is the request struct for api DescribeIpReport
func CreateDescribeIpReportRequest ¶
func CreateDescribeIpReportRequest() (request *DescribeIpReportRequest)
CreateDescribeIpReportRequest creates a request to invoke DescribeIpReport API
type DescribeIpReportResponse ¶
type DescribeIpReportResponse struct {
*responses.BaseResponse
Context string `json:"Context" xml:"Context"`
Intelligences string `json:"Intelligences" xml:"Intelligences"`
Whois string `json:"Whois" xml:"Whois"`
RequestId string `json:"RequestId" xml:"RequestId"`
AttackPreferenceTop5 string `json:"AttackPreferenceTop5" xml:"AttackPreferenceTop5"`
Confidence string `json:"Confidence" xml:"Confidence"`
ThreatTypes string `json:"ThreatTypes" xml:"ThreatTypes"`
Scenario string `json:"Scenario" xml:"Scenario"`
Ip string `json:"Ip" xml:"Ip"`
ThreatLevel string `json:"ThreatLevel" xml:"ThreatLevel"`
AttackCntByThreatType string `json:"AttackCntByThreatType" xml:"AttackCntByThreatType"`
Group string `json:"Group" xml:"Group"`
}
DescribeIpReportResponse is the response struct for api DescribeIpReport
func CreateDescribeIpReportResponse ¶
func CreateDescribeIpReportResponse() (response *DescribeIpReportResponse)
CreateDescribeIpReportResponse creates a response to parse from DescribeIpReport response
type GetGraphQueryTemplatesRequest ¶
type GetGraphQueryTemplatesRequest struct {
*requests.RpcRequest
ServiceUnit string `position:"Body" name:"ServiceUnit"`
Env string `position:"Body" name:"Env"`
}
GetGraphQueryTemplatesRequest is the request struct for api GetGraphQueryTemplates
func CreateGetGraphQueryTemplatesRequest ¶
func CreateGetGraphQueryTemplatesRequest() (request *GetGraphQueryTemplatesRequest)
CreateGetGraphQueryTemplatesRequest creates a request to invoke GetGraphQueryTemplates API
type GetGraphQueryTemplatesResponse ¶
type GetGraphQueryTemplatesResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Data []DataItem `json:"Data" xml:"Data"`
}
GetGraphQueryTemplatesResponse is the response struct for api GetGraphQueryTemplates
func CreateGetGraphQueryTemplatesResponse ¶
func CreateGetGraphQueryTemplatesResponse() (response *GetGraphQueryTemplatesResponse)
CreateGetGraphQueryTemplatesResponse creates a response to parse from GetGraphQueryTemplates response