Documentation
¶
Index ¶
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) UpdateCall(request *UpdateCallRequest) (response *UpdateCallResponse, err error)
- func (client *Client) UpdateCallWithCallback(request *UpdateCallRequest, ...) <-chan int
- func (client *Client) UpdateCallWithChan(request *UpdateCallRequest) (<-chan *UpdateCallResponse, <-chan error)
- func (client *Client) UploadVoiceData(request *UploadVoiceDataRequest) (response *UploadVoiceDataResponse, err error)
- func (client *Client) UploadVoiceDataWithCallback(request *UploadVoiceDataRequest, ...) <-chan int
- func (client *Client) UploadVoiceDataWithChan(request *UploadVoiceDataRequest) (<-chan *UploadVoiceDataResponse, <-chan error)
- type UpdateCallRequest
- type UpdateCallResponse
- type UploadVoiceDataRequest
- type UploadVoiceDataResponse
- type UploadVoiceDataVoiceDataList
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) UpdateCall ¶
func (client *Client) UpdateCall(request *UpdateCallRequest) (response *UpdateCallResponse, err error)
UpdateCall invokes the smartsales.UpdateCall API synchronously
func (*Client) UpdateCallWithCallback ¶
func (client *Client) UpdateCallWithCallback(request *UpdateCallRequest, callback func(response *UpdateCallResponse, err error)) <-chan int
UpdateCallWithCallback invokes the smartsales.UpdateCall API asynchronously
func (*Client) UpdateCallWithChan ¶
func (client *Client) UpdateCallWithChan(request *UpdateCallRequest) (<-chan *UpdateCallResponse, <-chan error)
UpdateCallWithChan invokes the smartsales.UpdateCall API asynchronously
func (*Client) UploadVoiceData ¶
func (client *Client) UploadVoiceData(request *UploadVoiceDataRequest) (response *UploadVoiceDataResponse, err error)
UploadVoiceData invokes the smartsales.UploadVoiceData API synchronously
func (*Client) UploadVoiceDataWithCallback ¶
func (client *Client) UploadVoiceDataWithCallback(request *UploadVoiceDataRequest, callback func(response *UploadVoiceDataResponse, err error)) <-chan int
UploadVoiceDataWithCallback invokes the smartsales.UploadVoiceData API asynchronously
func (*Client) UploadVoiceDataWithChan ¶
func (client *Client) UploadVoiceDataWithChan(request *UploadVoiceDataRequest) (<-chan *UploadVoiceDataResponse, <-chan error)
UploadVoiceDataWithChan invokes the smartsales.UploadVoiceData API asynchronously
type UpdateCallRequest ¶
type UpdateCallRequest struct {
*requests.RpcRequest
CallId requests.Integer `position:"Query" name:"CallId"`
ClueStatusRemark string `position:"Query" name:"ClueStatusRemark"`
AgentKey string `position:"Query" name:"AgentKey"`
BusinessResult requests.Integer `position:"Query" name:"BusinessResult"`
CustomCallId string `position:"Query" name:"CustomCallId"`
}
UpdateCallRequest is the request struct for api UpdateCall
func CreateUpdateCallRequest ¶
func CreateUpdateCallRequest() (request *UpdateCallRequest)
CreateUpdateCallRequest creates a request to invoke UpdateCall API
type UpdateCallResponse ¶
type UpdateCallResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Success string `json:"Success" xml:"Success"`
}
UpdateCallResponse is the response struct for api UpdateCall
func CreateUpdateCallResponse ¶
func CreateUpdateCallResponse() (response *UpdateCallResponse)
CreateUpdateCallResponse creates a response to parse from UpdateCall response
type UploadVoiceDataRequest ¶
type UploadVoiceDataRequest struct {
*requests.RpcRequest
AgentKey string `position:"Query" name:"AgentKey"`
VoiceDataList *[]UploadVoiceDataVoiceDataList `position:"Query" name:"VoiceDataList" type:"Json"`
}
UploadVoiceDataRequest is the request struct for api UploadVoiceData
func CreateUploadVoiceDataRequest ¶
func CreateUploadVoiceDataRequest() (request *UploadVoiceDataRequest)
CreateUploadVoiceDataRequest creates a request to invoke UploadVoiceData API
type UploadVoiceDataResponse ¶
type UploadVoiceDataResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
JobId string `json:"JobId" xml:"JobId"`
}
UploadVoiceDataResponse is the response struct for api UploadVoiceData
func CreateUploadVoiceDataResponse ¶
func CreateUploadVoiceDataResponse() (response *UploadVoiceDataResponse)
CreateUploadVoiceDataResponse creates a response to parse from UploadVoiceData response
type UploadVoiceDataVoiceDataList ¶
type UploadVoiceDataVoiceDataList struct {
CustomParamJson string `name:"CustomParamJson"`
ClueStatusRemark string `name:"ClueStatusRemark"`
BeginTime string `name:"BeginTime"`
CallChannel string `name:"CallChannel"`
BusinessResult string `name:"BusinessResult"`
CustomCallId string `name:"CustomCallId"`
SalesPersonId string `name:"SalesPersonId"`
TeamId string `name:"TeamId"`
CustomerId string `name:"CustomerId"`
FileUrl string `name:"FileUrl"`
ClientTrackNumber string `name:"ClientTrackNumber"`
CustomerName string `name:"CustomerName"`
CallType string `name:"CallType"`
CalleeNumber string `name:"CalleeNumber"`
SalesPersonName string `name:"SalesPersonName"`
CallerNumber string `name:"CallerNumber"`
}
UploadVoiceDataVoiceDataList is a repeated param struct in UploadVoiceDataRequest