Documentation
¶
Index ¶
- type CancelWaitingAsyncJobRequest
- type CancelWaitingAsyncJobResponse
- type Client
- func NewClient() (client *Client, err error)
- func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
- func NewClientWithEcsRamRole(regionId string, roleName string) (client *Client, err error)
- func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
- func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
- func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
- func NewClientWithRamRoleArnAndPolicy(regionId string, ...) (client *Client, err error)
- func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
- func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
- func (client *Client) CancelWaitingAsyncJob(request *CancelWaitingAsyncJobRequest) (response *CancelWaitingAsyncJobResponse, err error)
- func (client *Client) CancelWaitingAsyncJobWithCallback(request *CancelWaitingAsyncJobRequest, ...) <-chan int
- func (client *Client) CancelWaitingAsyncJobWithChan(request *CancelWaitingAsyncJobRequest) (<-chan *CancelWaitingAsyncJobResponse, <-chan error)
- func (client *Client) GetAsyncJobResult(request *GetAsyncJobResultRequest) (response *GetAsyncJobResultResponse, err error)
- func (client *Client) GetAsyncJobResultWithCallback(request *GetAsyncJobResultRequest, ...) <-chan int
- func (client *Client) GetAsyncJobResultWithChan(request *GetAsyncJobResultRequest) (<-chan *GetAsyncJobResultResponse, <-chan error)
- func (client *Client) QueryAsyncJobList(request *QueryAsyncJobListRequest) (response *QueryAsyncJobListResponse, err error)
- func (client *Client) QueryAsyncJobListWithCallback(request *QueryAsyncJobListRequest, ...) <-chan int
- func (client *Client) QueryAsyncJobListWithChan(request *QueryAsyncJobListRequest) (<-chan *QueryAsyncJobListResponse, <-chan error)
- type Data
- type DataInQueryAsyncJobList
- type GetAsyncJobResultRequest
- type GetAsyncJobResultResponse
- type QueryAsyncJobListRequest
- type QueryAsyncJobListResponse
- type Result
- type ResultItem
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CancelWaitingAsyncJobRequest ¶
type CancelWaitingAsyncJobRequest struct {
*requests.RpcRequest
JobId string `position:"Body" name:"JobId"`
Async requests.Boolean `position:"Body" name:"Async"`
}
CancelWaitingAsyncJobRequest is the request struct for api CancelWaitingAsyncJob
func CreateCancelWaitingAsyncJobRequest ¶
func CreateCancelWaitingAsyncJobRequest() (request *CancelWaitingAsyncJobRequest)
CreateCancelWaitingAsyncJobRequest creates a request to invoke CancelWaitingAsyncJob API
type CancelWaitingAsyncJobResponse ¶
type CancelWaitingAsyncJobResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Message string `json:"Message" xml:"Message"`
Success bool `json:"Success" xml:"Success"`
HttpCode string `json:"HttpCode" xml:"HttpCode"`
}
CancelWaitingAsyncJobResponse is the response struct for api CancelWaitingAsyncJob
func CreateCancelWaitingAsyncJobResponse ¶
func CreateCancelWaitingAsyncJobResponse() (response *CancelWaitingAsyncJobResponse)
CreateCancelWaitingAsyncJobResponse creates a response to parse from CancelWaitingAsyncJob response
type Client ¶
Client is the sdk client struct, each func corresponds to an OpenAPI
func NewClientWithAccessKey ¶
func NewClientWithAccessKey(regionId, accessKeyId, accessKeySecret string) (client *Client, err error)
NewClientWithAccessKey is a shortcut to create sdk client with accesskey usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithEcsRamRole ¶
NewClientWithEcsRamRole is a shortcut to create sdk client with ecs ram role usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithOptions ¶
func NewClientWithOptions(regionId string, config *sdk.Config, credential auth.Credential) (client *Client, err error)
NewClientWithOptions creates a sdk client with regionId/sdkConfig/credential this is the common api to create a sdk client
func NewClientWithProvider ¶
func NewClientWithProvider(regionId string, providers ...provider.Provider) (client *Client, err error)
NewClientWithProvider creates a sdk client with providers usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArn ¶
func NewClientWithRamRoleArn(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRamRoleArnAndPolicy ¶
func NewClientWithRamRoleArnAndPolicy(regionId string, accessKeyId, accessKeySecret, roleArn, roleSessionName, policy string) (client *Client, err error)
NewClientWithRamRoleArn is a shortcut to create sdk client with ram roleArn and policy usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithRsaKeyPair ¶
func NewClientWithRsaKeyPair(regionId string, publicKeyId, privateKey string, sessionExpiration int) (client *Client, err error)
NewClientWithRsaKeyPair is a shortcut to create sdk client with rsa key pair usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func NewClientWithStsToken ¶
func NewClientWithStsToken(regionId, stsAccessKeyId, stsAccessKeySecret, stsToken string) (client *Client, err error)
NewClientWithStsToken is a shortcut to create sdk client with sts token usage: https://github.com/aliyun/alibaba-cloud-sdk-go/blob/master/docs/2-Client-EN.md
func (*Client) CancelWaitingAsyncJob ¶
func (client *Client) CancelWaitingAsyncJob(request *CancelWaitingAsyncJobRequest) (response *CancelWaitingAsyncJobResponse, err error)
CancelWaitingAsyncJob invokes the viapi.CancelWaitingAsyncJob API synchronously
func (*Client) CancelWaitingAsyncJobWithCallback ¶
func (client *Client) CancelWaitingAsyncJobWithCallback(request *CancelWaitingAsyncJobRequest, callback func(response *CancelWaitingAsyncJobResponse, err error)) <-chan int
CancelWaitingAsyncJobWithCallback invokes the viapi.CancelWaitingAsyncJob API asynchronously
func (*Client) CancelWaitingAsyncJobWithChan ¶
func (client *Client) CancelWaitingAsyncJobWithChan(request *CancelWaitingAsyncJobRequest) (<-chan *CancelWaitingAsyncJobResponse, <-chan error)
CancelWaitingAsyncJobWithChan invokes the viapi.CancelWaitingAsyncJob API asynchronously
func (*Client) GetAsyncJobResult ¶
func (client *Client) GetAsyncJobResult(request *GetAsyncJobResultRequest) (response *GetAsyncJobResultResponse, err error)
GetAsyncJobResult invokes the viapi.GetAsyncJobResult API synchronously
func (*Client) GetAsyncJobResultWithCallback ¶
func (client *Client) GetAsyncJobResultWithCallback(request *GetAsyncJobResultRequest, callback func(response *GetAsyncJobResultResponse, err error)) <-chan int
GetAsyncJobResultWithCallback invokes the viapi.GetAsyncJobResult API asynchronously
func (*Client) GetAsyncJobResultWithChan ¶
func (client *Client) GetAsyncJobResultWithChan(request *GetAsyncJobResultRequest) (<-chan *GetAsyncJobResultResponse, <-chan error)
GetAsyncJobResultWithChan invokes the viapi.GetAsyncJobResult API asynchronously
func (*Client) QueryAsyncJobList ¶
func (client *Client) QueryAsyncJobList(request *QueryAsyncJobListRequest) (response *QueryAsyncJobListResponse, err error)
QueryAsyncJobList invokes the viapi.QueryAsyncJobList API synchronously
func (*Client) QueryAsyncJobListWithCallback ¶
func (client *Client) QueryAsyncJobListWithCallback(request *QueryAsyncJobListRequest, callback func(response *QueryAsyncJobListResponse, err error)) <-chan int
QueryAsyncJobListWithCallback invokes the viapi.QueryAsyncJobList API asynchronously
func (*Client) QueryAsyncJobListWithChan ¶
func (client *Client) QueryAsyncJobListWithChan(request *QueryAsyncJobListRequest) (<-chan *QueryAsyncJobListResponse, <-chan error)
QueryAsyncJobListWithChan invokes the viapi.QueryAsyncJobList API asynchronously
type Data ¶
type Data struct {
JobId string `json:"JobId" xml:"JobId"`
Result string `json:"Result" xml:"Result"`
ErrorMessage string `json:"ErrorMessage" xml:"ErrorMessage"`
Status string `json:"Status" xml:"Status"`
ErrorCode string `json:"ErrorCode" xml:"ErrorCode"`
}
Data is a nested struct in viapi response
type DataInQueryAsyncJobList ¶
type DataInQueryAsyncJobList struct {
CurrentPage int `json:"CurrentPage" xml:"CurrentPage"`
PageSize int `json:"PageSize" xml:"PageSize"`
TotalPage int `json:"TotalPage" xml:"TotalPage"`
TotalRecord int `json:"TotalRecord" xml:"TotalRecord"`
Result []ResultItem `json:"Result" xml:"Result"`
}
DataInQueryAsyncJobList is a nested struct in viapi response
type GetAsyncJobResultRequest ¶
type GetAsyncJobResultRequest struct {
*requests.RpcRequest
JobId string `position:"Body" name:"JobId"`
Async requests.Boolean `position:"Body" name:"Async"`
}
GetAsyncJobResultRequest is the request struct for api GetAsyncJobResult
func CreateGetAsyncJobResultRequest ¶
func CreateGetAsyncJobResultRequest() (request *GetAsyncJobResultRequest)
CreateGetAsyncJobResultRequest creates a request to invoke GetAsyncJobResult API
type GetAsyncJobResultResponse ¶
type GetAsyncJobResultResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Data Data `json:"Data" xml:"Data"`
}
GetAsyncJobResultResponse is the response struct for api GetAsyncJobResult
func CreateGetAsyncJobResultResponse ¶
func CreateGetAsyncJobResultResponse() (response *GetAsyncJobResultResponse)
CreateGetAsyncJobResultResponse creates a response to parse from GetAsyncJobResult response
type QueryAsyncJobListRequest ¶
type QueryAsyncJobListRequest struct {
*requests.RpcRequest
StartTime string `position:"Body" name:"StartTime"`
PageNum string `position:"Body" name:"PageNum"`
JobId string `position:"Body" name:"JobId"`
PopApiName string `position:"Body" name:"PopApiName"`
PageSize string `position:"Body" name:"PageSize"`
PopProduct string `position:"Body" name:"PopProduct"`
EndTime string `position:"Body" name:"EndTime"`
Status string `position:"Body" name:"Status"`
}
QueryAsyncJobListRequest is the request struct for api QueryAsyncJobList
func CreateQueryAsyncJobListRequest ¶
func CreateQueryAsyncJobListRequest() (request *QueryAsyncJobListRequest)
CreateQueryAsyncJobListRequest creates a request to invoke QueryAsyncJobList API
type QueryAsyncJobListResponse ¶
type QueryAsyncJobListResponse struct {
*responses.BaseResponse
RequestId string `json:"RequestId" xml:"RequestId"`
Message string `json:"Message" xml:"Message"`
Success bool `json:"Success" xml:"Success"`
HttpCode string `json:"HttpCode" xml:"HttpCode"`
Data DataInQueryAsyncJobList `json:"Data" xml:"Data"`
}
QueryAsyncJobListResponse is the response struct for api QueryAsyncJobList
func CreateQueryAsyncJobListResponse ¶
func CreateQueryAsyncJobListResponse() (response *QueryAsyncJobListResponse)
CreateQueryAsyncJobListResponse creates a response to parse from QueryAsyncJobList response
type Result ¶
type Result struct {
ResultItem []ResultItem `json:"result" xml:"result"`
}
Result is a nested struct in viapi response
type ResultItem ¶
type ResultItem struct {
CallerParentId string `json:"CallerParentId" xml:"CallerParentId"`
EndTime string `json:"EndTime" xml:"EndTime"`
GmtCreate string `json:"GmtCreate" xml:"GmtCreate"`
JobId string `json:"JobId" xml:"JobId"`
PopApiName string `json:"PopApiName" xml:"PopApiName"`
PopProduct string `json:"PopProduct" xml:"PopProduct"`
StartTime string `json:"StartTime" xml:"StartTime"`
Status string `json:"Status" xml:"Status"`
}
ResultItem is a nested struct in viapi response